********************************************************************************
*** EFFECT OF STARTING PRIMARY SCHOOL IN CERTAIN PART OF THE ELECTORAL CYCLE ***
********************************************************************************
* INPUTS: 
* ASER household datasets: aser05hh.dta, aser06.dta, aser07hh.dta, aser08.dta, aser2009.dta, aser2010.dta, aser2011.dta, aser2012.dta
* /DISE_clean_Dec13/distname_list0212.dta
* AssemblyElec/2000-2012-DistrictPoliticsMatrix
* /IndiaTeachers/Census/districts2011.dta (is it used?)
* /IndiaTeachers/Politicalcycle/districtexitrates2.dta (cycle_tch.do)
* /tera1/IndiaTeachers/Politicalcycle/exitvolatility.dta (cycle_tch.do)
*
* OUTPUTS: Table 3, Table 7, Table 8, Table 9, Appendix Table X3, Table 10

* updated 13.1.2016 

***************************************************************************
* GET DISE DISTRICT CODES MATCHED TO ASER ONES, USING RECLINK FUZZY MATCH *
* In most states they are the same, but not in all                        *
***************************************************************************
clear
use state_code district_code district using /tera1/ASER/aser05hh.dta
gen year=2005
rename district district_name
append using /tera1/ASER/aser06.dta, keep(state_code district_code district_name)
replace year=2006 if year==.
append using /tera1/ASER/aser07hh.dta, keep(state_code district_code district_name)
replace year=2007 if year==.
append using /tera1/ASER/aser08.dta, keep(state_code district_code district_name)
replace year=2008 if year==.
append using /tera1/ASER/aser2009.dta, keep(state_code district_code district_name)
replace year=2009 if year==.
append using /tera1/ASER/aser2010.dta, keep(state_code district_code district_name)
replace year=2010 if year==.
append using /tera1/ASER/aser2011.dta, keep(state_code district_code district_name)
replace year=2011 if year==.
* 2012 doesn't have dist name
append using /tera1/ASER/aser2012.dta, keep(state_code district_code)
replace year=2012 if year==.
duplicates drop
gen asercd=state*100+district_code
sort asercd year
replace district_name=district_name[_n-1] if year==2012 & year[_n-1]==2011 & asercd==asercd[_n-1]
rename state_code state
rename year ac_year
replace ac_year=ac_year-1
sort state ac_year district_name 
saveold /tera1/ASER/asername_list0512.dta,replace
sort state ac_year asercd
saveold /tera1/ASER/asercd_list0512.dta,replace

*** FUZZY MATCH WITH RECLINK ***
* require: state, year, match by name
use /tera1/DISE_Dec13/DISE_clean_Dec13/distname_list0212.dta,clear
replace distname=upper(trim(distname))
drop if ac_year<2004
sort state ac_year distname
* id using for reclink, form YYSSNN = Year State Number
gen idu=1 if ac_year!=ac_year[_n-1] | state!=state[_n-1]
replace idu=idu[_n-1]+1 if idu==.
replace idu=idu+state*100+(ac_year-2000)*10000
label var idu "DISE dist id"
* 5629 unique values, 35 states
save /tera1/DISE_Dec13/DISE_clean_Dec13/distname_list0212_v2.dta,replace

use /tera1/ASER/asername_list0512.dta,clear
rename district_name distname
replace distname=subinstr(distname,"*","",1)
replace distname=upper(trim(distname))
sort state ac_year distname 
* id master for reclink
gen idm=1 if ac_year!=ac_year[_n-1] | state!=state[_n-1]
replace idm=idm[_n-1]+1 if idm==.
replace idm=idm+state*100+(ac_year-2000)*10000
label var idm "ASER dist id"
* 4472 unique values, 32 states
reclink state ac_year distname using /tera1/DISE_Dec13/DISE_clean_Dec13/distname_list0212_v2.dta, idmaster(idm) idusing(idu) gen(lscore) req(state ac_year) wmatch(1 1 10)
ge ok=1 if asercd==distcd
replace ok=0 if asercd!=distcd & asercd!=. & distcd!=.
tabstat ok,stat(mean) by(state)
*go through by state and fix the rest
sort state distname ac_year
replace distcd = 114 in 39
replace distcd = 107 in 52
replace distcd = 311 in 212
replace distcd = 307 in 300
replace distcd = 307 in 301
replace distcd = 307 in 302
replace distcd = 307 in 303
replace distcd = 307 in 299
replace distcd = 510 in 328
replace distcd = 613 in 431
replace distcd = 607 in 429
replace distcd = 614 in 428
replace distcd = 611 in 430
replace distcd = 620 in 526
replace distcd = 807 in 583
replace distcd = 924 in 837
replace distcd = 968 in 1318
replace distcd = 968 in 1319
replace distcd = 968 in 1320
replace distcd = 968 in 1321
replace distcd = 968 in 1322
replace distcd = 968 in 1323
replace distcd = 968 in 1324
replace distcd = 968 in 1325
replace distcd = 1309 in 1794
replace distcd = 1309 in 1795
replace distcd = 1309 in 1796
replace distcd = 1310 in 1808
replace distcd = 1310 in 1809
replace distcd = 1310 in 1810
replace distcd = 1311 in 1829
replace distcd = 1311 in 1830
replace distcd = 1311 in 1831
replace asercd = . in 2134
replace distcd = . in 2134
replace distcd = 2012 in 2338
replace distcd = 2019 in 2340
replace distcd = 2023 in 2341
replace distcd = 2024 in 2339
replace distcd = 2422 in 3221
replace distcd = 2426 in 3395
replace distcd = . in 3898
replace asercd = . in 3898
replace distcd = . in 3901
replace asercd = . in 3901
replace distcd = . in 3903
replace asercd = . in 3903
replace distcd = . in 3904
replace asercd = . in 3904
* The rest: Seems that ASER code and DISE code always the same, so just duplicate for the rest  (mostly 2011)
egen okm=mean(ok),by(state)
replace distcd=asercd if asercd!=. & distcd==. & okm==1
keep ac_year asercd distcd
drop if asercd==.
rename ac_year year
replace year=year+1
sort year asercd
label var distcd "DISE district code"
label var asercd "ASER state_code*100+district_code"
saveold /tera1/ASER/asercd-distcd-key.dta,replace

**********
** 2005 **
**********
clear
use /tera1/ASER/aser05hh.dta
ge asercd=100*state_code+district_code
codebook asercd
* 489 districts
rename district district_name
* Fix some district names which exist in 2 states
replace district_name=trim(district_name)
replace state=trim(state)
replace district_name="Hamirpur UP" if state=="UP" & district_name=="Hamirpur"
replace district_name="Bilaspur CG" if state=="Chhatisgarh" & district_name=="Bilaspur"
replace district_name="Aurangabad BH" if state=="Bihar" & district_name=="Aurangabad"
replace district_name="Aurangabad MR" if state=="Maharashtra" & district_name=="Aurangabad"
replace district_name="Raigarh CG" if state=="Chhatisgarh" & district_name=="Raigarh"
replace district_name="Raigarh MR" if state=="Maharashtra" & district_name=="Raigarh"

gen read=0 if lang_nothing==1
replace read=1 if lang_letter==1
replace read=2 if lang_word==1
replace read=3 if lang_para==1
replace read=4 if lang_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_num==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
replace class=. if class>8
gen startyr=2005+1-class

* lang and math conditional on age
* use age-specific z-scores
gen readz=.
foreach num of numlist 6/14 {
egen readz`num'=std(read) if child_age==`num'
replace readz=readz`num' if child_age==`num'
drop readz`num'
}
gen mathz=.
foreach num of numlist 6/14 {
egen mathz`num'=std(math) if child_age==`num'
replace mathz=mathz`num' if child_age==`num'
drop mathz`num'
}
* Use these 2005 age-specific z-scores for all subsequent years
save /tera1/ASER/aser05hh_temp,replace
keep child_age read readz
duplicates drop 
sort child_age read
save /tera1/ASER/age_z_read6-14,replace
use /tera1/ASER/aser05hh_temp,clear
keep child_age math mathz
duplicates drop 
sort child_age math
save /tera1/ASER/age_z_math6-14,replace
use /tera1/ASER/aser05hh_temp,clear

* % in Private schools 
gen schpri=1 if pvt==1
replace schpri=0 if govt==1|egs==1 
* missing inlcude categories never, study, work, visit, madarsa
tab schpri,mi

ge never_sc=1 if never==1
replace never_sc=0 if never==.


* Separate vars for girls and boys, private/gov
gen mathb=mathz if child_sex==1 & schpri==0
gen mathg=mathz if child_sex==2 & schpri==0
gen readb=readz if child_sex==1 & schpri==0
gen readg=readz if child_sex==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age
rename child_sex sex

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age class schpri never_sc startyr femshare age sex state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2005
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readg "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
saveold /tera1/ASER/aser05indiv2.dta,replace

**********
** 2006 **
**********
clear
use /tera1/ASER/aser06.dta
ge asercd=100*state_code+district_code
codebook asercd
* 557 districts
* Fix some district names which exist in 2 states
replace district_name=trim(district_name)
rename state_name state
replace state=trim(state)
replace district_name="Hamirpur UP" if state=="UTTAR PRADESH" & district_name=="Hamirpur"
replace district_name="Hamirpur HP" if state=="HIMACHAL PRADESH" & district_name=="Hamirpur"
replace district_name="Bilaspur CG" if state=="CHHATTISGARH" & district_name=="Bilaspur"
replace district_name="Bilaspur HP" if state=="HIMACHAL PRADESH" & district_name=="Bilaspur"
replace district_name="Aurangabad BH" if state=="BIHAR" & district_name=="Aurangabad"
replace district_name="Aurangabad MR" if state=="MAHARASHTRA" & district_name=="Aurangabad"
replace district_name="Raigarh CG" if state=="CHHATTISGARH" & district_name=="Raigarh"
replace district_name="Raigarh MR" if state=="MAHARASHTRA" & district_name=="Raigarh"

gen read=0 if read_nothing==1
replace read=1 if read_letter==1
replace read=2 if read_word==1
replace read=3 if read_para==1
replace read=4 if read_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_numrec==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
rename age_5to16class class
replace class=. if class>8
gen startyr=2006+1-class

* lang and math conditional on age
* use age-specific sigma scores
rename childage child_age
sort child_age read
merge child_age read using /tera1/ASER/age_z_read6-14
drop _merge
sort child_age math
merge child_age math using /tera1/ASER/age_z_math6-14
drop _merge

* % in Private schools (include egs as public) 
gen schpri=1 == age_5to16pvt==1
replace schpri=. if age_5to16madarsa==1|age_5to16oosnever==1|age_5to16oosdropout==1
tab schpri,mi

ge never_sc=1 if age_5to16oosnever==1
replace never_sc=0 if age_5to16oosnever==.



* Separate vars for girls and boys, private/gov
gen mathb=mathz if sex==1 & schpri==0
gen mathg=mathz if sex==2 & schpri==0
gen readb=readz if sex==1 & schpri==0
gen readg=readz if sex==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age

*Mother Education & age
rename mother_schoolingclass mclass
replace mclass=. if mclass==99
replace mclass=0 if mother_schoolingnotattended==1
rename mother_testcanread mreads
replace mreads=0 if mother_testcannotread==1
rename mother_age mage
label var mclass "Mother schooling highest class"
label var mread "Mother can read"
label var mage "Mother's age"

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age class schpri never_sc startyr mclass mread mage femshare age sex state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2006
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readg "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
save /tera1/ASER/aser06indiv2.dta,replace


**********
** 2007 **
**********
clear
use /tera1/ASER/aser07hh.dta
ge asercd=100*state_code+district_code
codebook asercd
* 570 districts
* Fix some district names which exist in 2 states
replace district_name=trim(district_name)
rename state_name state
replace state=trim(state)
replace district_name="Hamirpur UP" if state=="UTTAR PRADESH" & district_name=="Hamirpur"
replace district_name="Hamirpur HP" if state=="HIMACHAL PRADESH" & district_name=="Hamirpur"
replace district_name="Bilaspur CG" if state=="CHHATTISGARH" & district_name=="Bilaspur"
replace district_name="Bilaspur HP" if state=="HIMACHAL PRADESH" & district_name=="Bilaspur"
replace district_name="Aurangabad BH" if state=="BIHAR" & district_name=="Aurangabad"
replace district_name="Aurangabad MR" if state=="MAHARASHTRA" & district_name=="Aurangabad"
replace district_name="Raigarh CG" if state=="CHHATTISGARH" & district_name=="Raigarh"
replace district_name="Raigarh MR" if state=="MAHARASHTRA" & district_name=="Raigarh"

* Rename varibles
rename basiclearninglevelsreadstory read_story
rename basiclearninglevelsreadpara read_para
rename basiclearninglevelsreadword read_word
rename basiclearninglevelsreadletter read_letter 
rename basiclearninglevelsreadnothing read_nothing
rename mathleveldivision math_div
rename mathlevelsubtraction math_sub
* Is this comparable??
gen math_numrec=1 if mathlevelnumrec1to9==1|mathlevelnumrec10to99==1
rename mathlevelnothing math_nothing

gen read=0 if read_nothing==1
replace read=1 if read_letter==1
replace read=2 if read_word==1
replace read=3 if read_para==1
replace read=4 if read_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_numrec==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
rename child5to16schoolingclassstd class
replace class=. if class>8
gen startyr=2007+1-class

* lang and math conditional on age
* use age-specific sigma scores
sort child_age read
merge child_age read using /tera1/ASER/age_z_read6-14
drop _merge
sort child_age math
merge child_age math using /tera1/ASER/age_z_math6-14
drop _merge

* % in Private schools (include egs as public) 
gen schpri=1 if schoolstatusage5to16pvt==1
replace schpri=0 if schoolstatusage5to16govt==1
tab schpri,mi

ge never_sc=1 if age5to16neverbeentoschool==1
replace never_sc=0 if age5to16neverbeentoschool==.


* Separate vars for girls and boys, private/gov
gen mathb=mathz if child_sex==1 & schpri==0
gen mathg=mathz if child_sex==2 & schpri==0
gen readb=readz if child_sex==1 & schpri==0
gen readg=readz if child_sex==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age
rename child_sex sex
rename village_id village_code 

*Mother Education & age
rename motherstudieduptoclass mclass
replace mclass=0 if mothergonetoschoolno==1
replace mclass=. if mclass==99
*rename mother_testcanread mreads
*replace mreads=0 if mother_testcannotread==1
rename motherage mage
label var mclass "Mother schooling highest class"
*label var mread "Mother can read"
label var mage "Mother's age"

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age sex class schpri never_sc startyr mclass mage femshare state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2007
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readg "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
save /tera1/ASER/aser07indiv2.dta,replace

**********
** 2008 **
**********
clear
use /tera1/ASER/aser08.dta
ge asercd=100*state_code+district_code
codebook asercd
* 577 districts
* Fix some district names which exist in 2 states
replace district_name=trim(district_name)
rename state_name state
replace state=trim(state)
replace district_name="Hamirpur UP" if state=="UTTAR PRADESH" & district_name=="Hamirpur"
replace district_name="Hamirpur HP" if state=="HIMACHAL PRADESH" & district_name=="Hamirpur"
replace district_name="Bilaspur CG" if state=="CHHATTISGARH" & district_name=="Bilaspur"
replace district_name="Bilaspur HP" if state=="HIMACHAL PRADESH" & district_name=="Bilaspur"
replace district_name="Aurangabad BH" if state=="BIHAR" & district_name=="Aurangabad"
replace district_name="Aurangabad MR" if state=="MAHARASHTRA" & district_name=="Aurangabad"
replace district_name="Raigarh CG" if state=="CHHATTISGARH" & district_name=="Raigarh"
replace district_name="Raigarh MR" if state=="MAHARASHTRA" & district_name=="Raigarh"

* Rename variables
rename read_level_2 read_story
rename read_level_1 read_para
rename math_division math_div
rename math_subtraction math_sub
gen math_numrec=1 if math_num_1_9==1|math_num_10_99==1

gen read=0 if read_nothing==1
replace read=1 if read_letter==1
replace read=2 if read_word==1
replace read=3 if read_para==1
replace read=4 if read_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_numrec==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
rename school_class class
replace class=. if class>8
gen startyr=2008+1-class

* lang and math conditional on age
* use age-specific sigma scores
sort child_age read
merge child_age read using /tera1/ASER/age_z_read6-14
drop _merge
sort child_age math
merge child_age math using /tera1/ASER/age_z_math6-14
drop _merge

* % in Private schools 
gen schpri=1 if school_private==1
replace schpri=0 if school_govt==1
tab schpri,mi

ge never_sc=1 if oos_never_enr==1
replace never_sc=0 if oos_never_enr==.


* Separate vars for girls and boys, private/gov
gen mathb=mathz if child_gender==1 & schpri==0
gen mathg=mathz if child_gender==2 & schpri==0
gen readb=readz if child_gender==1 & schpri==0
gen readg=readz if child_gender==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age
rename child_gender sex
rename hh_multiplier mult

*Mother Education & age
rename mother_class mclass
replace mclass=0 if mother_gone_to_school_no==1
replace mclass=. if mclass==99
rename mother_age mage
label var mclass "Mother schooling highest class"
label var mage "Mother's age"

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age sex class schpri never_sc startyr mclass mage femshare state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2008
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readb "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
save /tera1/ASER/aser08indiv2.dta,replace


**********
** 2009 ** 
**********
clear
use /tera1/ASER/aser2009.dta
ge asercd=100*state_code+district_code
codebook asercd
* 580 districts
* Fix some district names which exist in 2 states
replace district_name=trim(district_name)
rename state_name state
replace state=trim(state)
replace district_name="Hamirpur UP" if state=="UTTAR PRADESH" & district_name=="Hamirpur"
replace district_name="Hamirpur HP" if state=="HIMACHAL PRADESH" & district_name=="Hamirpur"
replace district_name="Bilaspur CG" if state=="CHHATTISGARH" & district_name=="Bilaspur"
replace district_name="Bilaspur HP" if state=="HIMACHAL PRADESH" & district_name=="Bilaspur"
replace district_name="Aurangabad BH" if state=="BIHAR" & district_name=="Aurangabad"
replace district_name="Aurangabad MR" if state=="MAHARASHTRA" & district_name=="Aurangabad"
replace district_name="Raigarh CG" if state=="CHHATTISGARH" & district_name=="Raigarh"
replace district_name="Raigarh MR" if state=="MAHARASHTRA" & district_name=="Raigarh"

* Rename variables
rename read_level_2 read_story
rename read_level_1 read_para
rename math_division math_div
rename math_subtraction math_sub
gen math_numrec=1 if math_num_1_9==1|math_num_10_99==1

gen read=0 if read_nothing==1
replace read=1 if read_letter==1
replace read=2 if read_word==1
replace read=3 if read_para==1
replace read=4 if read_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_numrec==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
rename school_class class
replace class=. if class>8
gen startyr=2009+1-class

* lang and math conditional on age
* use age-specific sigma scores
sort child_age read
merge child_age read using /tera1/ASER/age_z_read6-14
drop _merge
sort child_age math
merge child_age math using /tera1/ASER/age_z_math6-14
drop _merge

* % in Private schools 
gen schpri=1 if school_private==1
replace schpri=0 if school_govt==1
tab schpri,mi

ge never_sc=1 if oos_never_enr==1
replace never_sc=0 if oos_never_enr==.

* Separate vars for girls and boys, private/gov
gen mathb=mathz if child_gender==1 & schpri==0
gen mathg=mathz if child_gender==2 & schpri==0
gen readb=readz if child_gender==1 & schpri==0
gen readg=readz if child_gender==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age
rename child_gender sex
rename hh_multiplier mult

*Mother Education & age
rename mother_class mclass
replace mclass=0 if mother_gone_to_school==2
replace mclass=. if mclass==99
rename mother_read_level_1 mreads
replace mreads=0 if mreads==2
rename mother_age mage
label var mclass "Mother schooling highest class"
label var mread "Mother can read"
label var mage "Mother's age"

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age sex class schpri never_sc startyr mage mclass mreads femshare state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2009
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readg "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
save /tera1/ASER/aser09indiv2.dta,replace


**********
** 2010 ** 
**********
clear
use /tera1/ASER/aser2010.dta
ge asercd=100*state_code+district_code
codebook asercd
* 567 districts
* Fix some district names which exist in 2 states
replace district_name=trim(district_name)
rename state_name state
replace state=trim(state)
replace district_name="Hamirpur UP" if state=="UTTAR PRADESH" & district_name=="Hamirpur"
replace district_name="Hamirpur HP" if state=="HIMACHAL PRADESH" & district_name=="Hamirpur"
replace district_name="Bilaspur CG" if state=="CHHATTISGARH" & district_name=="Bilaspur"
replace district_name="Bilaspur HP" if state=="HIMACHAL PRADESH" & district_name=="Bilaspur"
replace district_name="Aurangabad BH" if state=="BIHAR" & district_name=="Aurangabad"
replace district_name="Aurangabad MR" if state=="MAHARASHTRA" & district_name=="Aurangabad"
replace district_name="Raigarh CG" if state=="CHHATTISGARH" & district_name=="Raigarh"
replace district_name="Raigarh MR" if state=="MAHARASHTRA" & district_name=="Raigarh"

* Rename variables
rename read_level_2 read_story
rename read_level_1 read_para
rename math_division math_div
rename math_subtraction math_sub
gen math_numrec=1 if math_num_1_9==1|math_num_10_99==1

gen read=0 if read_nothing==1
replace read=1 if read_letter==1
replace read=2 if read_word==1
replace read=3 if read_para==1
replace read=4 if read_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_numrec==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
rename school_class class
replace class=. if class>8
gen startyr=2010+1-class

* lang and math conditional on age
* use age-specific sigma scores
sort child_age read
merge child_age read using /tera1/ASER/age_z_read6-14
drop _merge
sort child_age math
merge child_age math using /tera1/ASER/age_z_math6-14
drop _merge

* % in Private schools 
gen schpri=1 if school_private==1
replace schpri=0 if school_govt==1
tab schpri,mi

ge never_sc=1 if oos_never_enr==1
replace never_sc=0 if oos_never_enr==.

* Separate vars for girls and boys, private/gov
gen mathb=mathz if child_gender==1 & schpri==0
gen mathg=mathz if child_gender==2 & schpri==0
gen readb=readz if child_gender==1 & schpri==0
gen readg=readz if child_gender==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age
rename child_gender sex
rename hh_multiplier mult

*Mother Education & age
rename mother_class mclass
replace mclass=0 if mother_gone_to_school_no==1
replace mclass=. if mclass==99
rename mother_mobile_test mreads
replace mreads=0 if mreads==2
rename mother_age mage
replace mage=. if mage==99
label var mclass "Mother schooling highest class"
label var mread "Mother can read"
label var mage "Mother's age"

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age sex class schpri never_sc startyr mage mclass mreads femshare state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2010
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readg "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
save /tera1/ASER/aser10indiv2.dta,replace

**********
** 2011 ** 
**********
clear
use /tera1/ASER/aser2011.dta
ge asercd=100*state_code+district_code
codebook asercd
* 564 districts
* Fix some district names which exist in 2 states
replace district_name=trim(district_name)
rename state_name state
replace state=trim(state)
replace district_name="Hamirpur UP" if state=="UTTAR PRADESH" & district_name=="Hamirpur"
replace district_name="Hamirpur HP" if state=="HIMACHAL PRADESH" & district_name=="Hamirpur"
replace district_name="Bilaspur CG" if state=="CHHATTISGARH" & district_name=="Bilaspur"
replace district_name="Bilaspur HP" if state=="HIMACHAL PRADESH" & district_name=="Bilaspur"
replace district_name="Aurangabad BH" if state=="BIHAR" & district_name=="Aurangabad"
replace district_name="Aurangabad MR" if state=="MAHARASHTRA" & district_name=="Aurangabad"
replace district_name="Raigarh CG" if state=="CHHATTISGARH" & district_name=="Raigarh"
replace district_name="Raigarh MR" if state=="MAHARASHTRA" & district_name=="Raigarh"

* Rename variables
rename read_level_2 read_story
rename read_level_1 read_para
rename math_division math_div
rename math_subtraction math_sub
gen math_numrec=1 if math_num_1_9==1|math_num_10_99==1

gen read=0 if read_nothing==1
replace read=1 if read_letter==1
replace read=2 if read_word==1
replace read=3 if read_para==1
replace read=4 if read_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_numrec==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
rename school_class class
replace class=. if class>8
gen startyr=2011+1-class

* lang and math conditional on age
* use age-specific sigma scores
sort child_age read
merge child_age read using /tera1/ASER/age_z_read6-14
drop _merge
sort child_age math
merge child_age math using /tera1/ASER/age_z_math6-14
drop _merge

* % in Private schools 
gen schpri=1 if school_private==1
replace schpri=0 if school_govt==1
tab schpri,mi
* lots of missing, why? FULL AGE RANGE - for ages 6-12, just 5% missing)

ge never_sc=1 if oos_never_enr==1
replace never_sc=0 if oos_never_enr==.


* Separate vars for girls and boys, private/gov
gen mathb=mathz if child_gender==1 & schpri==0
gen mathg=mathz if child_gender==2 & schpri==0
gen readb=readz if child_gender==1 & schpri==0
gen readg=readz if child_gender==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age
rename child_gender sex
rename hh_multiplier mult

*Mother Education & age
rename mother_class mclass
replace mclass=0 if mother_gone_to_school_no==1
replace mclass=. if mclass==99
rename mother_age mage
replace mage=. if mage==99
label var mclass "Mother schooling highest class"
label var mage "Mother's age"

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age sex class schpri never_sc startyr mage mclass femshare state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2011
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readg "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
save /tera1/ASER/aser11indiv2.dta,replace

**********
** 2012 ** 
**********
clear
* insheet using "/tera1/ASER/ASER 2012/aser2012.txt"
use /tera1/ASER/aser2012.dta
ge asercd=100*state_code+district_code
codebook asercd
* 568 districts
* District name variable empty (get from other years)

* Rename variables
rename read_level_2 read_story
rename read_level_1 read_para
rename math_division math_div
rename math_subtraction math_sub
gen math_numrec=1 if math_num_1_9==1|math_num_10_99==1

gen read=0 if read_nothing==1
replace read=1 if read_letter==1
replace read=2 if read_word==1
replace read=3 if read_para==1
replace read=4 if read_story==1
gen  math=0 if math_nothing==1
replace math=1 if math_numrec==1
replace math=2 if math_sub==1
replace math=3 if math_div==1

* YEAR OF STARTING
rename school_class class
replace class=. if class>8
gen startyr=2012+1-class

* lang and math conditional on age
* use age-specific sigma scores
sort child_age read
merge child_age read using /tera1/ASER/age_z_read6-14
drop _merge
sort child_age math
merge child_age math using /tera1/ASER/age_z_math6-14
drop _merge

* % in Private schools 
gen schpri=1 if school_private==1
replace schpri=0 if school_govt==1
tab schpri,mi
* lots of missing, why? FULL AGE RANGE - for ages 6-12, just 5% missing


ge never_sc=1 if oos_never_enr==1
replace never_sc=0 if oos_never_enr==.

* Separate vars for girls and boys, private/gov
gen mathb=mathz if child_gender==1 & schpri==0
gen mathg=mathz if child_gender==2 & schpri==0
gen readb=readz if child_gender==1 & schpri==0
gen readg=readz if child_gender==2 & schpri==0
gen mathpu=mathz if schpri==0
gen mathpr=mathz if schpri==1
gen readpu=readz if schpri==0
gen readpr=readz if schpri==1

* private share
egen prishare=mean(schpri),by(asercd)

rename child_age age
rename child_gender sex
rename hh_multiplier mult

*Mother Education & age
rename mother_class mclass
replace mclass=0 if mother_gone_to_school_no==1
replace mclass=. if mclass==99
rename mother_age mage
replace mage=. if mage==99
label var mclass "Mother schooling highest class"
label var mage "Mother's age"

* female share
egen femshare=mean(sex) if schpri==0,by(asercd)

* keep only key vars and save a separate file
keep mult village_code age sex class schpri never_sc startyr mage mclass femshare state_code asercd math read mathz readz mathb mathg readb readg mathpu mathpr readpu readpr prishare district_name
gen year=2012
label var class "Pupils's class (ASER)"
label var age "Pupil's age (ASER)"
label var schpri "Private/Public school status (ASER)"
label var startyr "Year started school (Assuming no repetition)"
label var femshare "Female pupil % in public ASER schools"
label var prishare "Private school share in ASER district"
label var read "reading ability index 0-3"
label var math "math ability index 0-3"
label var readz "Age specific z-score for reading"
label var mathz "Age specific z-score for maths"
label var mathb "mathz boys"
label var mathg "mathz girls"
label var readb "readz boys"
label var readg "readz girls"
label var mathpu "mathz public"
label var mathpr "mathz private"
label var readpu "readz public"
label var readpr "readz private"
save /tera1/ASER/aser12indiv2.dta,replace


****************
** POOL YEARS **
****************

clear
use /tera1/ASER/aser05indiv2.dta
append using /tera1/ASER/aser06indiv2.dta
append using /tera1/ASER/aser07indiv2.dta
append using /tera1/ASER/aser08indiv2.dta
append using /tera1/ASER/aser09indiv2.dta
append using /tera1/ASER/aser10indiv2.dta
append using /tera1/ASER/aser11indiv2.dta
append using /tera1/ASER/aser12indiv2.dta,force

* Merge in DISE district code
sort year asercd
merge year asercd using /tera1/ASER/asercd-distcd-key.dta 
drop _merge
save /tera1/ASER/aserindiv05-12.dta,replace



********************************
* ESTIMATE EFFECT OF THE CYCLE *
********************************
use /tera1/ASER/aserindiv05-12.dta,clear

* later years report more years of edu - harmonise:
replace mclass=13 if mclass>13 & mclass!=.
replace sex=sex-1
rename sex female

* Change year to make sure election results of say 2008 are matched to ASER 2009
* since 2009 the first year the new government is effecively governing
replace year=year-1
sort distcd year
merge distcd year using /tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix
replace year=year+1
label var elecyr "0 = post-election, 4=election year"
* election phase defined by state x year

drop if _merge==2
drop _merge

quietly tab elecyr, ge(ed)
*Now ed1 =  post-election, ed5 = election year"
quietly tab eleciv, ge(iv)
quietly tab year, ge(yd)
quietly tab age, ge(agd)
quietly tab class, ge(cld)
quietly tab read,ge(rea)
quietly tab math,ge(mat)

*********************
* MERGE CENSUS INFO *
*********************
sort distcd 
merge distcd using /tera1/IndiaTeachers/Census/districts2011.dta
drop if _merge==2
drop _merge

***************************
* MERGE DISTRICT TURNOVER * (generated by cycle_tch.do)
***************************
rename year ac_year
sort ac_year distcd 
merge ac_year distcd using /tera1/IndiaTeachers/Politicalcycle/districtexitrates2.dta
rename ac_year year

**********************
* NAXALITE DISTRICTS *
**********************
*see more at /ResourceCycle/naxaldists.do
set more off
gen naxal=0
foreach num of numlist 2817 2818 2822 2821 2812 2814 2811 2813 2809 2803 2801 2010 2804 2808 2807 2802 1034 1035 1032 1029 1031 1002 1001 1004 1024 1036 1037 2004 2015 2002 2003 2001 2014 2016 2021 2022 2006 2005 2013 2012 2017 2018 2020 2023 2024 2215 2220 2216 2214 2209 2202 2203 2201 2218 2221 2712 2713 2711 2130 2119 2129 2120 2127 2107 2105 2104 2121 970 969 966 1913 1920 1914 2345 {
replace naxal=1 if distcd==`num'
}


*******************************
* TURNOVER VOLATILITY INDICES * /ResourceCycle/cycle_tch.do
*******************************
rename year ac_year
sort distcd ac_year
capture drop _merge
merge distcd ac_year using /tera1/IndiaTeachers/Politicalcycle/exitvolatility.dta
rename ac_year year
drop if _merge==2
drop _merge
* not merged to year 2012 - fix:
egen cod1_=mean(cod1),by(distcd)
replace cod1=cod1_ if cod1==. & cod1_!=. 
egen trd1_=mean(trd1),by(distcd)
replace trd1=trd1_ if trd1==. & trd1_!=. 
*egen r2d1_=mean(r2d1),by(distcd)
*replace r2d1=r2d1_ if r2d1==. & r2d1_!=. 
drop cod1_ trd1_

tis year
iis distcd

* State trends not included since regression drops them as collinear
** state trends
*foreach num of numlist 1/35 {
*capture gen st_`num'=0
*capture replace st_`num'=ac_year if state==`num'
*}

gen noclass = class==.

* Grade 4 Sumstats (Table 3)
set more off
set logtype text 
log using /tera1/IndiaTeachers/ResourceCycle/aser_sumstat_g4321.txt,replace
noisily su year rea1-rea5 readz mat1-mat4 mathz female age class schpri ed1-ed5 if class==4 & age>=6 & age<=14 & elecyr~=.,sep(0) 
*noisily su year rea1-rea5 readz mat1-mat4 mathz female age class schpri ed1-ed5 if class==3 & age>=6 & age<=14 & elecyr~=.,sep(0) 
*noisily su year rea1-rea5 readz mat1-mat4 mathz female age class schpri ed1-ed5 if class==2 & age>=6 & age<=14 & elecyr~=.,sep(0) 
*noisily su year rea1-rea5 readz mat1-mat4 mathz female age class schpri ed1-ed5 if class==1 & age>=6 & age<=14 & elecyr~=.,sep(0) 
codebook distcd if class<=4 & age>=6 & age<=14 & elecyr~=.
codebook state if class<=4 & age>=6 & age<=14 & elecyr~=.
log close

*** Event graphs (Equation 3 with OLS) ***
* Produces Figure 3, Figure 4 and Figure 5 for the paper.
* dummies for grouped years, before and after elections
gen bef = ed3==1|ed4==1
gen aft = ed1==1|ed2==1
save /tera1/ASER/aserindiv05-12_reg.dta,replace

do aser_polcycle_eventgraphs.do
*** Event graphs end ***

use /tera1/ASER/aserindiv05-12_reg.dta,clear

* Table 7 (effect by current election phase)
xtivreg2 readz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==0 & class==4, fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_currentphase_c4, wide replace 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)
xtivreg2 mathz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==0 & class==4, fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_currentphase_c4, wide append 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)
xtivreg2 readz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==1 & class==4, fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_currentphase_c4, wide append 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)
xtivreg2 mathz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==1 & class==4, fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_currentphase_c4, wide append 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)

* Table 9: subsamples by intensity of turnover in phase 1, Gov schools
xtivreg2 readz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==0 & class==4 & cod1<=.04205, fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_current_splits, wide replace 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)
xtivreg2 readz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==0 & class==4 & cod1>.04205 & cod1!=., fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_current_splits, wide append 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)
xtivreg2 mathz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==0 & class==4 & cod1<=.04205, fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_current_splits, wide append 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)
xtivreg2 mathz (ed1 ed2 ed3 ed4 = iv1 iv2 iv3 iv4) female yd* agd5-agd12 if schpri==0 & class==4 & cod1>.04205 & cod1!=., fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_current_splits, wide append 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed3 ed4)


* Table 8 - Direct effect of teacher turnover
xtreg readz disap female yd* agd5-agd12 if schpri==0 & class==4, fe cluster(distcd)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_disap_c4v2, wide replace 10pct bracket dec(3) fmt(g) keep(disap)
xtreg readz disap female yd* agd5-agd12 if schpri==1 & class==4, fe cluster(distcd)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_disap_c4v2, wide append 10pct bracket dec(3) fmt(g) keep(disap)
xtreg mathz disap female yd* agd5-agd12 if schpri==0 & class==4, fe cluster(distcd)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_disap_c4v2, wide append 10pct bracket dec(3) fmt(g) keep(disap)
xtreg mathz disap female yd* agd5-agd12 if schpri==1 & class==4, fe cluster(distcd)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_disap_c4v2, wide append 10pct bracket dec(3) fmt(g) keep(disap)


** Avoiding election year, pooled, OLS only (no IV since instrumenting less transparent) **
set more off
cd /tera1/IndiaTeachers/ResourceCycle
* Pooling all pupils 
gen notaf=0 
replace notaf=1 if class==4 & ed5==1
replace notaf=1 if class==3 & (ed5==1|ed4==1)
replace notaf=1 if class==2 & (ed5==1|ed4==1|ed3==1)
replace notaf=1 if class==1 & (ed5==1|ed4==1|ed3==1|ed2==1)
gen notaf2=0 
replace notaf2=1 if class==4 & ed1==1
replace notaf2=1 if class==3 & (ed1==1|ed5==1)
replace notaf2=1 if class==2 & (ed1==1|ed5==1|ed4==1)
replace notaf2=1 if class==1 & (ed1==1|ed5==1|ed4==1|ed3==1)
gen notaf3=0 
replace notaf3=1 if class==4 & ed2==1
replace notaf3=1 if class==3 & (ed2==1|ed1==1)
replace notaf3=1 if class==2 & (ed2==1|ed1==1|ed5==1)
replace notaf3=1 if class==1 & (ed2==1|ed1==1|ed5==1|ed4==1)
gen notaf4=0 
replace notaf4=1 if class==4 & ed3==1
replace notaf4=1 if class==3 & (ed3==1|ed2==1)
replace notaf4=1 if class==2 & (ed3==1|ed2==1|ed1==1)
replace notaf4=1 if class==1 & (ed3==1|ed2==1|ed1==1|ed5==1)
gen notaf5=0 
replace notaf5=1 if class==4 & ed4==1
replace notaf5=1 if class==3 & (ed4==1|ed3==1)
replace notaf5=1 if class==2 & (ed4==1|ed3==1|ed2==1)
replace notaf5=1 if class==1 & (ed4==1|ed3==1|ed2==1|ed1==1)

gen notafiv=0 
replace notafiv=1 if class==4 & iv5==1
replace notafiv=1 if class==3 & (iv5==1|iv4==1)
replace notafiv=1 if class==2 & (iv5==1|iv4==1|iv3==1)
replace notafiv=1 if class==1 & (iv5==1|iv4==1|iv3==1|iv2==1)
gen notafiv2=0 
replace notafiv2=1 if class==4 & iv1==1
replace notafiv2=1 if class==3 & (iv1==1|iv5==1)
replace notafiv2=1 if class==2 & (iv1==1|iv5==1|iv4==1)
replace notafiv2=1 if class==1 & (iv1==1|iv5==1|iv4==1|iv3==1)
gen notafiv3=0 
replace notafiv3=1 if class==4 & iv2==1
replace notafiv3=1 if class==3 & (iv2==1|iv1==1)
replace notafiv3=1 if class==2 & (iv2==1|iv1==1|iv5==1)
replace notafiv3=1 if class==1 & (iv2==1|iv1==1|iv5==1|iv4==1)
gen notafiv4=0 
replace notafiv4=1 if class==4 & iv3==1
replace notafiv4=1 if class==3 & (iv3==1|iv2==1)
replace notafiv4=1 if class==2 & (iv3==1|iv2==1|iv1==1)
replace notafiv4=1 if class==1 & (iv3==1|iv2==1|iv1==1|iv5==1)
gen notafiv5=0 
replace notafiv5=1 if class==4 & iv4==1
replace notafiv5=1 if class==3 & (iv4==1|iv3==1)
replace notafiv5=1 if class==2 & (iv4==1|iv3==1|iv2==1)
replace notafiv5=1 if class==1 & (iv4==1|iv3==1|iv2==1|iv1==1)

* replace to missing election year or iv is missing
foreach var of varlist notaf* {
replace `var'=. if elecyr==.
}

label var notaf "Not affected by post-election year (ed5)"
label var notaf2 "Not affected by election year +2 (ed1)"
label var notaf3 "Not affected by election year +3 (ed2)"
label var notaf4 "Not affected by election year +4 (ed3)"
label var notaf5 "Not affected by election year (ed4)"
gen overage=age-class-5
tab overage,ge(oag)
tab class, ge(cl)

* Appendix Table X3, effect by by missed phase
cd /tera1/IndiaTeachers/ResourceCycle/
* reading gov
xtivreg2 readz (notaf = notafiv) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_r, wide 10pct bracket replace dec(3) fmt(g) keep(notaf)
xtivreg2 readz (notaf2 = notafiv2) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_r, wide 10pct bracket append dec(3) fmt(g) keep(notaf2)
xtivreg2 readz (notaf3 = notafiv3) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_r, wide 10pct bracket append dec(3) fmt(g) keep(notaf3)
xtivreg2 readz (notaf4 = notafiv4) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_r, wide 10pct bracket append dec(3) fmt(g) keep(notaf4)
xtivreg2 readz (notaf5 = notafiv5) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_r, wide 10pct bracket append dec(3) fmt(g) keep(notaf5)
* Maths gov
xtivreg2 mathz (notaf = notafiv) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_m, wide 10pct bracket replace dec(3) fmt(g) keep(notaf)
xtivreg2 mathz (notaf2 = notafiv2) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_m, wide 10pct bracket append dec(3) fmt(g) keep(notaf2)
xtivreg2 mathz (notaf3 = notafiv3) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_m, wide 10pct bracket append dec(3) fmt(g) keep(notaf3)
xtivreg2 mathz (notaf4 = notafiv4) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_m, wide 10pct bracket append dec(3) fmt(g) keep(notaf4)
xtivreg2 mathz (notaf5 = notafiv5) female yd* oag* if class==4 & schpri==0, fe cluster(state_code) 
outreg2 using avoidp_m, wide 10pct bracket append dec(3) fmt(g) keep(notaf5)
* reading pri
xtivreg2 readz (notaf = notafiv) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_rp, wide 10pct bracket replace dec(3) fmt(g) keep(notaf)
xtivreg2 readz (notaf2 = notafiv2) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_rp, wide 10pct bracket append dec(3) fmt(g) keep(notaf2)
xtivreg2 readz (notaf3 = notafiv3) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_rp, wide 10pct bracket append dec(3) fmt(g) keep(notaf3)
xtivreg2 readz (notaf4 = notafiv4) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_rp, wide 10pct bracket append dec(3) fmt(g) keep(notaf4)
xtivreg2 readz (notaf5 = notafiv5) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_rp, wide 10pct bracket append dec(3) fmt(g) keep(notaf5)
* Maths pri
xtivreg2 mathz (notaf = notafiv) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_mp, wide 10pct bracket replace dec(3) fmt(g) keep(notaf)
xtivreg2 mathz (notaf2 = notafiv2) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_mp, wide 10pct bracket append dec(3) fmt(g) keep(notaf2)
xtivreg2 mathz (notaf3 = notafiv3) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_mp, wide 10pct bracket append dec(3) fmt(g) keep(notaf3)
xtivreg2 mathz (notaf4 = notafiv4) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_mp, wide 10pct bracket append dec(3) fmt(g) keep(notaf4)
xtivreg2 mathz (notaf5 = notafiv5) female yd* oag* if class==4 & schpri==1, fe cluster(state_code) 
outreg2 using avoidp_mp, wide 10pct bracket append dec(3) fmt(g) keep(notaf5)

* Effect of political cycle on private school enrolment share, grade 4 pupils
* Table 10 (note ed2=iv2 no need to instrument)
xtivreg2 schpri (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 female yd* if class==4, fe cluster(state_code)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/aser_privateshare, wide replace 10pct bracket dec(3) fmt(g) keep(ed4 ed5 ed1 ed2)


* Naxalite districts [Not reported in the paper]
* do non-naxal districts since only 9 states with naxal districts
xtivreg2 readz (notaf = notafiv ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_r_nax, wide 10pct bracket replace dec(3) fmt(g) keep(notaf )
xtivreg2 readz (notaf2  = notafiv2 ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_r_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf2 )
xtivreg2 readz (notaf3  = notafiv3 ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_r_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf3 )
xtivreg2 readz (notaf4  = notafiv4 ) female yd* oag* if class==4 & schpri==0 & naxal==0,  fe cluster(state_code) 
outreg2 using avoidp_r_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf4 )
xtivreg2 readz (notaf5  = notafiv5 ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_r_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf5 )
* math: naxal 
xtivreg2 mathz (notaf = notafiv ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_m_nax, wide 10pct bracket replace dec(3) fmt(g) keep(notaf )
xtivreg2 mathz (notaf2  = notafiv2 ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_m_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf2 )
xtivreg2 mathz (notaf3  = notafiv3 ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_m_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf3 )
xtivreg2 mathz (notaf4  = notafiv4 ) female yd* oag* if class==4 & schpri==0 & naxal==0,  fe cluster(state_code) 
outreg2 using avoidp_m_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf4 )
xtivreg2 mathz (notaf5  = notafiv5 ) female yd* oag* if class==4 & schpri==0 & naxal==0, fe cluster(state_code) 
outreg2 using avoidp_m_nax, wide 10pct bracket append dec(3) fmt(g) keep(notaf5 )







