/**********************************
PREPARE DISE CSV DATA FOR USE (USE DATA OBTAINED IN DEC 2013)

Modified: 28.3.2014 - rewrite for Dec13
* Examresult, pincentives and repeaters lack most data for 2012-13
**********************************/

clear
set more off
set memory 14g 
***********************
* CLEAN TEACHER FILES *
***********************
* Teacher file too large for 16g of mem, split in 2, don't take supvar variables
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_TEACHER_part2.txt,delimiter(";")
drop supvar1-supvar10
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER2.dta,replace
clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_TEACHER_part1.txt,delimiter(";")
drop supvar1-supvar10
append using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER2.dta
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER.dta,replace
erase /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER2.dta

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
replace ac_year="2004" if ac_year=="2004-05"
destring ac_year,replace

* FIX SCHCD AND DESTRING
* Has O:s in place of zeros, refuses to destring 
* This bit may not be needed if schcd comes automatically as numeric
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
* lose 17677 here: have letters, unrecoverable
drop schcd
rename schcd2 schcd
format schcd %14.0g

* FIX DOB
* NOTE: This will still leave errors to the birthyear.
* Later too old and too young must be excluded
gen dob2=substr(dob,1,11)
gen dob3=trim(dob2)
gen dobd=substr(dob3,-2,2)
gen dobm=substr(dob3,-5,2)
gen doby=substr(dob3,-8,2)
* if dobd=="0:", then dob cannot be recovered
replace doby="" if dobd=="0:"
replace dobm="" if dobd=="0:"
* if dobd==" 0" - but note that some doby:s will not make sense
replace doby=substr(dob3,-10,2) if dobd==" 0"
replace dobm=substr(dob3,-7,2) if dobd==" 0"
* if dobd=="00", 
replace doby=substr(dob3,-11,2) if dobd=="00"
replace dobm=substr(dob3,-8,2) if dobd=="00"
* finally fix dobd
replace dobd="" if dobd=="0:"
replace dobd=substr(dob3,-4,2) if dobd==" 0"
replace dobd=substr(dob3,-5,2) if dobd=="00"
destring dobd,replace
destring dobm,replace
destring doby,replace
drop dob dob2 dob3 

* SIMPLIFY NAME
* dots and commas to spaces
replace tchname=subinstr(tchname,"."," ",.)
replace tchname=subinstr(tchname,","," ",.)
*remove SHRI SHIV SMT from the beginning of the names
gen fword=word(tchname,1)
replace tchname=subinword(tchname,"SHRI","",1) if fword=="SHRI"
replace tchname=subinword(tchname,"SHIV","",1) if fword=="SHIV"
replace tchname=subinword(tchname,"SMT","",1) if fword=="SMT"
drop fword
* Take the first and last words
gen name1=word(tchname,1)
gen name2=word(tchname,-1)
replace name1="" if name1=="Type"
replace name2="" if name2=="Here"
drop tchname
* Cut down the memory use, take 12 first chars, cuts only ~1%
replace name1=substr(name1,1,12)
replace name2=substr(name2,1,12)

* YEAR OF JOINING
* clean if joining in the future or more than 60 years ago.
* ac_year=2008 implies academic year 2008-09
replace yoj=. if yoj>2013 & ac_year==2012
replace yoj=. if yoj>2012 & ac_year==2011
replace yoj=. if yoj>2011 & ac_year==2010
replace yoj=. if yoj>2010 & ac_year==2009
replace yoj=. if yoj>2009 & ac_year==2008
replace yoj=. if yoj>2008 & ac_year==2007
replace yoj=. if yoj>2007 & ac_year==2006
replace yoj=. if yoj>2006 & ac_year==2005
replace yoj=. if yoj<1953 & ac_year==2012
replace yoj=. if yoj<1952 & ac_year==2011
replace yoj=. if yoj<1951 & ac_year==2010
replace yoj=. if yoj<1950 & ac_year==2009
replace yoj=. if yoj<1949 & ac_year==2008
replace yoj=. if yoj<1948 & ac_year==2007
replace yoj=. if yoj<1947 & ac_year==2006
replace yoj=. if yoj<1946 & ac_year==2005

* SET DUBIOUS BIRTH YEARS MISSING
ge age=ac_year-1900-doby
* Allow ages 17-80 (drops about 0.1% from both ends)
replace doby=. if age<17|age>80
replace dobm=. if age<17|age>80
replace dobd=. if age<17|age>80
drop age

* SET SEX==9 AS MISSING (1.06% OF OBS) (sex=4 in one obs)
replace sex=. if sex==9|sex==4

* MISSING CASTE
replace caste=. if caste==0|caste==7|caste==8|caste==9
* MISSING CATEGORY
replace category=. if category==0|category==9|category==10|category==11
* MISSING ACAD QUALS
replace qual_acad=. if qual_acad==0|qual_acad==8|qual_acad==9
* MISSING CLASSES TAUGHT
replace cls_taught=. if cls_taught>=8
* MISSING MAIN SUBJECTS
replace main_taught1=. if main_taught1>=9|main_taught1==0
replace main_taught2=. if main_taught2>=9|main_taught2==0
* MISSING MATH/ENGLISH
replace math_upto=. if math_upto==0|math_upto==8|math_upto==9
replace eng_upto=. if eng_upto==0|eng_upto==8|eng_upto==9

* PROFESSIONAL QUALIFICATION
replace qual_prof=. if qual_prof==0|qual_prof>6
* dummy for yes/no
gen qual_prof_d=1 if qual_prof>=1 & qual_prof<=5
replace qual_prof_d=0 if qual_prof==6

* LABEL VARIABLES
label var dobd "DOB, day"
label var dobm "DOB, month"
label var doby "DOB, year"
label var slno "teacher # (within school)"
label var name1 "1st 12 letters of first word" 
label var name2 "1st 12 letters of last word" 
label define ge 1 "Male" 2 "Female"
label values sex ge
label define cs 1 "General" 2 "SC" 3 "ST" 4 "OBC" 5 "ORC" 6 "Others"
label values caste cs
label define ca 1 "Head" 2 "Acting head" 3 "Teacher" 4 "Parateacher" 5 "Parttime teacher" 6 "Community teacher" 7 "Language teacher" 8 "Others"
label values category ca
label var yoj "Year of joining"
label define aq 1 "Below secondary" 2 "Secondary" 3 "Higher Secondary" 4 "Graduate" 5 "Postgraduate" 6 "MPhil/PhD" 7 "Other"
label values qual_acad aq
label define qp 1 "JV, JBT or equiv." 2 "SV, CT, SBT or equiv" 3 "LT, BT, BEd or equiv" 4 "MEd or equiv" 5 "Others" 6 "None" 
label values qual_prof qp
label var qual_prof_d "Dummy for any professional qualification"
label define ct 1 "Primary only" 2 "Upper primary only" 3 "Mostly primary" 4 "Mostly upper primary" 5 "Not sure" 6 "Secondary only" 7 "Mostly secondary"
label values cls_taught ct
label define mt 1 "All subjects" 2 "Languages" 3 "Mathematics" 4 "Environment studies" 5 "Sports" 6 "Music" 7 "Science" 8 "Arts/Craft"
label values main_taught1 mt
label values main_taught2 mt
label values math_upto aq
label values eng_upto aq

* CAP TRAINING DAYS TO 365 DAYS
replace trn_brc=. if trn_brc>365
replace trn_crc=. if trn_crc>365
replace trn_diet=. if trn_diet>365
replace trn_other=. if trn_other>365

* CAP NON-TEACHING ASSIGNMENTS TO 365 DAYS
replace nontch_ass=. if nontch_ass>365

* CLEAN WORKING SINCE
* can't start in the future, allow since 1960
replace workingsince=. if workingsince>ac_year+1
replace workingsince=. if workingsince<1960

* STATE
gen state=floor(dist/100)
replace state=. if state==0

compress
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER_clean.dta,replace

*********************
* CLEAN KEYVAR FILE *
*********************
* Note: This file includes years 02-03, 03-04
* This file sets dubious schcd:s to missing
clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_KEYVAR.txt,delimiter(";")

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
replace ac_year="2004" if ac_year=="2004-05"
replace ac_year="2003" if ac_year=="2003-04"
replace ac_year="2002" if ac_year=="2002-03"
destring ac_year,replace

* FIX SCHCD AND DESTRING
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
drop schcd
rename schcd2 schcd
format schcd %14.0g

* VARIABLES DROPPED (pancd=not sure what/whether needed, phase=?, schstatus=all zero)
drop pancd phase schstatus
* I keep schname now

* MANAGEMENT/TYPE
replace schmgt=. if schmgt>6
replace schcat=. if schcat>5
replace schtype=. if schtype<1|schtype>3
replace rururb=. if rururb~=1 & rururb~=2
gen urban = rururb-1
drop rururb

* LOCATION CODES
* some non-numerics will become missing
destring clucd,replace force
format clucd %12.0g
destring blkcd,replace force 
destring vilcd,replace force
format vilcd %12.0g

* FIX ERRORS IN SCHOOLCODE
replace schcd=. if schcd<1000000000
replace schcd=. if schcd>40000000000
gen distcd2=floor(schcd/10000000)
gen blkcd2=floor(schcd/100000)
* The following applies in cases where schcd typically misses a number from the end
gen er=1 if ((distcd>distcd2)|(distcd<distcd2)) & distcd~=. & distcd2~=.
replace er=1 if ((blkcd>blkcd2)|(blkcd<blkcd2)) & blkcd~=. & blkcd2~=.
egen er2=mean(er),by(schcd)
replace schcd=. if er2==1
replace distcd=distcd2 if schcd~=.
replace blkcd=blkcd2 if schcd~=.
drop er er2 distcd2 blkcd2

* LABELS
label define mg 1 "Dept of Edu" 2 "Tribal/Social welfare dept" 3 "Local body" 4 "Private aided" 5 "Private Unaided" 6 "Others"
label values schmgt mg
label define cz 1 "Primary" 2 "Prim with upper prim" 3 "Prim with upper prim and sec/higher sec" 4 "Upper prim" 5 "Upper prim with sec/higher sec" 
label values schcat cz
label define gn 1 "Boys" 2 "Girls" 3 "Co-educational" 
label values schtype gn
label var schmgt "School management"
label var schcat "School category"
label var schtype "School gender"
label var clucd "Cluster code"
label var blkcd "Block code"
label var vilcd "Village code"
label var distcd "District code"
label var distname "District name"
label var schname "School name"

compress
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_KEYVAR_clean.dta,replace

***************************
* CLEAN CONSTITUENCY FILE *
***************************
clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_CONSTITUENCY.txt,delimiter(";")
*These all useless here 
drop blkcd vilcd chk_bit constvar3 constvar4 constvar5
* constvar1, constvar2 appear useless and take up space, so drop if become problem, but keep now.
label var constcd "Constituency code"
label var constname "Constituency name"
label var inityear "Constituency init. year (?)"
label var constvar1 "Constituency extra info 1"
label var constvar2 "Constituency extra info 2"
*count if constcd==constcd[_n-1] & inityear~=inityear[_n-1]
* The above gives zero which is nice.
*NOTE: Before destringing, see what to do with leading zeros. 
*They matter for the determination of the state, and the lenth of the variable is not constant.
sort constcd
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_CONSTITUENCY_clean.dta,replace

*********************
* CLEAN MASTER FILE *
*********************
clear
set memory 9g
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_MASTER.txt,delimiter(";")

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
destring ac_year,replace

compress
* FIX SCHCD AND DESTRING
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
drop schcd
rename schcd2 schcd
format schcd %14.0g

* VARIABLES DROPPED 
*pincd=mostly missing, pp*=not interested in pre-primary, workdays=hardly informative, 
*schres_yn & resitype, schshi_yn = not interesting, supvar?=not useful, edublkcd,habitcd,aconstcd,municipalcd,city = not useful
* schstatus=all zero
drop pincd ppsec_yn ppstudent ppteacher workdays schres_yn resitype schshi_yn supvar? edublkcd habitcd municipalcd city schstatus

* RENAME CONSTITUENCY TO MATCH THE NAMEFILE
rename aconstcd constcd
* Constcd data in earlier years mostly missing. Don't use
replace constcd="" if ac_year<2010
* do not destring it yet

* YEAR OF ESTABLISHMENT [NOTE: FAIRLY UNCERTAIN VARIABLE]
* Set to missing if larger than the earliest observer academic year
* Set to missing if <1800
egen myr=min(ac_year),by(schcd)
replace estdyear=. if estdyear>myr+1
replace estdyear=. if estdyear<1800
egen sde=sd(estdyear),by(schcd)
count if sde==0
count if sde>0
* Note: significant uncertainty about establishment year. 1/3 of schools have variation.
* take mode, max if ambiguous
egen mde=mode(estdyear),by(schcd) maxmode
replace estdyear=mde
replace estdyear=. if schcd==.
drop myr sde mde

* LOWEST & HIGHEST CLASS
* This should be cleaned with the help of variable schcat from KEYVAR
* I wonder if high/low class refer to current high or low (and may thus vary)
* in that case it could be confirmed from year-specific pupil numbers
replace lowclass=. if lowclass<1|lowclass>9
replace highclass=. if highclass<1|lowclass>12
count if highclass<lowclass
* very few freak cases..

* VISITS & INSPECTIONS
* For inspections, a natural cutoff appears to be 12 and for visits, 25
replace noinspect=. if noinspect>12|noinspect<0
replace visitscrc=. if visitscrc>25|visitscrc<0
replace visitsbrc=. if visitsbrc>25|visitsbrc<0

* FUNDING VARIABLES
* replace 999999 with missing to start with
foreach var of varlist *_? {
replace `var'=. if `var'==999999
}

* TEACHERS
replace tchsan=. if tchsan<0
replace tchpos=. if tchpos<0
replace parapos=. if parapos<0
replace ntpos=. if ntpos<0
ge tch=parapos+tchpos

* LANGUAGE (MEDIUM) OF INSTRUCTION
foreach var of varlist medinstr? {
replace `var'= . if `var'==0|`var'>32
replace `var'=30 if `var'>29 & `var'<=32.
}

* LABELS
label var constcd "Constituency code (2009-10 onwards only)"
label var disthq "Distance to Block HQ (km)"
label var distcrc "Distance to Cluster Resource Centre (km)"
label var estdyear "Year established"
label var lowclass "Lowest class"
label var highclass "Highest class"
label var noinspect "# of academic inspections"
label var visitscrc "# of visits by CRC coordinators"
label var visitsbrc "# of visits by BRC coordinators"
label var conti_r "School Dev Grant (DPEP/SSA) Receipts"
label var conti_e "School Dev Grant (DPEP/SSA) Expend."
label var tlm_r "TLM Grant (DPEP/SSA) Receipts"
label var tlm_e "TLM Grant (DPEP/SSA) Expend."
label var funds_r "Funds collected from Students Receipts"
label var funds_e "Funds collected from Students Expend."
label var osrc_r "Funds from Other SouRCes Receipts"
label var osrc_e "Funds from Other SouRCes Expend."
label var schmntcgrant_r "SCH MaiNTenanCe GRAnt (DPEP/SSA) Receipts"
label var schmntcgrant_e "SCH MaiNTenanCe GRAnt (DPEP/SSA) Expend."
label var tle_r "TLE Grant (DPEP/SSA) Receipts"
label var tle_e "TLE Grant (DPEP/SSA) Expend."
label var tchsan "# Sanctioned teachers (prim+up.prim)"
label var tchpos "# Teachers in position (prim+up.prim)"
label var parapos "# Parateacher/Shiksha karmi/Guruji/Comm.teacher (prim+up.prim)"
label var ntpos "# Non-teaching staff (prim+up.prim)"
label var tch "Teachers in position + parateachers"
label define ln 1 "Assamese" 2 "Bengali" 3 "Gujarati" 4 "Hindi" 5 "Kannada" 6 "Kashmiri" 7 "Konkani" 8 "Malayalam" 9 "Manipuri" 10 "Marathi" 11 "Nepali" 12 "Oriya" 13 "Punjabi" 14 "Sanskrit" 15 "Sindhi" 16 "Tamil" 17 "Telugu" 18 "Urdu" 19 "English" 20 "Bodo" 21 "Mising" 22 "Dogri" 23 "Khasi" 24 "Garo" 25 "Mizo" 26 "Bhutia" 27 "Lepcha" 28 "Limboo" 29 "French" 30 "Other" 
label values medinstr1 ln
label values medinstr2 ln
label values medinstr3 ln
label values medinstr4 ln
label var medinstr1 "Medium of Instruction #1"

* MERGE CONSTITUENCY NAME IN
sort constcd
merge constcd using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_CONSTITUENCY_clean.dta
tab _merge if constcd~="" & ac_year==2010
* 93% merge
* probably variation by state
drop if _merge==2
drop _merge

compress
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_MASTER_clean.dta,replace



************************
* CLEAN ENROLMENT FILE *
************************
clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_ENROLMENT.txt,delimiter(";")

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
destring ac_year,replace

* FIX SCHCD AND DESTRING
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
drop schcd
rename schcd2 schcd
format schcd %14.0g

* ENROLMENT BY SCHOOL YEAR
* The number of missing seratively low, let it be
* Some numbers are really large: fix later when the number of teachers also known.
foreach num of numlist 1/8 {
* Total enrolment by class
gen enr`num' = c`num'_gb+c`num'_gg+c`num'_cb+c`num'_cg+c`num'_tb+c`num'_tg+c`num'_ob+c`num'_og+c`num'_oth1b+c`num'_oth1g+c`num'_oth2b+c`num'_oth2g+c`num'_oth3b+c`num'_oth3g
* Low castes (I don't consider the 'other' categories to be low caste)
gen enr`num'c = c`num'_cb+c`num'_cg+c`num'_tb+c`num'_tg+c`num'_ob+c`num'_og
* Girls
gen enr`num'g = c`num'_gg+c`num'_cg+c`num'_tg+c`num'_og+c`num'_oth1g+c`num'_oth2g+c`num'_oth3g
}


* TOTALS
gen enrtot=enr1+enr2+enr3+enr4+enr5+enr6+enr7+enr8
gen enrtot15=enr1+enr2+enr3+enr4+enr5
gen enrtotc=enr1c+enr2c+enr3c+enr4c+enr5c+enr6c+enr7c+enr8c
gen enrtotg=enr1g+enr2g+enr3g+enr4g+enr5g+enr6g+enr7g+enr8g
gen enrtot15g=enr1g+enr2g+enr3g+enr4g+enr5g
gen enr_g=enrtotg/enrtot
gen enr_15g=enrtot15g/enrtot
gen enr_c=enrtotc/enrtot

* LABELS
label var enr1 "Enrolment in grade 1"
label var enr1c "Enrolment in grade 1, SC-ST-OB"
label var enr1g "Enrolment in grade 1, girls"
label var enrtot "Total enrolment, grades 1-8"
label var enrtot15 "Total enrolment, grades 1-5"
label var enrtotg "Total enrolment, girls, grades 1-8"
label var enrtot15g "Total enrolment, girls, grades 1-5"
label var enrtotc "Total enrolment, SC-ST-OB, grades 1-8"
label var enr_g "% Girls, grades 1-8"
label var enr_15g "% Girls, grades 1-5"
label var enr_c "% SC-ST-OB, grades 1-8"

compress
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_ENROLMENT_clean.dta,replace

*************************
* CLEAN EXAMRESULT FILE *
*************************
* PROBLEM: MOST SCHOOLS DONT HAVE DATA FOR 2012-13 - WHY? (I May not need it though)
clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_EXAMRESULT.txt,delimiter(";")

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
destring ac_year,replace

* FIX SCHCD AND DESTRING
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
drop schcd
rename schcd2 schcd
format schcd %14.0g

* ENROLMENTS
gen c5enr=c5_enrolb+c5_enrolg
gen c7enr=c7_enrolb+c7_enrolg

* 4/5TH GRADE: % TAKING EXAM, % GIRLS,  %PASS & % >60
gen c5exam=(c5_appearb+c5_appearg)/(c5_enrolb+c5_enrolg)
gen c5girl=c5_enrolg/(c5_enrolb+c5_enrolg)
gen c5pass=(c5_passb+c5_passg)/(c5_appearb+c5_appearg)
gen c5m60=(c5_m60b+c5_m60g)/(c5_appearb+c5_appearg)

* 7/8TH GRADE: % TAKING EXAM, % GIRLS,  %PASS & % >60
gen c7exam=(c7_appearb+c7_appearg)/(c7_enrolb+c7_enrolg)
gen c7girl=c7_enrolg/(c7_enrolb+c7_enrolg)
gen c7pass=(c7_passb+c7_passg)/(c7_appearb+c7_appearg)
gen c7m60=(c7_m60b+c7_m60g)/(c7_appearb+c7_appearg)

* REMOVE OUTLIERS.
* Perhaps exam takers CAN be higher than enrolled, if coming from private schools?
* but if pass rate or >60% is more than 100% or larger than pass rate, it should be a concern
gen ol=.
replace ol=1 if c5m60>1 & c5m60~=. 
replace ol=1 if c5pass>1 & c5pass~=.
replace ol=1 if c5m60>c5pass & c5m60~=. & c5pass~=.
count if c5exam>1 & c5exam~=.
* 30k+ - quite a lot. Remove top 50%, the cutoff is 1.42
su c5exam if c5exam>1,d
replace ol=1 if c5exam>r(p50) & c5exam~=.
* View by year
tab ol ac_year,mi
* set missing to all 3 variables is outliers
replace c5exam=. if ol==1
replace c5pass=. if ol==1
replace c5m60=. if ol==1
drop ol

* Same for 7/8 grade
gen ol=.
replace ol=1 if c7m60>1 & c7m60~=. 
replace ol=1 if c7pass>1 & c7pass~=.
replace ol=1 if c7m60>c7pass & c7m60~=. & c7pass~=.
count if c7exam>1 & c7exam~=.
* 18000 - quite a lot. Remove top 50%, the cutoff is 1.28
su c7exam if c7exam>1,d
replace ol=1 if c7exam>r(p50) & c7exam~=.
* View by year
tab ol ac_year,mi
* set missing to all 3 variables is outliers
replace c7exam=. if ol==1
replace c7pass=. if ol==1
replace c7m60=. if ol==1
drop ol

* LABELS
label var c5enr "Enrolment, cl. 4/5, last acad.yr."
label var c7enr "Enrolment, cl. 4/5, last acad.yr."
label var c5exam "% Examined, cl. 4/5, last acad.yr."
label var c5girl "% Girls, cl. 4/5, last acad.yr."
label var c5pass "%Passed, cl. 4/5, last acad.yr."
label var c5m60 "% >60%, cl. 4/5, last acad.yr."
label var c7exam "% Examined, cl. 4/5, last acad.yr."
label var c7girl "% Girls, cl. 7/8, last acad.yr."
label var c7pass "%Passed, cl. 7/8, last acad.yr."
label var c7m60 "% >60%, cl. 7/8, last acad.yr."

* DROP THOSE NOT NEEDED
drop c5_enrolb-c7_m60g checkbit

compress
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_EXAMRESULT_clean.dta,replace

*********************
* CLEAN BLDEQP FILE *
*********************

clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_BLDEQP.txt,delimiter(";")

* DROP SUPPLEMENTARY VARIABLES (TAKE UP MOST OF SPACE, AND APPEAR USELESS)
drop supvar*

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
destring ac_year,replace


* FIX SCHCD AND DESTRING
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
drop schcd
rename schcd2 schcd
format schcd %14.0g

* EXISTANCE OF BUILDING 
* Don't know what 9-15 are in bldstatus, more common in 2008-09 data
gen bld_none = bldstatus == 5
drop bldstatus
* NOTE: most schools with no building state they have classrooms in question below.

* CONDITION OF CLASSROOMS
* Peeking the data suggests that missings should be zero
replace clgood=0 if clgood==.
replace clmajor=0 if clmajor==.
replace clminor=0 if clminor==.
gen clrooms2=clgood+clmajor+clminor
compare clrooms clrooms2
* Cases of miscoding: 
* (1) clrooms set to 0, others filled, suggesting clrooms was ignored
* (2) clsrooms positive, other zero (or ignored)
count if clrooms==0 & clrooms2~=0
count if clrooms~=0 & clrooms2==0
count if clrooms==0 & clrooms2==0
* Create %major %minor using clrooms2, and dummy for no info, for case 2
gen bld_crmaj=clmajor/clrooms2
gen bld_crmin=clminor/clrooms2
replace bld_crmaj=0 if clrooms2==0
replace bld_crmin=0 if clrooms2==0
gen bld_crna= clrooms2==0
* Number of classrooms from clrooms2, or clrooms if clrooms2=0
gen bld_crn=clrooms2
replace bld_crn=clrooms if clrooms~=0 & clrooms2==0
* Dummy for no rooms at all
gen bld_crn0= bld_crn==0
drop clrooms clrooms2 clgood clmajor clminor

* CONDITION OF OTHER ROOMS
* As above, set missings to zero
replace othgood=0 if othgood==.
replace othminor=0 if othminor==.
replace othmajor=0 if othmajor==.
gen bld_otn=othgood+othminor+othmajor
gen bld_otmaj=othmajor/bld_otn
gen bld_otmin=othminor/bld_otn
replace bld_otmaj=0 if bld_otn==0
replace bld_otmin=0 if bld_otn==0
gen bld_otna = bld_otn==0
drop othgood othmajor othminor

* TOILETS, ELECTRICITY, BOUNDARY WALL, BOOKBANK, DRAWERS, BOXES
* coding changes from 2008 onwards. No missings from 2009, so set NA to zero prior to 2009
* Common toilet declines from 2008 - must mean boys' toilet? -> Don't use it
replace toilet_c=0 if toilet_c~=1 & ac_year<=2008
replace toilet_c=1 if toilet_c>1 & ac_year>2008 
replace toilet_g=0 if toilet_g~=1 & ac_year<=2008
replace toilet_g=1 if toilet_g>1 & ac_year>2008 
rename toilet_c bld_wc
rename toilet_g bld_wcg
replace electric_yn=0 if electric_yn==2
replace electric_yn=. if electric_yn>1
rename electric_yn bld_elec
* in bndrywall, values 7,9,10 are unknown.. set to missing
gen bld_wall=0 if bndrywall==5
replace bld_wall=1 if (bndrywall>=1 & bndrywall<=4)|bndrywall==6
drop bndrywall
gen bld_bookb=1 if bookbank_yn==1
replace bld_bookb=0 if bookbank_yn==2
drop bookbank_yn
gen bld_playg=1 if pground_yn==1
replace bld_playg=0 if pground_yn==2
drop pground_yn
* new var "more than 0.5 blackboards per class room" (otherwise will have outlier problem)
replace blackboard=blackboard/bld_crn
replace blackboard=0 if bld_crn==0
gen bld_bboard=1 if blackboard>=0.5 & blackboard~=.
replace bld_bboard=0 if blackboard<0.5
drop blackboard
* new var "more than 0.5 drawers per room (any room)" (otherwise will have outlier problem)
replace almirah=almirah/(bld_crn+bld_otn)
replace almirah=0 if bld_crn==0 & bld_otn==0
gen bld_cabin=1 if almirah>=0.5 & almirah~=.
replace bld_cabin=0 if almirah<0.5
drop almirah
* new var "more than 0.5 boxes per room (any room)" (otherwise will have outlier problem)
replace box=box/(bld_crn+bld_otn)
replace box=0 if bld_crn==0 & bld_otn==0
gen bld_box=1 if box>=0.5 & box~=.
replace bld_box=0 if box<0.5
drop box

* LIBRABY BOOKS, WATER, MEDICAL CHECKS, RAMPS, COMPUTERS
* leave is as it is and relate later to pupil number
rename bookinlib bld_lib
gen bld_wathp = water==1
gen bld_watwe = water==2
gen bld_watta = water==3
gen bld_watot = water==4
gen bld_watno = water==5
foreach var of varlist bld_wat?? {
replace `var'=. if water>5
}
drop water
gen bld_medic=1 if medchk_yn==1
replace bld_medic=0 if medchk_yn==2
drop medchk_yn
gen bld_ramp=1 if ramps_yn==1
replace bld_ramp=0 if ramps_yn==2
drop ramps_yn
* relate # of computers to pupils later
rename computer bld_comp

* BUILDING QUALITY, ANANDCLASS(?), FURNITURE
* Assume that if some points filled, missing implies zero
* some negative values for roomstent, set to missing
* Only use classrooms, compute percentages in each category & total number of classrooms.
replace roomstent=. if roomstent<0
egen resp=rownonmiss(bldpucca bldppucca bldkuccha bldtent clspucca clsppucca clskuccha clstent roomspucca roomsppucca roomskuccha roomstent)
foreach var of varlist bldpucca bldppucca bldkuccha bldtent clspucca clsppucca clskuccha clstent roomspucca roomsppucca roomskuccha roomstent {
replace `var'=0 if `var'==. & resp>0 & resp~=.
}
gen bld_qn=clspucca+clsppucca+clskuccha+clstent
gen bld_qpucca=clspucca/bld_qn
gen bld_qppucca=clsppucca/bld_qn
gen bld_qkuccha=clskuccha/bld_qn
gen bld_qtent=clstent/bld_qn
drop resp bldpucca bldppucca bldkuccha bldtent clspucca clsppucca clskuccha clstent roomspucca roomsppucca roomskuccha roomstent
* drop anandclass - not known what it is 
* drop checkbit
* Drop furniture & kitshed - collected after 2006, and still too much missings
drop anandclass checkbit furntch furnstu kitshed


* LABELS
label var bld_none "No school building"
label var bld_crmaj "% classrooms needing major repair"
label var bld_crmin "% classrooms needing minor repair"
label var bld_crna "Classroom condition NA"
label var bld_crn "Number of classrooms"
label var bld_crn0 "Number of classrooms = 0"
label var bld_otn "Number of other rooms"
*label var bld_crna "Number of rooms = 0 / Condition NA"
label var bld_otmaj "% other rooms needing major repair"
label var bld_otmin "% other rooms needing minor repair"
label var bld_wc "Toilet, common (don't use - inconsistent?)"
label var bld_wcg "Toilet, girls"
label var bld_elec "Building has electricity"
label var bld_wall "School has a boundary wall"
label var bld_bookb "School has a book bank"
label var bld_playg "School has a playground"
label var bld_bboard "School has >=0.5 blackboards per classroom"
label var bld_cabin "School has >=0.5 filing cabinets per room"
label var bld_box "School has >=0.5 boxes per room"
label var bld_lib "Number of books in school library"
label var bld_wathp "Water: Handpump"
label var bld_watwe "Water: Well"
label var bld_watta "Water: Tap"
label var bld_watot "Water: Other"
label var bld_watno "Water: None"
label var bld_medic "Medical checks last year"
label var bld_ramp "Ramps for disabled"
label var bld_comp "Number of computers"
label var bld_qn "Classroom Quality: Number of rooms"
label var bld_qpucca "Classroom Quality: % Pucca"
label var bld_qppucca "Classroom Quality: % Partially Pucca"
label var bld_qkuccha "Classroom Quality: % Kuccha"
label var bld_qtent "Classroom Quality: % Tent"

compress
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_BLDEQP_clean.dta,replace


*************************
* CLEAN INCENTIVES FILE *
*************************
* 2012 Lacks data 
*NOTE: The file used is just for primary, not upper primary schools
clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_PINCENTIVES.txt,delimiter(";")

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
destring ac_year,replace

* FIX SCHCD AND DESTRING
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
drop schcd
rename schcd2 schcd
format schcd %14.0g

* TEXTBOOKS, STATIONARY, UNIFORMS, ATTENDANCE SCHOLARSHIPS
* Textbooks: Do total number, then % going to girls and % going to castes
egen resp=rownonmiss(text_ab text_ag text_cb text_cg text_tb text_tg text_ob text_og)
* Only few schools in which some missing even if responded - set to zero
foreach var of varlist text_ab text_ag text_cb text_cg text_tb text_tg text_ob text_og {
replace `var'=0 if `var'==. & resp>0 & resp<8
}
drop resp
* Clearly ab and ag are not 'all', but refers to the general caste (also apparent in the form).
gen inc_txt=text_ab+text_ag+text_cb+text_cg+text_tb+text_tg+text_ob+text_og
gen inc_txt0= inc_txt == 0
replace inc_txt0=. if inc_txt==.
gen inc_txtg=(text_ag+text_cg+text_tg+text_og)/inc_txt
replace inc_txtg=0 if inc_txt==0
gen inc_txtc=(text_cb+text_cg+text_tb+text_tg+text_ob+text_og)/inc_txt
replace inc_txtc=0 if inc_txt==0
gen inc_txtab=text_ab/inc_txt
replace inc_txtab=0 if inc_txt==0
drop text_??
* Stationary: Do total number, then % going to girls and % going to castes
egen resp=rownonmiss(station_ab station_ag station_cb station_cg station_tb station_tg station_ob station_og)
* Only 1 school in which some missing even if responded - set to zero
foreach var of varlist station_ab station_ag station_cb station_cg station_tb station_tg station_ob station_og {
replace `var'=0 if `var'==. & resp>0 & resp<8
}
drop resp
gen inc_sta=station_ab+station_ag+station_cb+station_cg+station_tb+station_tg+station_ob+station_og
gen inc_sta0= inc_sta == 0
replace inc_sta0=. if inc_sta==.
gen inc_stag=(station_ag+station_cg+station_tg+station_og)/inc_sta
replace inc_stag=0 if inc_sta==0
gen inc_stac=(station_cb+station_cg+station_tb+station_tg+station_ob+station_og)/inc_sta
replace inc_stac=0 if inc_sta==0
gen inc_staab=station_ab/inc_sta
replace inc_staab=0 if inc_sta==0
drop station_??
* Uniforms: Do total number, then % going to girls and % going to castes
egen resp=rownonmiss(uniform_ab uniform_ag uniform_cb uniform_cg uniform_tb uniform_tg uniform_ob uniform_og)
* Only 4 schools in which some missing even if responded - set to zero
foreach var of varlist uniform_ab uniform_ag uniform_cb uniform_cg uniform_tb uniform_tg uniform_ob uniform_og {
replace `var'=0 if `var'==. & resp>0 & resp<8
}
drop resp
gen inc_uni=uniform_ab+uniform_ag+uniform_cb+uniform_cg+uniform_tb+uniform_tg+uniform_ob+uniform_og
gen inc_uni0= inc_uni == 0
replace inc_uni0=. if inc_uni==.
gen inc_unig=(uniform_ag+uniform_cg+uniform_tg+uniform_og)/inc_uni
replace inc_unig=0 if inc_uni==0
gen inc_unic=(uniform_cb+uniform_cg+uniform_tb+uniform_tg+uniform_ob+uniform_og)/inc_uni
replace inc_unic=0 if inc_uni==0
gen inc_uniab=uniform_ab/inc_uni
replace inc_uniab=0 if inc_uni==0
drop uniform_??
* Scholarships: Do total number, then % going to girls and % going to castes
egen resp=rownonmiss(attend_ab attend_ag attend_cb attend_cg attend_tb attend_tg attend_ob attend_og)
* Only 9 schools in which some missing even if responded - set to zero
foreach var of varlist attend_ab attend_ag attend_cb attend_cg attend_tb attend_tg attend_ob attend_og {
replace `var'=0 if `var'==. & resp>0 & resp<8
}
drop resp
gen inc_sco=attend_ab+attend_ag+attend_cb+attend_cg+attend_tb+attend_tg+attend_ob+attend_og
gen inc_sco0= inc_sco == 0
replace inc_sco0=. if inc_sco==.
gen inc_scog=(attend_ag+attend_cg+attend_tg+attend_og)/inc_sco
replace inc_scog=0 if inc_sco==0
gen inc_scoc=(attend_cb+attend_cg+attend_tb+attend_tg+attend_ob+attend_og)/inc_sco
replace inc_scoc=0 if inc_sco==0
gen inc_scoab=attend_ab/inc_sco
replace inc_scoab=0 if inc_sco==0
drop attend_??

* OTHER INCENTIVES
* Just drop because not sure what they are.
drop oth?_?? checkbit

* LABELS
label var inc_txt "# Free text books last year"
label var inc_txt0 "No free text books last year"
label var inc_txtg "% of free text books to girls, last year"
label var inc_txtc "% of free text books to SC-ST-OB, last year"
label var inc_txtab "% of free text books to General caste boys, last year"
label var inc_sta "# Free stationary last year"
label var inc_sta0 "No free stationary last year"
label var inc_stag "% of free stationary to girls, last year"
label var inc_stac "% of free stationary to SC-ST-OB, last year"
label var inc_staab "% of free stationary to General caste boys, last year"
label var inc_uni "# Free uniforms last year"
label var inc_uni0 "No free uniforms last year"
label var inc_unig "% of free uniforms to girls, last year"
label var inc_unic "% of free uniforms to SC-ST-OB, last year"
label var inc_uniab "% of free uniforms to General caste boys, last year"
label var inc_sco "# Attendance scholarhips last year"
label var inc_sco0 "No scholarhips last year"
label var inc_scog "% of scholarhips to girls, last year"
label var inc_scoc "% of scholarhips to SC-ST-OB, last year"
label var inc_scoab "% of scholarhips to General caste boys, last year"

compress
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_PINCENTIVES_clean.dta,replace

************************
* CLEAN REPEATERS FILE *
************************
* 2012 data missing
clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_REPEATERS.txt,delimiter(";")

* DESTRING AC_YEAR
replace ac_year="2012" if ac_year=="2012-13"
replace ac_year="2011" if ac_year=="2011-12"
replace ac_year="2010" if ac_year=="2010-11"
replace ac_year="2009" if ac_year=="2009-10"
replace ac_year="2008" if ac_year=="2008-09"
replace ac_year="2007" if ac_year=="2007-08"
replace ac_year="2006" if ac_year=="2006-07"
replace ac_year="2005" if ac_year=="2005-06"
replace ac_year="2002" if ac_year=="2002-03"
destring ac_year,replace

* FIX SCHCD AND DESTRING
gen schcd2=subinstr(schcd,"O","0",.)
* force option generates missing if further problems
destring schcd2, force replace
drop schcd
rename schcd2 schcd
format schcd %14.0g

* FAILURES, LONG ABSENCES, READMISSIONS
* count the number per yeargroup, don't separate by gender.
* assume missing=zero if some responses
egen resp=rownonmiss(c1_failb c1_failg c2_failb c2_failg c3_failb c3_failg c4_failb c4_failg c5_failb c5_failg c6_failb c6_failg c7_failb c7_failg c8_failb c8_failg)
foreach var of varlist c1_failb c1_failg c2_failb c2_failg c3_failb c3_failg c4_failb c4_failg c5_failb c5_failg c6_failb c6_failg c7_failb c7_failg c8_failb c8_failg {
replace `var'=0 if `var'==. & resp>0 & resp<16
}
drop resp
foreach num of numlist 1/8 {
gen c`num'_fail=c`num'_failb+c`num'_failg
}
drop c?_fail?
* long absences
egen resp=rownonmiss(c1_absb c1_absg c2_absb c2_absg c3_absb c3_absg c4_absb c4_absg c5_absb c5_absg c6_absb c6_absg c7_absb c7_absg c8_absb c8_absg)
foreach var of varlist c1_absb c1_absg c2_absb c2_absg c3_absb c3_absg c4_absb c4_absg c5_absb c5_absg c6_absb c6_absg c7_absb c7_absg c8_absb c8_absg {
replace `var'=0 if `var'==. & resp>0 & resp<16
}
drop resp
foreach num of numlist 1/8 {
gen c`num'_abs=c`num'_absb+c`num'_absg
}
drop c?_abs?
* Readmissions
egen resp=rownonmiss(c1_readb c1_readg c2_readb c2_readg c3_readb c3_readg c4_readb c4_readg c5_readb c5_readg c6_readb c6_readg c7_readb c7_readg c8_readb c8_readg)
foreach var of varlist c1_readb c1_readg c2_readb c2_readg c3_readb c3_readg c4_readb c4_readg c5_readb c5_readg c6_readb c6_readg c7_readb c7_readg c8_readb c8_readg {
replace `var'=0 if `var'==. & resp>0 & resp<16
}
drop resp
foreach num of numlist 1/8 {
gen c`num'_read=c`num'_readb+c`num'_readg
}
drop c?_read?
drop checkbit

compress
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_REPEATERS_clean.dta,replace


********************
* CLEAN BLOCK FILE *
********************

clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_BLOCK.txt,delimiter(";")
keep blkcd blkname
compress
sort blkcd
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_BLOCK_clean.dta,replace

************************
* CLEAN PANCHAYAT FILE *
************************

clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_PANCHAYAT.txt,delimiter(";")
keep pancd panname blkcd
destring pancd,replace force
destring blkcd,replace force
compress
sort pancd
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_PANCHAYAT_clean.dta,replace

************************
* CLEAN VILLAGE FILE *
************************

clear
insheet using /tera1/DISE_Dec13/DISE_full_csv_Dec13/STEPS_VILLAGE.txt,delimiter(";")
keep vilcd vilname
destring vilcd,replace force
compress
sort vilcd
save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_VILLAGE_clean.dta,replace

exit








