* This documents district splits within indian states, 
* Includes code for returning districts to 2005 partition if needed 
* Problem with returning to 2005 partition is that merging other dataset may create issues (ASER/Election results)

* OUTPUT: STEPS_TEACHER_clean_fix.dta

* IMPORTANTLY: generates an 'exclude' flag for districts with district/block splits

*******************************************************************
* FIX DISTRICT, SCHOOL and BLOCK CODES TO 2005 DISTRICT PARTITION *
*******************************************************************
* Ignore cluster and village codes (can be added later if needed)

clear
set memory 8g
use /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER_clean.dta

drop slno

* Merge in District names
sort schcd ac_year
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_KEYVAR_clean.dta,nokeep keep(distname distcd blkcd)
drop _merge

* FIX ERRORS IN SCHOOLCODE
replace schcd=. if schcd<1000000000
replace schcd=. if schcd>40000000000
gen distcd2=floor(schcd/10000000)
gen blkcd2=floor(schcd/100000)
* The following applies in cases where schcd typically misses a number from the end
gen er=1 if ((distcd>distcd2)|(distcd<distcd2)) & distcd~=. & distcd2~=.
replace er=1 if ((blkcd>blkcd2)|(blkcd<blkcd2)) & blkcd~=. & blkcd2~=.
egen er2=mean(er),by(schcd)
replace schcd=. if er2==1
replace distcd=distcd2 if schcd~=.
replace blkcd=blkcd2 if schcd~=.
drop er er2 distcd2 blkcd2

* To inspect:
*tab distname ac_year if state==X
*tab distcd ac_year if state==X

gen byte splitter=.
replace distname=trim(distname)

*** JAMMU *** 
*tab distcd ac_year if state==1
*tab distname ac_year if state==1
* appears 115-122 may be new splitters in 2006->2007
*
*115 SHOPIAN
*116 BANDIPORA (from BARAMULA 102)
*117 KISHTWAR
*118 RAMBAN
*119 GANDERBAL (from SRINAGAR 103)
*120 KULGAM
*121 REASI (from UDHAMPUR 110)
*122 SAMBA (from JAMMU 113)
* make the whole state "splitter"
replace splitter=1 if distcd>=115 & distcd<=122
* The next line is a quess based on jumps in number of schools
replace splitter=1 if distcd==102|distcd==103|distcd==105|distcd==106|distcd==109|distcd==110|distcd==113

*** PUNJAB *** OK
replace distname="FIROZPUR" if distname=="FEROZEPUR" & state==3
replace distname="RUPNAGAR" if distname=="ROPAR" & state==3
replace distname="FAZILKA" if distname=="Fazilka" & state==3
* 318 MOHALI (from ROPAR 307)
* 319 TARAN TARAN (from AMRITSAR 302)
* 320 BARNALA (from SANGRUR 316)
* 321 FAZILKA (from FIROZPUR 311) [new]
* 322 PATHANKOT (from GURDASPUR 301) [new]
replace splitter=1 if distcd==318|distcd==319|distcd==320|distcd==321|distcd==322|distcd==301|distcd==302|distcd==307|distcd==311|distcd==316

*** CHANDIGARH (4) *** OK
replace distname="CHANDIGARH (U.T.)" if distname=="CHANDIGARH" 

*** UTTARAKHAND (5) *** OK
replace distname="GARHWAL" if distname=="PAURI GARHWAL" & state==5

*** HARYANA (6) *** OK
*620 MEWAT (from FARIDABAD 619 and GURGAON 618)
*621 PALWAL (from FARIDABAD 619)
replace splitter=1 if distcd==621|distcd==620|distcd==619|distcd==618

* Ignore DELHI (7) 

*** RAJASTHAN (8)*** OK 
replace distname="PRATAPGARH(RAJ.)" if distname=="PRATAPGARH(RAJASTHAN)"|distname=="PRATAPGARH (RAJ.)"
replace distname="DAUSA" if distname=="Dausa" & state==8
*833 PRATAPGARH (from Chittorgarh 829, Udaipur 826 and Banswara 828)
replace splitter=1 if distcd==833|distcd==829|distcd==826|distcd==828

*** UTTAR PRADESH (9) *** OK
replace distname="HAMIRPUR (U.P.)" if distname=="HAMIRPUR" & state==9
replace distname="BHADOI" if distname=="BHADOHI" & state==9
replace distname="SULTANPUR" if distname=="Sultanpur" & state==9
replace distname="KASHIRAM NAGAR" if distname=="KANSHIRAM NAGAR" & state==9
replace distname="AMETHI - CSM NAGAR" if distname=="CSMAHARAJ NAGAR" & state==9
replace distname="SHAMLI" if distname=="SHAMLI (PRABUDH NAGAR" & state==9
replace distname="HAPUR" if distname=="HAPUR (PANCHSHEEL NAG" & state==9
replace distname="SAMBHAL" if distname=="SAMBHAL (BHIM NAGAR)" & state==9
*972 KASHIRAM NAGAR (from ETAH 917)
*968 SAMBHAL (from MORADABAD 904) [new]
*973 AMETHI - CSM NAGAR (from SULTANPUR 949) [new]
*974 SHAMLI (from MUZAFFARNAGAR 902) [new]
*975 HAPUR (from GHAZIABAD 909) [new]
replace splitter=1 if distcd==968|distcd==972|distcd==973|distcd==974|distcd==975|distcd==902|distcd==904|distcd==909|distcd==917|distcd==949

*** BIHAR (10) OK
* 1039 ARWAL (from JEHANABAD 1033) 
replace splitter=1 if distcd==1033|distcd==1039

*** ARUNACHAL PRADESH (12) *** OK
replace distname="ANJAW" if distname=="Anjaw" & state==12
*1216 ANJAW (from LOHIT 1211)
replace splitter=1 if distcd==1216|distcd==1211

*** NAGALAND (13) *** OK
replace distname="KIPHERE" if distname=="KIPHIRE" & state==13
*1309 KIPHERE (from TUENSANG 1302)
*1310 LONGLENG (from TUENSANG 1302)
*1311 PEREN (from KOHIMA 1307)
replace splitter=1 if distcd==1309|distcd==1310|distcd==1311|distcd==1302|distcd==1307

*** TRIPURA (16) *** 
replace distname="NORTH TRIPURA" if distname=="NORTH" & state==16
replace distname="SOUTH TRIPURA" if distname=="SOUTH" & state==16
replace distname="WEST TRIPURA" if distname=="WEST" & state==16
*1605 SEPAHIJALA (from WEST TRIPURA 1601) [new]
*1606 KHOWAI (from WEST TRIPURA 1601) [new]
*1607 GOMATI (from SOUTH TRIPURA 1602) [new]
*1608 UNAKOTI (from NORTH TRIPURA 1604) [new]
replace splitter=1 if distcd==1601|distcd==1602|distcd==1604|distcd==1605|distcd==1606|distcd==1607|distcd==1608

*** ASSAM (18) ***
replace distname="DIMA HASAO" if distname=="NORTH CACHAR HILLS" & state==18
replace distname="KAMRUP-RURAL" if distname=="KAMRUP" & state==18
*1824 BAKSA (from BARPETA 1805, NALBARI 1807, and KAMRUP 1806) [new]
*1825 CHIRANG (from BONGAIGAON 1804) [new]
*1826 UDALGURI (from DARRANG 1808) [new]
*1827 KAMRUP-METRO (from KAMRUP [now KAMRUP-RURAL] 1806) [new]
replace splitter=1 if distcd==1804|distcd==1805|distcd==1806|distcd==1807|distcd==1808|distcd==1824|distcd==1825|distcd==1826|distcd==1827

*** JHARKAND (20) *** OK
*2023 KHUNTI (from RANCHI 2014)
*2024 RAMGARH (from HAZARIBAG 2004)
replace splitter=1 if distcd==2023|distcd==2024|distcd==2014|distcd==2004

*** ORISSA (21) *** OK
replace distname="ANGUL" if distname=="ANUGUL" & state==21
replace distname="BOLANGIR" if distname=="BALANGIR" & state==21
replace distname="DEOGARH" if distname=="DEBAGARH" & state==21
replace distname="JAJPUR" if distname=="JAJAPUR" & state==21
replace distname="KEONJHAR" if distname=="KENDUJHAR" & state==21
replace distname="SONEPUR" if distname=="SONAPUR" & state==21
replace distname="BOUDH" if distname=="BAUDH" & state==21
replace distname="BALASORE" if distname=="BALESHWAR" & state==21
replace distname="JAGATSINGHPUR" if distname=="JAGATSINGHAPUR" & state==21
replace distname="MAYURBHANJ" if distname=="MAYURBHANJA" & state==21
replace distname="NABARANGPUR" if distname=="NABARANGAPUR"|distname=="NAWARANGAPUR" & state==21
replace distname="SUNDERGARH" if distname=="SUNDARGARH" & state==21

*** CHATTISGARH (22) OK
replace distname="BILASPUR (CG)" if (distname=="BILASPUR (CHHATTISGARH)"|distname=="BILASPUR") & state==22
replace distname="RAIGARH (CG)" if (distname=="RAIGARH (CHHATTISGARH)"|distname=="RAIGARH") & state==22
*2217 KONDAGAON (from BASTER 2215) [new]
*2218 NARAYANPUR (from BASTER 2215) [new]
*2219 MUNGELI (from BILASPUR (CG) 2207) [new]
*2220 BIJAPUR (from DANTEWADA 2216) [new]
*2221 SUKMA (from DANTEWADA 2216) [new]
*2222 BALOD (from DURG 2210) [new]
*2223 BEMETARA (from DURG 2210) [new]
*2224 BALODABAZAR (from RAIPUR 2211) [new]
*2225 GARIABAND (from RAIPUR 2211) [new]
*2226 BALRAMPUR	(from SURGUJA 2202) [new]
*2227 SURAJPUR from SARGUJA 2202) [new]
replace splitter=1 if distcd==2202|distcd==2207|distcd==2210|distcd==2211|distcd==2215|distcd==2216|distcd==2217|distcd==2218|distcd==2219|distcd==2220|distcd==2221|distcd==2222|distcd==2223|distcd==2224|distcd==2225|distcd==2226|distcd==2227

*** MADHYA PRADESH (23) *** OK 
replace distname="ANUPPUR" if distname=="ANUP PUR" & state==23
replace distname="ASHOKNAGAR" if distname=="ASHOK NAGAR" & state==23
replace distname="NARSIMHAPUR" if distname=="NARSINGHPUR" & state==23
*2349 ALIRAJPUR (from JHABUA 2324)
*2350 SINGRAULI (from SIDHI 2317)
replace splitter=1 if distcd==2349|distcd==2350|distcd==2324|distcd==2317

*** GUJARAT (24) *** OK
* 2426 TAPI (from SURAT 2422)
replace splitter=1 if distcd==2426|distcd==2422

*** DADRA NAGAR (26) *** OK 
replace distname="DADRA & NAGAR HAVELI" if distname=="SILVASSA"|distname=="DADRA AND NAGAR HAVELI(UT)" & state==26

*** MAHARASHTRA (27) *** OK
replace distname="MUMBAI" if distname=="MUMBAI II" & state==27

*** KARANATAKA (29) *** OK
* From 2006 to 2007 # of districts 27->33 via 6 splits
*KOLAR(2919) to KOLAR(2919) and CHIKKABALLAPURA/CHIKBALLAPUR(2929)
*BANGALORE(2920) to BANGALORE NORTH(2928) and BANGALORE SOUTH(2920)
*BELGAUM(2901) to BELGAUM(2901) and CHIKKODI(2930)
*TUMKUR(2918) to TUMKUR(2918) and MADHUGIRI(2931)
*GULBARGA(2904) to GULBARGA(2904) and YADAGIRI/YADGIRI(2933)
*BAGALORE RURAL(2921) to BANGALORE RURAL(2921) and RAMANAGARA/RAMNAGARA(2932)
* From 2010: # of districts 33->34 via 1 split
*UTTARAKANNADA (2910) to UTTARAKANNADA (2910) and UTTARA KANNADA SIRSI (2934)
replace distname="CHIKKABALLAPURA" if distname=="CHIKBALLAPUR" & state==29
replace distname="CHIKKAMANGALORE" if distname=="CHIKMAGALUR" & state==29
replace distname="CHAMARAJANAGAR" if distname=="CHAMRAJNAGAR"|distname=="CHAMARAJANAGARA" & state==29
replace distname="UTTARKANNADA" if distname=="UTTARA KANNADA"
replace distname="DAVANGERE" if distname=="DAVANAGERE" & state==29
replace distname="YADGIRI" if distname=="YADAGIRI" & state==29
replace distname="RAMANAGARA" if distname=="RAMNAGARA" & state==29
replace distname="BANGALORE NORTH" if distname=="BANGALORE U NORTH" & state==29
replace distname="BANGALORE SOUTH" if distname=="BANGALORE U SOUTH" & state==29
replace distname="MADHUGIRI" if distname=="TUMKUR MADHUGIRI" & state==29
replace distname="CHIKKODI" if distname=="BELGAUM CHIKKODI" & state==29
replace splitter=1 if distcd==2919|distcd==2920|distcd==2901|distcd==2918|distcd==2904|distcd==2921|distcd==2910
replace splitter=1 if distcd>=2928 & distcd<=2934

*** PONDICHERRY (34) *** OK
replace distname="PONDICHERRY" if distname=="PONDICHERRY (DISTRICT)"|distname=="PONDICHERRY (UT)" & state==34

*** ANDAMAN (35) *** OK
replace distname="NICOBARS" if distname=="NICOBAR" & state==35
replace distname="SOUTH ANDAMANS" if distname=="ANDAMANS" & state==35
* 3503 MIDDLE AND NORTH ANDAMANS (from SOUTH ANDAMANS 3501)
replace splitter=1 if distcd==3503|distcd==3501

* RETURN TO 2005 DISTRICT STRUCTURE *
* Only do this if needed
* Revise to include splits with [new] tag above!!

* MOHALI TO ROPAR
*replace schcd=schcd-11*10000000 if distcd==318
*replace blkcd=blkcd-11*100 if distcd==318
*replace distcd=distcd-11 if distcd==318
* TARAN TARAN TO AMRITSAR
*replace schcd=schcd-17*10000000 if distcd==319
*replace blkcd=blkcd-17*100 if distcd==319
*replace distcd=distcd-17 if distcd==319
* BARNALA TO SANGRUR
*replace schcd=schcd-4*10000000 if distcd==320
*replace blkcd=blkcd-4*100 if distcd==320
*replace distcd=distcd-4 if distcd==320
* ETAH TO KASHMIR NAGAR
*replace schcd=schcd-55*10000000 if distcd==972
*replace blkcd=blkcd-55*100 if distcd==972
*replace distcd=distcd-55 if distcd==972
* ANJAW TO LOHIT
*replace schcd=schcd-5*10000000 if distcd==1216
*replace blkcd=blkcd-5*100 if distcd==1216
*replace distcd=distcd-5 if distcd==1216
* KIPHERE TO TUENSANG
*replace schcd=schcd-7*10000000 if distcd==1309
*replace blkcd=blkcd-7*100 if distcd==1309
*replace distcd=distcd-7 if distcd==1309
* LONGLENG TO TUENSANG
*replace schcd=schcd-8*10000000 if distcd==1310
*replace blkcd=blkcd-8*100 if distcd==1310
*replace distcd=distcd-8 if distcd==1310
* PEREN TO KOHIMA
*replace schcd=schcd-4*10000000 if distcd==1311
*replace blkcd=blkcd-4*100 if distcd==1311
*replace distcd=distcd-4 if distcd==1311
* KHUNTI TO RANCHI
*replace schcd=schcd-9*10000000 if distcd==2023
*replace blkcd=blkcd-9*100 if distcd==2023
*replace distcd=distcd-9 if distcd==2023
* RAMGARH TO HAZARIBAG
*replace schcd=schcd-20*10000000 if distcd==2024
*replace blkcd=blkcd-20*100 if distcd==2024
*replace distcd=distcd-20 if distcd==2024
* ALIRAJPUR TO JHABUA
*replace schcd=schcd-25*10000000 if distcd==2349
*replace blkcd=blkcd-25*100 if distcd==2349
*replace distcd=distcd-25 if distcd==2349
* SINGRAULI TO SIDHI
*replace schcd=schcd-33*10000000 if distcd==2350
*replace blkcd=blkcd-33*100 if distcd==2350
*replace distcd=distcd-33 if distcd==2350
* TAPI TO SURAT
*replace schcd=schcd-4*10000000 if distcd==2426
*replace blkcd=blkcd-4*100 if distcd==2426
*replace distcd=distcd-4 if distcd==2426
* CHIKKABALLAPURA TO KOLAR
*replace schcd=schcd-10*10000000 if distcd==2929
*replace blkcd=blkcd-10*100 if distcd==2929
*replace distcd=distcd-10 if distcd==2929
* BANGALORE NORTH TO BANGALORE
*replace schcd=schcd-8*10000000 if distcd==2928
*replace blkcd=blkcd-8*100 if distcd==2928
*replace distcd=distcd-8 if distcd==2928
* CHIKKODI TO BELGAUM
*replace schcd=schcd-29*10000000 if distcd==2930
*replace blkcd=blkcd-29*100 if distcd==2930
*replace distcd=distcd-29 if distcd==2930
* MADHUGIRI TO TUMKUR
*replace schcd=schcd-13*10000000 if distcd==2931
*replace blkcd=blkcd-13*100 if distcd==2931
*replace distcd=distcd-13 if distcd==2931
* YADGIRI TO GULBARGA
*replace schcd=schcd-29*10000000 if distcd==2933
*replace blkcd=blkcd-29*100 if distcd==2933
*replace distcd=distcd-29 if distcd==2933
* RAMANAGARA TO BANGALORE RURAL
*replace schcd=schcd-11*10000000 if distcd==2932
*replace blkcd=blkcd-11*100 if distcd==2932
*replace distcd=distcd-11 if distcd==2932
* UTTARA KANNADA SIRSI TO UTTARAKANNADA
*replace schcd=schcd-24*10000000 if distcd==2934
*replace blkcd=blkcd-24*100 if distcd==2934
*replace distcd=distcd-24 if distcd==2934
* MIDDLE AND NORTH ANDAMANS TO SOUTH ANDAMANS
*replace schcd=schcd-2*10000000 if distcd==3503
*replace blkcd=blkcd-2*100 if distcd==3503
*replace distcd=distcd-2 if distcd==3503


tab splitter,mi
* 11% of teaches in districts that split between 2005-2012

label var splitter "District that splits at some point in 2005-2012"

*********************************************************************
* FIXES minor mistakes in DOB based on some assumptions (see below) *
*********************************************************************
set more off 

* drop useless
drop checkbit deputation_yn disability_type cwsntrained_yn post_status main_taught2 
compress

gen dob=10000*doby+100*dobm+dobd
* See if variation in dob even for a person with same name, sex and same school
egen dobv=sd(dob),by(schcd sex name2 name1)
replace dobv=1 if dobv~=0 & dobv~=.
replace dobv=. if name2==""|name1==""|doby==.|sex==.
compress dobv

* 1 = 10% in 4/2014
* . = 16.5% in 4/2014
* a lot, but not clearly concentrated to years / states
*seems that errors in DOB due to:
*1.typing mistakes (just one error in one DOB number)
*2.Uninformative names, and really two different people (if just initial and common last name) (esp if duplicate years)
*3.Respondent knows doby, but just guesses dobm and dobd, chooses 1.1. or 1.6. or such.
*Solution: 
*Could fix most by taking mode dob by {schcd name2 name1 sex} IF {names deemed informative AND total in group max 6 (max nr of years)!}
*If median not defined, don't fix 

gen dob2=dob
* set maxmode for cases of undefined mode
egen dobmod=mode(dob2),by(schcd name2 name1 sex) maxmode
egen dobcount=count(dob2),by(schcd name2 name1 sex)
gen name1l=length(name1)
gen name2l=length(name2)
replace dob2=dobmod if dob2~=dobmod & dobmod~=. & name2l>=3 & name1l>=1 & dobcount<=6 
gen doby2=floor(dob2/10000)
gen dobm2=floor((dob2-doby2*10000)/100)
gen dobd2=dob2-doby2*10000-dobm2*100
drop name1l name2l dobcount dobmod
compress

label var dobv "(inconsistent) variation in DOB using school, sex and names"
label var dob2 "DOB improved using name and gender info"
label var doby2 "DOBY improved using name and gender info"
label var dobm2 "DOBM improved using name and gender info"
label var dobd2 "DOBD improved using name and gender info"

save /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER_clean_fix.dta,replace


exit




