*********************************************************************************************
* Creates a school-level file (Using the DISE data obtained on Dec 2013) 		    
* Only for Government primary schools, and excluding teacher information (merged in later)  
* This is similar to "DISE_school_Dec13.do" but 
*	-Excludes teachers info
*	-Restricts sample to primary schools 
*	-creates indicator for schoolcode chages
* (The two do-files partly overlap)
*********************************************************************************************
* Includes information for splitting districts
*
* DEPENDS ON:
* many files created by DISE_prepare_Dec13.do
* 
* OUTPUTS:
* Turnover/DISE_schooltypes.txt
* turnover_schools.dta
* turnover_schools_primaries.dta
*
* Updated 15.9.2014 alternative school code change indicator 'scss'
*****************************
* MERGE ALL FILES TOGETHER **
*****************************
clear
set memory 13g

* START WITH KEYVAR (note that Keyvar has data 2002-2004 as well)
* MASTER data has some same vars as well, but data only for latest years
use /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_KEYVAR_clean.dta
* years 2002-2004 don't merge, plus some obs on other years
drop if ac_year==2002|ac_year==2003|ac_year==2004
drop if schcd==.

* MERGE IN MASTER
sort schcd ac_year
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_MASTER_clean.dta
drop if schcd==.
drop _merge

* make room
drop supvar* constvar? pincd edublkcd habitcd municipalcd clucd postaladdr stdcode1 phone1 mobile1 stdcode2 phone2 mobile2 email website

* MERGE IN ENROLMENT
sort schcd ac_year 
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_ENROLMENT_clean.dta
drop _merge
* will not need these now
drop if schcd==.
drop enr6* enr7* enr8*

* MERGE IN BLDEQP
sort schcd ac_year 
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_BLDEQP_clean.dta,nokeep
drop if schcd==.
drop _merge

compress

* MERGE IN PINCENTIVES
sort schcd ac_year 
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_PINCENTIVES_clean.dta,nokeep
drop if schcd==.
drop _merge

* SAVE SPACE
drop checkbit
drop inc_stag inc_stac inc_stac inc_scog inc_scoc

* MERGE IN EXAMRESULT
sort schcd ac_year 
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_EXAMRESULT_clean.dta,nokeep
drop if schcd==.
drop _merge

*GEN STATE VARIABLE
ge state=floor(schcd/1000000000)
gen state1="jammu" if state==1
replace state1="himachal" if state==2
replace state1="punjab" if state==3
replace state1="chandigarh" if state==4
replace state1="uttarakhand" if state==5
replace state1="haryana" if state==6
replace state1="delhi" if state==7
replace state1="rajasthan" if state==8
replace state1="uttarpradesh" if state==9
replace state1="bihar" if state==10
replace state1="sikkim" if state==11
replace state1="arunachal" if state==12
replace state1="nagaland" if state==13
replace state1="manipur" if state==14
replace state1="mizoram" if state==15
replace state1="tripura" if state==16
replace state1="meghalaya" if state==17
replace state1="assam" if state==18
replace state1="west_bengal" if state==19
replace state1="jharkand" if state==20
replace state1="orissa" if state==21
replace state1="chattisgarh" if state==22
replace state1="madhya_pradesh" if state==23
replace state1="gujarat" if state==24
replace state1="daman_diu" if state==25
replace state1="dadra_nagar" if state==26
replace state1="maharashtra" if state==27
replace state1="andhra_pradesh" if state==28
replace state1="karnataka" if state==29
replace state1="goa" if state==30
replace state1="lakshadweep" if state==31
replace state1="kerala" if state==32
replace state1="tamil_nadu" if state==33
replace state1="pondicherry" if state==34
replace state1="andaman" if state==35

*Some oddities in state variable
drop if state>35|state==0

*final fixes 
replace schcd=. if schcd<1000000000
replace schcd=. if schcd>40000000000
gen distcd2=floor(schcd/10000000)

compress

**********************
* FIX DISTRICT CODES *
**********************

gen byte splitter=.
replace distname=trim(distname)

*** JAMMU *** 
*tab distcd ac_year if state==1
*tab distname ac_year if state==1
* appears 115-122 may be new splitters in 2006->2007
*
*115 SHOPIAN
*116 BANDIPORA (from BARAMULA 102)
*117 KISHTWAR
*118 RAMBAN
*119 GANDERBAL (from SRINAGAR 103)
*120 KULGAM
*121 REASI (from UDHAMPUR 110)
*122 SAMBA (from JAMMU 113)
* make the whole state "splitter"
replace splitter=1 if distcd>=115 & distcd<=122
* The next line is a quess based on jumps in number of schools
replace splitter=1 if distcd==102|distcd==103|distcd==105|distcd==106|distcd==109|distcd==110|distcd==113

*** PUNJAB *** OK
replace distname="FIROZPUR" if distname=="FEROZEPUR" & state==3
replace distname="RUPNAGAR" if distname=="ROPAR" & state==3
replace distname="FAZILKA" if distname=="Fazilka" & state==3
* 318 MOHALI (from ROPAR 307)
* 319 TARAN TARAN (from AMRITSAR 302)
* 320 BARNALA (from SANGRUR 316)
* 321 FAZILKA (from FIROZPUR 311) [new]
* 322 PATHANKOT (from GURDASPUR 301) [new]
replace splitter=1 if distcd==318|distcd==319|distcd==320|distcd==321|distcd==322|distcd==301|distcd==302|distcd==307|distcd==311|distcd==316

*** CHANDIGARH (4) *** OK
replace distname="CHANDIGARH (U.T.)" if distname=="CHANDIGARH" 

*** UTTARAKHAND (5) *** OK
replace distname="GARHWAL" if distname=="PAURI GARHWAL" & state==5

*** HARYANA (6) *** OK
*620 MEWAT (from FARIDABAD 619 and GURGAON 618)
*621 PALWAL (from FARIDABAD 619)
replace splitter=1 if distcd==621|distcd==620|distcd==619|distcd==618

* Ignore DELHI (7) now

*** RAJASTHAN (8)*** OK 
replace distname="PRATAPGARH(RAJ.)" if distname=="PRATAPGARH(RAJASTHAN)"|distname=="PRATAPGARH (RAJ.)"
replace distname="DAUSA" if distname=="Dausa" & state==8
*833 PRATAPGARH (from Chittorgarh 829, Udaipur 826 and Banswara 828)
replace splitter=1 if distcd==833|distcd==829|distcd==826|distcd==828

*** UTTAR PRADESH (9) *** OK
replace distname="HAMIRPUR (U.P.)" if distname=="HAMIRPUR" & state==9
replace distname="BHADOI" if distname=="BHADOHI" & state==9
replace distname="SULTANPUR" if distname=="Sultanpur" & state==9
replace distname="KASHIRAM NAGAR" if distname=="KANSHIRAM NAGAR" & state==9
replace distname="AMETHI - CSM NAGAR" if distname=="CSMAHARAJ NAGAR" & state==9
replace distname="SHAMLI" if distname=="SHAMLI (PRABUDH NAGAR" & state==9
replace distname="HAPUR" if distname=="HAPUR (PANCHSHEEL NAG" & state==9
replace distname="SAMBHAL" if distname=="SAMBHAL (BHIM NAGAR)" & state==9
*972 KASHIRAM NAGAR (from ETAH 917)
*968 SAMBHAL (from MORADABAD 904) [new]
*973 AMETHI - CSM NAGAR (from SULTANPUR 949) [new]
*974 SHAMLI (from MUZAFFARNAGAR 902) [new]
*975 HAPUR (from GHAZIABAD 909) [new]
replace splitter=1 if distcd==968|distcd==972|distcd==973|distcd==974|distcd==975|distcd==902|distcd==904|distcd==909|distcd==917|distcd==949

*** BIHAR (10) OK
* 1039 ARWAL (from JEHANABAD 1033) 
replace splitter=1 if distcd==1033|distcd==1039

*** ARUNACHAL PRADESH (12) *** OK
replace distname="ANJAW" if distname=="Anjaw" & state==12
*1216 ANJAW (from LOHIT 1211)
replace splitter=1 if distcd==1216|distcd==1211

*** NAGALAND (13) *** OK
replace distname="KIPHERE" if distname=="KIPHIRE" & state==13
*1309 KIPHERE (from TUENSANG 1302)
*1310 LONGLENG (from TUENSANG 1302)
*1311 PEREN (from KOHIMA 1307)
replace splitter=1 if distcd==1309|distcd==1310|distcd==1311|distcd==1302|distcd==1307

*** TRIPURA (16) *** 
replace distname="NORTH TRIPURA" if distname=="NORTH" & state==16
replace distname="SOUTH TRIPURA" if distname=="SOUTH" & state==16
replace distname="WEST TRIPURA" if distname=="WEST" & state==16
*1605 SEPAHIJALA (from WEST TRIPURA 1601) [new]
*1606 KHOWAI (from WEST TRIPURA 1601) [new]
*1607 GOMATI (from SOUTH TRIPURA 1602) [new]
*1608 UNAKOTI (from NORTH TRIPURA 1604) [new]
replace splitter=1 if distcd==1601|distcd==1602|distcd==1604|distcd==1605|distcd==1606|distcd==1607|distcd==1608

*** ASSAM (18) ***
replace distname="DIMA HASAO" if distname=="NORTH CACHAR HILLS" & state==18
replace distname="KAMRUP-RURAL" if distname=="KAMRUP" & state==18
*1824 BAKSA (from BARPETA 1805, NALBARI 1807, and KAMRUP 1806) [new]
*1825 CHIRANG (from BONGAIGAON 1804) [new]
*1826 UDALGURI (from DARRANG 1808) [new]
*1827 KAMRUP-METRO (from KAMRUP [now KAMRUP-RURAL] 1806) [new]
replace splitter=1 if distcd==1804|distcd==1805|distcd==1806|distcd==1807|distcd==1808|distcd==1824|distcd==1825|distcd==1826|distcd==1827

*** JHARKAND (20) *** OK
*2023 KHUNTI (from RANCHI 2014)
*2024 RAMGARH (from HAZARIBAG 2004)
replace splitter=1 if distcd==2023|distcd==2024|distcd==2014|distcd==2004

*** ORISSA (21) *** OK
replace distname="ANGUL" if distname=="ANUGUL" & state==21
replace distname="BOLANGIR" if distname=="BALANGIR" & state==21
replace distname="DEOGARH" if distname=="DEBAGARH" & state==21
replace distname="JAJPUR" if distname=="JAJAPUR" & state==21
replace distname="KEONJHAR" if distname=="KENDUJHAR" & state==21
replace distname="SONEPUR" if distname=="SONAPUR" & state==21
replace distname="BOUDH" if distname=="BAUDH" & state==21
replace distname="BALASORE" if distname=="BALESHWAR" & state==21
replace distname="JAGATSINGHPUR" if distname=="JAGATSINGHAPUR" & state==21
replace distname="MAYURBHANJ" if distname=="MAYURBHANJA" & state==21
replace distname="NABARANGPUR" if distname=="NABARANGAPUR"|distname=="NAWARANGAPUR" & state==21
replace distname="SUNDERGARH" if distname=="SUNDARGARH" & state==21

*** CHATTISGARH (22) OK
replace distname="BILASPUR (CG)" if (distname=="BILASPUR (CHHATTISGARH)"|distname=="BILASPUR") & state==22
replace distname="RAIGARH (CG)" if (distname=="RAIGARH (CHHATTISGARH)"|distname=="RAIGARH") & state==22
*2217 KONDAGAON (from BASTER 2215) [new]
*2218 NARAYANPUR (from BASTER 2215) [new]
*2219 MUNGELI (from BILASPUR (CG) 2207) [new]
*2220 BIJAPUR (from DANTEWADA 2216) [new]
*2221 SUKMA (from DANTEWADA 2216) [new]
*2222 BALOD (from DURG 2210) [new]
*2223 BEMETARA (from DURG 2210) [new]
*2224 BALODABAZAR (from RAIPUR 2211) [new]
*2225 GARIABAND (from RAIPUR 2211) [new]
*2226 BALRAMPUR	(from SURGUJA 2202) [new]
*2227 SURAJPUR from SARGUJA 2202) [new]
replace splitter=1 if distcd==2202|distcd==2207|distcd==2210|distcd==2211|distcd==2215|distcd==2216|distcd==2217|distcd==2218|distcd==2219|distcd==2220|distcd==2221|distcd==2222|distcd==2223|distcd==2224|distcd==2225|distcd==2226|distcd==2227

*** MADHYA PRADESH (23) *** OK 
replace distname="ANUPPUR" if distname=="ANUP PUR" & state==23
replace distname="ASHOKNAGAR" if distname=="ASHOK NAGAR" & state==23
replace distname="NARSIMHAPUR" if distname=="NARSINGHPUR" & state==23
*2349 ALIRAJPUR (from JHABUA 2324)
*2350 SINGRAULI (from SIDHI 2317)
replace splitter=1 if distcd==2349|distcd==2350|distcd==2324|distcd==2317

*** GUJARAT (24) *** OK
* 2426 TAPI (from SURAT 2422)
replace splitter=1 if distcd==2426|distcd==2422

*** DADRA NAGAR (26) *** OK 
replace distname="DADRA & NAGAR HAVELI" if distname=="SILVASSA"|distname=="DADRA AND NAGAR HAVELI(UT)" & state==26

*** MAHARASHTRA (27) *** OK
replace distname="MUMBAI" if distname=="MUMBAI II" & state==27

*** KARANATAKA (29) *** OK
* From 2006 to 2007 # of districts 27->33 via 6 splits
*KOLAR(2919) to KOLAR(2919) and CHIKKABALLAPURA/CHIKBALLAPUR(2929)
*BANGALORE(2920) to BANGALORE NORTH(2928) and BANGALORE SOUTH(2920)
*BELGAUM(2901) to BELGAUM(2901) and CHIKKODI(2930)
*TUMKUR(2918) to TUMKUR(2918) and MADHUGIRI(2931)
*GULBARGA(2904) to GULBARGA(2904) and YADAGIRI/YADGIRI(2933)
*BAGALORE RURAL(2921) to BANGALORE RURAL(2921) and RAMANAGARA/RAMNAGARA(2932)
* From 2010: # of districts 33->34 via 1 split
*UTTARAKANNADA (2910) to UTTARAKANNADA (2910) and UTTARA KANNADA SIRSI (2934)
replace distname="CHIKKABALLAPURA" if distname=="CHIKBALLAPUR" & state==29
replace distname="CHIKKAMANGALORE" if distname=="CHIKMAGALUR" & state==29
replace distname="CHAMARAJANAGAR" if distname=="CHAMRAJNAGAR"|distname=="CHAMARAJANAGARA" & state==29
replace distname="UTTARKANNADA" if distname=="UTTARA KANNADA"
replace distname="DAVANGERE" if distname=="DAVANAGERE" & state==29
replace distname="YADGIRI" if distname=="YADAGIRI" & state==29
replace distname="RAMANAGARA" if distname=="RAMNAGARA" & state==29
replace distname="BANGALORE NORTH" if distname=="BANGALORE U NORTH" & state==29
replace distname="BANGALORE SOUTH" if distname=="BANGALORE U SOUTH" & state==29
replace distname="MADHUGIRI" if distname=="TUMKUR MADHUGIRI" & state==29
replace distname="CHIKKODI" if distname=="BELGAUM CHIKKODI" & state==29
replace splitter=1 if distcd==2919|distcd==2920|distcd==2901|distcd==2918|distcd==2904|distcd==2921|distcd==2910
replace splitter=1 if distcd>=2928 & distcd<=2934

*** PONDICHERRY (34) *** OK
replace distname="PONDICHERRY" if distname=="PONDICHERRY (DISTRICT)"|distname=="PONDICHERRY (UT)" & state==34

*** ANDAMAN (35) *** OK
replace distname="NICOBARS" if distname=="NICOBAR" & state==35
replace distname="SOUTH ANDAMANS" if distname=="ANDAMANS" & state==35
* 3503 MIDDLE AND NORTH ANDAMANS (from SOUTH ANDAMANS 3501)
replace splitter=1 if distcd==3503|distcd==3501

* RETURN TO 2005 DISTRICT STRUCTURE *
* Only do this if needed
* Revise to include splits with [new] tag above!!

* MOHALI TO ROPAR
*replace schcd=schcd-11*10000000 if distcd==318
*replace blkcd=blkcd-11*100 if distcd==318
*replace distcd=distcd-11 if distcd==318
* TARAN TARAN TO AMRITSAR
*replace schcd=schcd-17*10000000 if distcd==319
*replace blkcd=blkcd-17*100 if distcd==319
*replace distcd=distcd-17 if distcd==319
* BARNALA TO SANGRUR
*replace schcd=schcd-4*10000000 if distcd==320
*replace blkcd=blkcd-4*100 if distcd==320
*replace distcd=distcd-4 if distcd==320
* ETAH TO KASHMIR NAGAR
*replace schcd=schcd-55*10000000 if distcd==972
*replace blkcd=blkcd-55*100 if distcd==972
*replace distcd=distcd-55 if distcd==972
* ANJAW TO LOHIT
*replace schcd=schcd-5*10000000 if distcd==1216
*replace blkcd=blkcd-5*100 if distcd==1216
*replace distcd=distcd-5 if distcd==1216
* KIPHERE TO TUENSANG
*replace schcd=schcd-7*10000000 if distcd==1309
*replace blkcd=blkcd-7*100 if distcd==1309
*replace distcd=distcd-7 if distcd==1309
* LONGLENG TO TUENSANG
*replace schcd=schcd-8*10000000 if distcd==1310
*replace blkcd=blkcd-8*100 if distcd==1310
*replace distcd=distcd-8 if distcd==1310
* PEREN TO KOHIMA
*replace schcd=schcd-4*10000000 if distcd==1311
*replace blkcd=blkcd-4*100 if distcd==1311
*replace distcd=distcd-4 if distcd==1311
* KHUNTI TO RANCHI
*replace schcd=schcd-9*10000000 if distcd==2023
*replace blkcd=blkcd-9*100 if distcd==2023
*replace distcd=distcd-9 if distcd==2023
* RAMGARH TO HAZARIBAG
*replace schcd=schcd-20*10000000 if distcd==2024
*replace blkcd=blkcd-20*100 if distcd==2024
*replace distcd=distcd-20 if distcd==2024
* ALIRAJPUR TO JHABUA
*replace schcd=schcd-25*10000000 if distcd==2349
*replace blkcd=blkcd-25*100 if distcd==2349
*replace distcd=distcd-25 if distcd==2349
* SINGRAULI TO SIDHI
*replace schcd=schcd-33*10000000 if distcd==2350
*replace blkcd=blkcd-33*100 if distcd==2350
*replace distcd=distcd-33 if distcd==2350
* TAPI TO SURAT
*replace schcd=schcd-4*10000000 if distcd==2426
*replace blkcd=blkcd-4*100 if distcd==2426
*replace distcd=distcd-4 if distcd==2426
* CHIKKABALLAPURA TO KOLAR
*replace schcd=schcd-10*10000000 if distcd==2929
*replace blkcd=blkcd-10*100 if distcd==2929
*replace distcd=distcd-10 if distcd==2929
* BANGALORE NORTH TO BANGALORE
*replace schcd=schcd-8*10000000 if distcd==2928
*replace blkcd=blkcd-8*100 if distcd==2928
*replace distcd=distcd-8 if distcd==2928
* CHIKKODI TO BELGAUM
*replace schcd=schcd-29*10000000 if distcd==2930
*replace blkcd=blkcd-29*100 if distcd==2930
*replace distcd=distcd-29 if distcd==2930
* MADHUGIRI TO TUMKUR
*replace schcd=schcd-13*10000000 if distcd==2931
*replace blkcd=blkcd-13*100 if distcd==2931
*replace distcd=distcd-13 if distcd==2931
* YADGIRI TO GULBARGA
*replace schcd=schcd-29*10000000 if distcd==2933
*replace blkcd=blkcd-29*100 if distcd==2933
*replace distcd=distcd-29 if distcd==2933
* RAMANAGARA TO BANGALORE RURAL
*replace schcd=schcd-11*10000000 if distcd==2932
*replace blkcd=blkcd-11*100 if distcd==2932
*replace distcd=distcd-11 if distcd==2932
* UTTARA KANNADA SIRSI TO UTTARAKANNADA
*replace schcd=schcd-24*10000000 if distcd==2934
*replace blkcd=blkcd-24*100 if distcd==2934
*replace distcd=distcd-24 if distcd==2934
* MIDDLE AND NORTH ANDAMANS TO SOUTH ANDAMANS
*replace schcd=schcd-2*10000000 if distcd==3503
*replace blkcd=blkcd-2*100 if distcd==3503
*replace distcd=distcd-2 if distcd==3503

**********************************
** SOME IMPORTANT SUMMARY STATS **
**********************************

*DROP 2012-13 HERE (DUE TO INSUFFICIENT DATA IN DEC 13 DISE)
drop if ac_year==2012

set logtype text
log using /tera1/IndiaTeachers/Turnover/DISE_schooltypes.txt,replace

* In some states, 'local body' -run schools much more common than Dept of Edu (Rajastan, Gujarat, Maharashtra, AndraPradesh, TamilNadu)
tab state schmgt
* Some states have lots of Primary+upper Primary schools (Gujarat, Maharasthra, Karnataka)
tab state schcat
* Developments of schooltypes over time: Genuine or coverage?
* Gov and local schools have grown 10-13%, private aided by 12% and unaided by 45%
tab schmgt ac_year
* Private school numbers by state & year
* in some states, the growth is jerky or doesn't make sense (Assam, WestBengal)
tab state ac_year if schmgt==5

log close
********************************
** SAVE THE FULL SCHOOLS FILE **
********************************
sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/turnover_schools,replace


************
** SAMPLE **
************

* no school duplicates: same schcd & year
sort schcd ac_year
gen repeat=1 if schcd==schcd[_n-1] & ac_year==ac_year[_n-1]
tab repeat
* 1 school
drop if repeat==1
drop repeat

* Count how large proportion of grade 1 enrollment is in Private schools, and Primary only schools, by year and district

*** PRIVATE AND PRIMARY ONLY ENROLLMENT BY DISTRICT & YEAR 
egen di_enr1=total(enr1),by(distcd ac_year)
label var di_enr1 "1st grade enrolment (dist,year)" 
* some district enrolments are zero! (egen total makes missing zero) 
tab state ac_year if di_enr1==0
* tab distcd ac_year if di_enr1==0
* set enrolments to missing in these district*year obs. Clearly, missing data has been coded as zero.
* the same dists come up with year 4 enrolment
foreach var of varlist enr* *enr {
replace `var'=. if di_enr1==0
replace `var'=. if distcd==704 & ac_year==2008
replace `var'=. if distcd==919 & ac_year==2005
replace `var'=. if distcd==1921 & ac_year==2005
}
* dist 704 added since values are very small for delhi districts and other years of that dist are excluded
* dists 919 & 1921 for 2005 excluded since total enrolment numbers since enr1g and enr1 exists for too few schools
* flag them up 
gen badenr=1 if di_enr1==0 | (distcd==704 & ac_year==2008)| (distcd==919 & ac_year==2005)| (distcd==1921 & ac_year==2005)
label var badenr "poor quality enrolment data - don't use"
drop di_enr1
egen di_enr1=total(enr1),by(distcd ac_year) missing

* want % enrolment of tribal and local schools
egen di_tenr1_=total(enr1) if schmgt==2|schmgt==3,by(distcd ac_year) missing
egen di_tenr1=mean(di_tenr1_),by(distcd ac_year)
gen di_tri=di_tenr1/di_enr1
drop di_tenr1_ di_tenr1
label var di_tri "1st grade tribal/local school enrolment share (dist,year)" 

egen di_penr1_=total(enr1) if schmgt==4|schmgt==5,by(distcd ac_year) missing
egen di_penr1=mean(di_penr1_),by(distcd ac_year)
gen di_pri=di_penr1/di_enr1
drop di_penr1_ di_penr1
label var di_pri "1st grade private enrolment share (dist,year)"

* % low caste in all schools
egen di_cenr1_=total(enr1c),by(distcd ac_year) missing
egen di_cenr1=mean(di_cenr1_),by(distcd ac_year)
gen di_cas=di_cenr1/di_enr1
drop di_cenr1_ di_cenr1
label var di_cas "1st grade SC-ST-OB enrolment share (dist,year)"

*% low caste in gov/trib/local schools 
egen di_cenr1_=total(enr1c) if schmgt<=3,by(distcd ac_year) missing
egen di_cenr1=mean(di_cenr1_),by(distcd ac_year)
gen di_casg=di_cenr1/di_enr1
drop di_cenr1_ di_cenr1
label var di_casg "1st grade SC-ST-OB enrolment share in gov/loc/trib schools (dist,year)"


* Keep schools that are Primary (schcat<=3). So far keep all management types (schmgt)
keep if schcat<=3

* Total number of primary pupils and primary schools in district
* differentiate states where ends after class 4/5
* returns missing if any of the classes has a missing
gen prienrg=enr1+enr2+enr3+enr4+enr5 if highclass~=4 & schmgt<=3
replace prienrg = enr1+enr2+enr3+enr4 if highclass==4 & schmgt<=3
egen di_prienrg_=total(prienrg),by(distcd ac_year) missing
egen di_prienrg=mean(di_prienrg_),by(distcd ac_year)
drop prienrg di_prienrg_
label var di_prienrg "Total lower primary enrolment in gov/loc/trib school (dist,year)"

egen di_prigs_=count(schcd) if schmgt<=3,by(distcd ac_year) 
egen di_prigs=mean(di_prigs_),by(distcd ac_year)
drop di_prigs_
label var di_prigs "Total # of lower primary gov/loc/trib schools (dist,year)"

***************************************
* INDICATOR FOR CHANGES IN SCHOOLCODE *
***************************************
* Flag up schools for which schcd and and schname inconsistent
* Exclude these from analyses where school time series is essential  
* Number of schools if year>2005
sort state schcd ac_year
replace schname=trim(schname)

*count if ac_year>2005
*6557987
* How many of them have a preceding year observation
*count if schcd==schcd[_n-1] & ac_year==ac_year[_n-1]+1 & schcd~=.
*5991388
* How many of them have a school name for both
*count if schcd==schcd[_n-1] & ac_year==ac_year[_n-1]+1 & schcd~=. & schname~="" & schname[_n-1]~=""
*5991270
*How many of them has precisely the same name
*count if schcd==schcd[_n-1] & ac_year==ac_year[_n-1]+1 & schcd~=. & schname~="" & schname[_n-1]~="" & schname==schname[_n-1]
*5339180

* Instances due to:
*  School code change (still same school, unless split/merge?)
*  School name change (still same school)
*  Differences in how name coded (still same school)
* Options:
*  changing schcd:s probably not a good idea 
* The real problem are schools that have the same schoolcode but really change (and change name)
* need something smarter: see if name 'too different'
* use rudimentary pattern recognition
gen sn1=substr(schname,1,5)
gen sn2=substr(schname,-5,5)

gen scc_=1 if schcd==schcd[_n-1] & ac_year==ac_year[_n-1]+1 & schcd~=. & schname~="" & schname[_n-1]~="" & sn1~=sn1[_n-1] & sn2~=sn2[_n-1]
replace scc_=1 if scc_[_n+1]==1
egen scc=mean(scc_),by(schcd)
replace scc=0 if scc==.
drop scc_ sn1 sn2 
label var scc "School code change indicator (selfconstructed)"
* ALTERNATIVE, BASED ON SCHOOL CODE CHANGE WITHIN NAME
* schools can have same names, but assume not within a block!
sort blkcd schname schcd ac_year 
gen scs = schname==schname[_n-1] & schcd!=schcd[_n-1]
egen scss =max(scs),by(blkcd schname)
* some schools have >1 changes so don't define the year of change
label var scss "schools that change school code"


set logtype text
log using /tera1/IndiaTeachers/Turnover/Gender_output/scc-scss0511.txt,replace
* Uncertainty in schoolcode/name for 2005-2011 data without district splits code change applied	
su scc scss
* do the two correspond?
tab scc scss,mi
* No!
tabstat scc scss,by(state)
log close

sort schcd ac_year
save /tera1/DISE_Dec13/DISE_clean_Dec13/turnover_schools_primaries,replace


exit














