******************************************************
* SCHOOL LEVEL FILE FOR DATA PROCESSING AND ANALYSIS * 
******************************************************
*
*INPUTS:
*/tera1/DISE_Apr15/DISE_clean_Apr15/STEPS_TEACHER_clean_fix.dta
*/tera1/DISE_Apr15/DISE_clean_Apr15/turnover_schools_primaries.dta (turnover_schools_Apr15.do)
*/tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix (appendelec.do)
*/tera1/ASER/aserdist.dta
*/tera1/IndiaTeachers/Census/districts2011.dta
*/tera1/IndiaTeachers/Turnover/polcycle_all.dta (/Turnover/politicalcycle.do)
*
*OUTPUTS:
*/tera1/IndiaTeachers/Turnover/polcycle_all2012.dta (for school and district level analysis)
*/tera1/IndiaTeachers/Turnover/polcycle_tch2012.dta (for teacher level analysis, using the same sample as school level data)
* Table 2, Table 4 columns 2-3, Table 12, Appendix Table X1
*
*updated: 20.10.2018 added 2 new teacher caste variables.

clear
* set mem 12g
set more off
****************************************************
**** TEACHER DATA TO BE MERGED INTO SCHOOL DATA ****
****************************************************
* Get numbers of teachers who teach at primary level 
use qual_acad eng_upto math_upto cls_taught schcd ac_year category sex caste trn* nontch_ass yoj dob doby dobm dobd using /tera1/DISE_Apr15/DISE_clean_Apr15/STEPS_TEACHER_clean_fix.dta 
gen tchpri=1 if cls_taught==1|cls_taught==3
* restrict to primary teachers only
keep if tchpri==1
gen tchpri_nopara=1 if category<4 
gen paratch_pri=1 if category==4 
gen female=1 if sex==2
replace female=0 if sex==1
* Training & non-teaching
gen ed_g = qual_acad>=4 &qual_acad<=6
gen byte math_g = math_upto>=4 & math_upto<=6
gen byte eng_g = eng_upto>=4 & eng_upto<=6
replace math_upto=. if math_upto>6
replace eng_upto=. if eng_upto>6
gen trn_any=trn_brc+trn_crc+trn_diet+trn_other
gen trnnon=trn_any+nontch_ass
replace trn_any=. if trn_any>365
replace trnnon=. if trnnon>365
 
* Teacher caste for formal primary teachers
gen tlcaste=0 if caste==1 & tchpri_nopara==1
replace tlcaste=1 if caste>1 & caste<=11 & tchpri_nopara==1 
gen ttcaste=1 if caste==3 & tchpri_nopara==1
replace ttcaste=0 if caste<=11 & caste!=3 & tchpri_nopara==1 
gen tocaste=1 if (caste==4|caste==5|caste==6) & tchpri_nopara==1
replace tocaste=0 if caste<=11 & (caste!=4 & caste!=5 & caste!=6) & tchpri_nopara==1 
gen alcaste=0 if caste==1
replace alcaste=1 if caste>1 & caste<=11 
gen atcaste=1 if caste==3 
replace atcaste=0 if caste<=11 & caste!=3 
gen aocaste=1 if (caste==4|caste==5|caste==6) 
replace aocaste=0 if caste<=11 & (caste!=4 & caste!=5 & caste!=6)
* Teacher gender for formal primary teachers
gen tfemale=female if tchpri_nopara==1 
* Numbers of teachers in categories
gen tchpri_nopara_g=tchpri_nopara if caste==1
gen tchpri_nopara_c=tchpri_nopara if caste>1 & caste<=6
gen tchpri_nopara_m=tchpri_nopara if female==0
gen tchpri_nopara_f=tchpri_nopara if female==1
** New teacher: Year of joining is the current year
gen newtch=1 if ac_year==yoj & ac_year!=.
replace newtch=0 if newtch!=1

compress
saveold /tera1/IndiaTeachers/Turnover/polcycle_tch2012-intermediate.dta,replace
************************************************
* Collapse teacher file to school X year level *
************************************************
collapse (count) tchpri tchpri_nopara paratch_pri tchpri_nopara_g tchpri_nopara_c tchpri_nopara_m tchpri_nopara_f (mean) newtch tlcaste ttcaste tocaste alcaste atcaste aocaste tfemale ed_g eng_g math_g math_upto eng_upto trn_any nontch_ass trnnon female,by(schcd ac_year)
* a few obs are clear outliers - just drop
*su tchpri if tchpri<1000,d
*su tchpri if tchpri<1000,d
drop if tchpri>1000 & tchpri~=.
label var tchpri "# of teachers who teach (lower) primary (incl para)"
label var tchpri_nopara "# of teachers who teach (lower) primary (excl para)"
label var paratch_pri "# of teachers who teach (lower) primary (para only)"
label var ed_g "Graduate (BSc etc) at lower primary"
label var math_g "Maths to university level at lower primary"
label var eng_g "English to university level at lower primary"
label var trn_any "Avg. Training days (in any place) at lower primary"
label var nontch_ass "Avg. Non-teaching assignment days at lower primary"
label var trnnon "Avg. training or nonteaching days at lower primary"
label var female "% of teachers who are female (incl paras, at lower primary) (by schcd ac_year)"
label var newtch "% of new teachers in the school (zero tenure, incl. paras at lower primary)"
label var tlcaste "% primary teachers SC/ST/OB caste (excl paras)"
label var ttcaste "% primary teachers Scheduled Tribe caste (excl paras)"
label var tocaste "% primary teachers OBC/OBR/Other caste (excl paras)"
label var alcaste "% primary teachers SC/ST/OB caste (incl paras)"
label var atcaste "% primary teachers Scheduled Tribe caste (incl paras)"
label var aocaste "% primary teachers OBC/OBR/Other caste (incl paras)"
label var tfemale "% primary teachers female (excl paras)"
label var tchpri_nopara_g "# of General caste teachers (excl paras) at lower primary"
label var tchpri_nopara_c "# of SC/ST/OB caste teachers (excl paras) at lower primary"
label var tchpri_nopara_m "# of male teachers (excl paras) at lower primary"
label var tchpri_nopara_f "# of female teachers (excl paras) at lower primary"
sort schcd ac_year 
saveold /tera1/IndiaTeachers/Turnover/pritchlist2012.dta,replace


*********************
**** SCHOOL DATA ****
*********************
use /tera1/DISE_Apr15/DISE_clean_Apr15/turnover_schools_primaries.dta,clear
sort schcd ac_year 
merge schcd ac_year using /tera1/IndiaTeachers/Turnover/pritchlist2012.dta
* The schools dropped here are not officially primary schools (by schcat), but claim to have teachers who teach primary (by cls_taught)
drop if _merge==2
drop _merge

gen outl=0
label var outl "Outliers"

* DISE report: States with 4-year primary schools are: 15 17 18 19 24 25 26 27 29 30 32
* lower primary enrolment
gen enr=enr1+enr2+enr3+enr4
replace enr=enr+enr5 if state!=15 & state!=17 & state!=18 & state!=19 & state!=24 & state!=25 & state!=26 & state!=27 & state!=29 & state!=30 & state!=32 
gen lenr=ln(enr)
label var lenr "Ln Enrollment in grades 1-4/5"


* Some enrolment figures don't make sense. Shave 0.5% from enrollment figures for classes 1-5, for each year
foreach num of numlist 2005/2012 {
 quietly su enr if ac_year==`num',d
 gen top1=r(p99)
 quietly su enr if enr>top1 & ac_year==`num',d
 replace outl=1 if enr>r(p50) & enr~=. & ac_year==`num'
 drop top1
}


* Fix some worrying outliers on Distance to HQ
* set top 0.5% missing
gen outdis=.
foreach num of numlist 2005/2012 {
quietly su disthq if ac_year==`num',d
gen top1=r(p99)
quietly su disthq if disthq>top1 & ac_year==`num',d
replace outdis=1 if disthq>r(p50) & disthq~=. & ac_year==`num'
drop top1
}
egen disthqm=mode(disthq) if outdis!=1,by(schcd) maxmode
label var disthqm "Distance to district HQ (mode without outliers)"
drop disthq outdis
compress


* School management
gen mgt_tribal = schmgt==2
gen mgt_local = schmgt==3
gen mgt_priv = schmgt==4|schmgt==5
label var mgt_tribal "School management: Tribal"
label var mgt_local "School management: Local"
label var mgt_priv "School management: Private (aided+unaided)"
* School category 
gen cat_pup = schcat==2
gen cat_pups = schcat==3
label var cat_pup "School includes Upper Primary"
label var cat_pups "School includes Upper Pri. and Sec."

* Pupil teacher ratio
* note that enr is for year 1-4/5 only
* tchpos & parapos refer to whole school which may include upper primary, thus use 'tchpri'
gen puptch=enr/tchpri
gen puptch_nopara=enr/tchpri_nopara
* in both: note that zero teachers leads to pt-ratio not being defined!
gen noreg=tchpri_nopara==0
* Number of formal teachers there should be, if max of 40 pups per teacher enforced
gen tch40_=enr/40
gen tch40=floor(enr/40)
replace tch40=tch40+1 if tch40_!=tch40 | tch40==0
* set to zero for those with no pupils.
replace tch40=0 if enr==0
* Number of formal teachers required if also should have a minimum of 2 per school
gen tch40_2=tch40
replace tch40_2=2 if tch40==1
drop tch40_

su puptch,d
* set top  0.5% as outliers each year. Unrealistic figures.
foreach num of numlist 2005/2012 {
quietly su puptch if ac_year==`num',d
gen top1=r(p99)
quietly su puptch if puptch>top1 & ac_year==`num',d
replace outl=1 if puptch>r(p50) & puptch~=. & ac_year==`num'
drop top1
}

label var puptch "enr/tchpri = enrolment 1-4/5 / primary teachers (inc para)"
label var puptch_nopara "enr/tchpri = enrolment 1-4/5 / primary teachers (excl para)"
label var noreg "No regular teacher in the primary school"
label var tch40 "required # of teachers if max 40 per teacher"
label var tch40_2 "tch40 + minimum of 2 per school (if any pupils)"

************************
**** POLITICAL DATA ****
************************
rename ac_year year
* Match election 2008 results to DISE 2009 as that is the first year with new gov.
replace year=year-1
sort distcd year
merge distcd year using /tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix
replace year=year+1
rename year ac_year
drop if _merge==2
drop _merge

compress
saveold /tera1/IndiaTeachers/Turnover/polcycle_all2012.dta,replace

*******************************************************************
**** TEACHER FILE WHICH HAS THE SAME SAMPLE AS THE SCHOOL FILE ****
*******************************************************************
clear
use schcd ac_year distcd urban disthqm enr_c using /tera1/IndiaTeachers/Turnover/polcycle_all2012.dta
sort schcd ac_year
saveold /tera1/IndiaTeachers/Turnover/polcycle_all2012-sample.dta,replace

clear
* This file is saved above from teacher level file
use /tera1/IndiaTeachers/Turnover/polcycle_tch2012-intermediate.dta,replace
sort schcd ac_year
merge m:1 schcd ac_year using /tera1/IndiaTeachers/Turnover/polcycle_all2012-sample.dta
* drop if sample restricted at school level
drop if _merge==2
* drop teachers that are not assigned to a school (mostly teachers in 2013, for which no school data)
drop if _merge==1
drop _merge

drop if ac_year==2005

* Teacher identifier and exit.
* also need to drop some schools for which teachers not identified

* DATE OF BIRTH INFO MISSING
gen nod=0
replace nod=1 if doby==.
egen nods=mean(nod),by(schcd)
gen misdob = nods>0 & nods~=.
drop nods
label var nod "DOB missing"
label var misdob "School(code) has a teacher with missing DOB in ANY year"

* TEACHER IDENTIFIER
egen tchid=group(schcd dob sex) 
* br schcd ac_year dob sex tchid misdob
* Identical ppl in the same year?
sort schcd tchid ac_year
count if tchid==tchid[_n-1] & ac_year==ac_year[_n-1]
gen doub_=1 if tchid==tchid[_n-1] & ac_year==ac_year[_n-1]
egen doub=mean(doub_),by(tchid)
replace doub=0 if doub==.
* br schcd ac_year dob sex tchid misdob doub_ doub
* These have to be dropped for the analysis to work

* see these to assess quality of birthdate data

ge yob=1900+doby
ge age=ac_year-yob
gen byte lcaste = caste>1 & caste!=.
*su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4
* Must drop if doub==1
* Other issues can be lived with
*su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4 & doub==1


drop if doub==1

*su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4

* TEACHER EXIT DUMMY (within school only)
sort schcd tchid ac_year
gen disap=0 if schcd==schcd[_n+1] & tchid==tchid[_n+1] & ac_year<ac_year[_n+1]
* now set it to 1 unless the last year of the school
egen lastyr=max(ac_year),by(schcd)
replace disap=1 if disap==. & ac_year~=lastyr
label var disap "Teacher disappears the next year (from the school)"
* Appearing teacher (probably not needed much)
egen firye=min(ac_year),by(schcd)
gen appear=0 if schcd==schcd[_n-1] & tchid==tchid[_n-1] & ac_year>ac_year[_n-1]
* set to 1 unless 1st year of the school
replace appear=1 if appear==. & ac_year!=firye
label var appear "Teacher appears for the 1st year (in the school)"

* Note that this includes all ages, for analysis of movements, need to exclude retirees (age<=55)
saveold /tera1/IndiaTeachers/Turnover/polcycle_tch2012.dta,replace



**************************
* ANALYSIS: SCHOOL LEVEL *
**************************
clear
set more off
use /tera1/IndiaTeachers/Turnover/polcycle_all.dta

quietly tab elecyr, ge(ed)
quietly tab eleciv, ge(iv)

** School FEs is the most rigorous (use them)
tis ac_year
iis schcd

* Political cycle effects / timing:
* Pre-election: ed4 ed5, post-election: ed1 ed2, leave ed3 as ref category

* redefine no water
gen bld_wat=1-bld_watno
* Water index
gen bld_watind=0 if bld_watno==1
replace bld_watind=1 if bld_watwe==1|bld_watot==1
replace bld_watind=2 if bld_wathp==1
replace bld_watind=3 if bld_watta==1
* Building index (quite simple) 
* reduce missings in some bld_ variables:
foreach var of varlist bld_qtent bld_qkuccha bld_qppucca bld_qpucca {
replace `var'=0 if bld_none==1
}
gen bld_bldind=0*bld_none+1*bld_qtent+2*bld_qkuccha+3*bld_qppucca+4*bld_qpucca

* incentives per pupil 
gen inc_txtp=inc_txt/enr
gen inc_unip=inc_uni/enr
gen inc_scop=inc_sco/enr
* note that some places get more uniforms than there are pupils 
* for both, set top 0.5% as outliers (3.44 books, 1.5 uniforms)
foreach var of varlist inc_txtp inc_unip inc_scop {
quietly su `var',d
gen top1=r(p99)
quietly su `var' if `var'>top1,d
replace outl=1 if `var'>r(p50) & `var'~=.
drop top1
}
label var inc_txtp "textbooks per pupil"
label var inc_unip "uniforms per pupil"
label var inc_scop "attendance scholarships per pupil"
* also need to set outlier if enrolment is missing
replace outl=1 if enrtot==. |enr==.


*label define statex 1 Jammu 2 Himachal 3 Punjab 4 Chandigarh 5 Uttarakhand 6 Haryana 7 Delhi 8 Rajastan 9 Uttarpradesh 
*10 Bihar 11 Sikkim 12 Arunachal 13 Nagaland 14 Manipur 15 Mizoram 16 Tripura 17 Meghalaya 18 Assam 19 WestBengal 
*20 Jharkand 21 Orissa 22 Chattisgarh 23 MadhyaPradesh 24 Gujarat 25 DamanDiu 26 DadraNagar 27 Maharashtra
*28 AndhraPradesh 29 Karnataka 30 Goa 31 Lakshadweep 32 Kerala 33 Tamilnadu 34 Ponicherry 35 Andaman;

replace outl=0 if outl==.
tab ac_year,ge(yd)

* classrooms/computers per pupil (divide by total enrolment for year 1-8 here)
foreach var of varlist bld_crn bld_comp {
gen `var'p=`var'/enrtot
* Outliers, top 0.5% 
quietly su `var'p,d
gen top1=r(p99)
quietly su `var'p if `var'p>top1,d
replace outl=1 if `var'p>r(p50) & `var'p~=.
drop top1
}
replace bld_crnp=100*bld_crnp
replace bld_compp=100*bld_compp
label var bld_crnp "Classrooms per 100 pupils"
label var bld_compp "Computers per 100 pupils"


compress
saveold /tera1/IndiaTeachers/Turnover/polcycle_reg2.dta,replace

********************************
*** School level regressions ***
********************************
clear
set more off
use /tera1/IndiaTeachers/Turnover/polcycle_reg2.dta
* Save space
drop c?_* *h1 *h2 *h3 schname distname constcd city pancd constname inityear vilcd blkcd 
drop clsunderconst-comp_func *sec schstatus-schreshsec_yn
drop *_r *_e dist sparty c5* c7*
* formal teachers only
gen tchpri_for=tchpri-paratch_pri
label var tchpri_for "# of teachers who teach (lower) primary (formal only)"

* state trends
foreach num of numlist 1/35 {
capture gen st_`num'=0
capture replace st_`num'=ac_year if state==`num'
}

iis schcd
tis ac_year


*Add district-level census variables
sort distcd
merge distcd using "/tera1/IndiaTeachers/Census/districts2011.dta"

*** SUMMARY STATISTICS, (Table 2) ***
set logtype text
log using /tera1/IndiaTeachers/ResourceCycle/sumstats_dec15small.txt,replace
quietly xtivreg2 tchpri (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* if outl==0 & schmgt<4 & scc==0, fe 
ge regsam2=e(sample)
su ac_year tchpri tchpri_nopara nontch_ass newtch ed1 ed2 ed3 ed4 ed5 if regsam2==1, sep(0)
codebook state if regsam2==1
codebook distcd if regsam2==1
codebook schcd if regsam2==1
log close

*** SAMPLE SELECTION (APPENDIX Table X1) 
set logtype text
log using /tera1/IndiaTeachers/ResourceCycle/sumstats_dec15small.txt,append
su ac_year tchpri urban if schmgt<4 
* school code change =0 
su ac_year tchpri urban if schmgt<4 & scc!=0
* outliers
su ac_year tchpri urban if schmgt<4 & scc==0 & outl==1
* then have 
su ac_year tchpri urban if schmgt<4 &  scc==0 & outl==0
su ac_year tchpri urban if regsam2==1
log close
*** Table X1 ENDS ***

* Make space - drop some unnecessary vars
drop distcrc estdyear lowclass highclass ppsec_yn ppstudent ppteacher workdays schres_yn resitype schshi_yn noinspect visitscrc visitsbrc tchsan tchpos parapos ntpos medinstr1 medinstr2 medinstr3 medinstr4
drop enr1-enr_c
drop di_enr1 di_tri di_pri di_cas di_casg di_prienrg di_prigs math_upto eng_upto trn_any headn headan head_f head_af head_c DPEPf DPEPfp DPEP lnDPEPfp
drop schtypes schtypehs schmgths bld_crmaj bld_crmin bld_crn0 bld_otmaj bld_otmin bld_bboard bld_cabin bld_box bld_wathp bld_watwe bld_watta bld_watot bld_watno bld_medic bld_qpucca bld_qppucca bld_qkuccha bld_qtent inc_txtg inc_txtc inc_txtab inc_staab inc_txt0 inc_sta0 inc_uni0 inc_unig inc_unic inc_uniab inc_sco0 inc_scoab
drop state1 distcd2
drop tch40 tch40_2 state2 month saligns CFiv1 CFiv2 CFiv1b CFiv2b fems ivfem1 ivfem2 ivfem15 ivfem25 ivfem17 ivfem27 resst ressc pst psc dturnout dturnoutpre
drop durban dlit_f dlit_m dsexratio dsc dst mdlit_f rdlit_f mdlit_m rdlit_m diff_lit mdiff_lit rdiff_lit _merge
compress

** RESOURCE CYCLES  
gen paras=paratch_pri/tchpri
set logtype text
log using /tera1/IndiaTeachers/ResourceCycle/teachers_nov15.txt, replace
** TEACHERS & NON_TEACHING ASSIGNMENTS (Table 4 Columns 2-4)
xtivreg2 tchpri (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/dise_tch, replace wide 10pct bracket dec(3) fmt(g) 
xtivreg2 paras (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/dise_tch, append wide 10pct bracket dec(3) fmt(g)
xtivreg2 nontch_ass (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/dise_tch, append wide 10pct bracket dec(3) fmt(g) 
log close
*xtivreg2 tchpri_for (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
*outreg2 using /tera1/IndiaTeachers/ResourceCycle/dise_tch, append wide 10pct bracket dec(3) fmt(g) 
*xtivreg2 paratch_pri (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
*outreg2 using /tera1/IndiaTeachers/ResourceCycle/dise_tch, append wide 10pct bracket dec(3) fmt(g) 
*** Table 4 ENDS ***

* Political interactions to teachers [NOT USED?]
gen ed1n=ed1*newrule
gen ed1a=ed1*aligns
xtreg tchpri ed4 ed5 ed1 ed2 newrule ed1n yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_pol2, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1n ed2 ed4 ed5 newrule)
xtreg tchpri ed4 ed5 ed1 ed2 aligns ed1a yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_pol2, append wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1a ed2 ed4 ed5 aligns)


** School resources Table (Table 12)
set more off
set logtype text
log using /tera1/IndiaTeachers/ResourceCycle/resources_all_jun16.txt, replace
foreach var of varlist inc_unip inc_txtp bld_crnp bld_wcg bld_elec bld_watind bld_bldind bld_wall bld_bookb bld_compp bld_ramp bld_medic bld_playg {
quietly xtivreg2 `var' (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
quietly su `var' if e(sample)
display _b[ed4], _se[ed4],_b[ed5], _se[ed5],_b[ed1], _se[ed1],_b[ed2], _se[ed2], e(N), e(r2), r(mean)
}
log close
** Table 12 ends

**** Enrolment in grade 4 (SF requested for a presentation) - do this at district level!
gen lenr4=ln(enr4)
xtivreg2 lenr4 (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_* if outl==0 & schmgt<4 & scc==0, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/dise_enr4, replace wide 10pct bracket dec(3) fmt(g) 


