*******************************************************
* TEACHER LEVEL FILE FOR DATA PROCESSING AND ANALYSIS * 
*******************************************************
* ALSO GENERATES A DISTRICT PANEL FROM TEACHER DATA ***
*******************************************************
** DEPENDS ON:
* STEPS_TEACHER_clean_fix.dta (DISE_prepare_Dec13.do -> Fix_Teachers_Dec13.do) 
* turnover_schools_primaries.dta (turnover_schools_Dec13.do)
* (/tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix)
*
* OUTPUTS: Figure 2, Table 1, Table 4 columns 1 and 5, Appendix Table A3, Table 11, Appendix Table X2, Table 5
* /tera1/IndiaTeachers/Politicalcycle/districtexitrates2.dta
* /tera1/IndiaTeachers/Politicalcycle/exitvolatility.dta

* Updated: 21.6.2017 
*************************
* CREATE THE BASIC FILE *
*************************
clear
set memory 12g
use /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER_clean_fix.dta
drop tchcd

* RESTRICT TO PRIMARY SCHOOLS
sort schcd ac_year
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/turnover_schools_primaries.dta,keep(schmgt highclass)
tab _merge 
keep if _merge==3
compress
drop _merge

* SET SAMPLE OF INTEREST
* Primary schools and teachers who declare working in one.
* possibly keep cls_taught==5 ("Not sure")
keep if schmgt<=3 & (cls_taught==1|cls_taught==3|cls_taught==5)

* MERGE SCHOOL LEVEL VARIABLES (Decide here what school resources are needed!)
sort schcd ac_year
*merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/turnover_schools_primaries-fxsplit.dta,keep(scc scss schname constcd constname disthq distcrc noinspect tchsan tchpos parapos urban schmgt schtype schcat conti_r tlm_r funds_r osrc_r schmntcgrant_r tle_r conti_e tlm_e funds_e osrc_e schmntcgrant_e tle_e enr1 enr2 enr3 enr4 enr5 enr1g enr2g enr3g enr4g enr5g enr1c enr2c enr3c enr4c enr5c enr_g enr_c bld_wcg bld_lib bld_crmaj bld_playg bld_medic bld_qpucca inc_txtg inc_txtc inc_unig inc_unic c5enr bld_wc bld_elec bld_none bld_watno)
merge schcd ac_year using /tera1/DISE_Dec13/DISE_clean_Dec13/turnover_schools_primaries.dta,keep(scc scss schname constcd constname disthq distcrc noinspect tchsan tchpos parapos urban schmgt schtype schcat conti_r tlm_r funds_r osrc_r schmntcgrant_r tle_r conti_e tlm_e funds_e osrc_e schmntcgrant_e tle_e enr1 enr2 enr3 enr4 enr5 enr1g enr2g enr3g enr4g enr5g enr1c enr2c enr3c enr4c enr5c enr_g enr_c bld_wcg bld_lib bld_crmaj bld_playg bld_medic bld_qpucca inc_txtg inc_txtc inc_unig inc_unic c5enr bld_wc bld_elec bld_none bld_watno c1_* c2_* c3_* c4_* c5_*)
tab _merge
keep if _merge==3
drop _merge

******************************************************
* SAVE BASIC FILE FOR LOWER PUBLIC PRIMARY TEACHERS **
******************************************************
* See restrictions above for what this contains
saveold /tera1/DISE_Dec13/DISE_clean_Dec13/teachers_public0511nofx,replace

***********************
* BEGIN DATA CLEANING * 
***********************
use /tera1/DISE_Dec13/DISE_clean_Dec13/teachers_public0511nofx,clear

#delimit ; 
label define statex 1 Jammu 2 Himachal 3 Punjab 4 Chandigarh 5 Uttarakhand 6 Haryana 7 Delhi 8 Rajastan 9 Uttarpradesh 
10 Bihar 11 Sikkim 12 Arunachal 13 Nagaland 14 Manipur 15 Mizoram 16 Tripura 17 Meghalaya 18 Assam 19 WestBengal 
20 Jharkand 21 Orissa 22 Chattisgarh 23 MadhyaPradesh 24 Gujarat 25 DamanDiu 26 DadraNagar 27 Maharashtra
28 AndhraPradesh 29 Karnataka 30 Goa 31 Lakshadweep 32 Kerala 33 Tamilnadu 34 Ponicherry 35 Andaman;
#delimit cr
label var state statex

* DATE OF BIRTH INFO MISSING
gen nod=0
replace nod=1 if doby==.
egen nods=mean(nod),by(schcd)
gen misdob = nods>0 & nods~=.
drop nods
label var nod "DOB missing"
label var misdob "School(code) has a teacher with missing DOB in ANY year"

* CLUMPINESS OF BIRTH DATE
* check % born on 1st day of month
gen cld= dobd==1
label var cld "Reported to be born on 1st day of month"

* DROP TINY STATES (NO MORE)
* set min of 100.000 obs in the 2005-2011
egen obs=count(ac_year),by(state)
*drop if obs<100000
*drop obs
** DROP DELHI & Tripura
*drop if state==7|state==16
** keeps 20 states

* TEACHER IDENTIFIER
egen tchid=group(schcd dob sex) 
* Identical ppl in the same year?
sort state schcd tchid ac_year
count if tchid==tchid[_n-1] & ac_year==ac_year[_n-1]
gen doub_=1 if tchid==tchid[_n-1] & ac_year==ac_year[_n-1]
egen doub=mean(doub_),by(tchid)
replace doub=0 if doub==.
* These have to be dropped for the analysis to work

* see these to assess quality of birthdate data
set logtype text
log using /tera1/IndiaTeachers/Gender/samplequality0511nofx.txt,replace
ge yob=1900+doby
ge age=ac_year-yob
gen byte lcaste = caste>1 & caste<6
gen ed_g = qual_acad>=4 &qual_acad<=6
gen female=sex-1
su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4
* Incl 2005
su ac_year female age lcaste ed_g if ac_year<=2011 & age>=18 & age<=55 & category<4
* Must drop if doub==1
* Other issues can be lived with
su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4 & doub==1
su ac_year female age lcaste ed_g if ac_year<=2011 & age>=18 & age<=55 & category<4 & doub==1

drop if doub==1

su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4
* Incl 2005
su ac_year female age lcaste ed_g if ac_year<=2011 & age>=18 & age<=55 & category<4
drop age yob lcaste ed_g female
log close

* TEACHER EXIT DUMMY (within school only)
sort schcd tchid ac_year
gen disap=0 if schcd==schcd[_n+1] & tchid==tchid[_n+1] & ac_year<ac_year[_n+1]
* now set it to 1 unless the last year of the school
egen lastyr=max(ac_year),by(schcd)
replace disap=1 if disap==. & ac_year~=lastyr
label var disap "Teacher disappears the next year (from the school)"
* Appearing teacher
egen firye=min(ac_year),by(schcd)
gen appear=0 if schcd==schcd[_n-1] & tchid==tchid[_n-1] & ac_year>ac_year[_n-1]
* set to 1 unless 1st year of the school
replace appear=1 if appear==. & ac_year!=firye
label var appear "Teacher appears for the 1st year (in the school)"

* OUTLIER INDICATOR
ge byte outl=0

* CODE VARS: INDIVIDUAL
gen byte female = sex==2
* yoj may have errors - take mode for each person
egen yojm=mode(yoj),by(tchid) maxmode
ge yob=1900+doby
ge age=ac_year-yob
gen tenure = ac_year-yojm
replace outl=1 if tenure<0
replace outl=1 if age-tenure<18
label var tenure "Years as teacher"
gen byte lcaste = caste>1 & caste<6
label var lcaste "SC/SC/OBC caste"
gen ed_g = qual_acad>=4 &qual_acad<=6
gen ed_pg = qual_acad>=5 &qual_acad<=6
label var ed_pg "Postgraduate (MSc/PhD)"
label var ed_g "Graduate (BSc etc)"
gen head = category<3
label var head "Head or acting head"
gen para = category == 4
label var para "Para-teacher"
gen byte math_g = math_upto>=4 & math_upto<=6
gen byte math_s = math_upto==3
gen byte eng_g = eng_upto>=4 & eng_upto<=6
gen byte eng_s = eng_upto==3
label var math_g "Maths to university level"
label var math_s "Maths to higher secondary level"
label var eng_g "English to university level"
label var eng_s "English to higher secondary level"
* Traning days (have already been capped to 365)
gen trn= trn_brc+ trn_crc+ trn_diet+ trn_other
replace outl=1 if trn>365 & trn~=.
drop trn
label var trn_diet "Training days at DIET"
label var trn_crc "Training days at CRC"
label var trn_brc "Training days at BRC"
label var trn_other "Training days at OTHER"
label var nontch_ass "Days in non-teaching assignments"

* Teacher caste & gender match
gen byte camatch=1 if (enr_c>=0.5 & enr_c~=. & lcaste==1)|(enr_c<0.5 & lcaste==0)
replace camatch=0 if (enr_c>=0.5 & enr_c~=. & lcaste==0)|(enr_c<0.5 & lcaste==1)
gen byte gematch=1 if (enr_g>=0.5 & enr_g~=. & female==1)|(enr_g<0.5 & female==0)
replace gematch=0 if (enr_g>=0.5 & enr_g~=. & female==0)|(enr_g<0.5 & female==1)
label var camatch "Teacher caste matches pupil majority"
label var gematch "Teacher gender matcheses pupil majority"

gen int yrsins = ac_year-workingsince
replace outl=1 if yrsins<0
replace outl=1 if yrsins>ac_year-1900-doby-17 & yrsins~=.
gen yrsins2=yrsins^2
label var yrsins "Years in current school"
label var yrsins2 "Years in current school, squared"


* CODE VARS: SCHOOL

* Some enrolment figures don't make sense. Shave 0.5% from enrollment figures for classes 1-4.
foreach var of varlist enr1 enr2 enr3 enr4 enr5 {
quietly su `var',d
gen top1=r(p99)
quietly su `var' if `var'>top1,d
replace outl=1 if `var'>r(p50) & `var'~=.
drop top1
}
gen enr=enr1+enr2+enr3+enr4+enr5
gen lenr=ln(enr)
label var lenr "Ln Enrollment in grades 1-5"
egen disthqm=mean(disthq),by(schcd)
label var disthqm "Distance to district HQ (mean)"
drop disthq
* set top 0.5% as outliers
quietly su  disthqm ,d
gen top1=r(p99)
quietly su disthqm if disthqm>top1,d
replace outl=1 if disthqm>r(p50) & disthqm~=.
drop top1

compress

* Pupils by precise caste
* Note: Teacher level file!
gen enr_gen=c1_gb+c1_gg+c2_gb+c2_gg+c3_gb+c3_gg+c4_gb+c4_gg+c5_gb+c5_gg
gen enr_scn=c1_cb+c1_cg+c2_cb+c2_cg+c3_cb+c3_cg+c4_cb+c4_cg+c5_cb+c5_cg
gen enr_stn=c1_tb+c1_tg+c2_tb+c2_tg+c3_tb+c3_tg+c4_tb+c4_tg+c5_tb+c5_tg
gen enr_obn=c1_ob+c1_og+c2_ob+c2_og+c3_ob+c3_og+c4_ob+c4_og+c5_ob+c5_og
gen enr_otn=c1_oth1b+c1_oth1g+c2_oth1b+c2_oth1g+c3_oth1b+c3_oth1g+c4_oth1b+c4_oth1g+c5_oth1b+c5_oth1g+c1_oth2b+c1_oth2g+c2_oth2b+c2_oth2g+c3_oth2b+c3_oth2g+c4_oth2b+c4_oth2g+c5_oth2b+c5_oth2g+c1_oth3b+c1_oth3g+c2_oth3b+c2_oth3g+c3_oth3b+c3_oth3g+c4_oth3b+c4_oth3g+c5_oth3b+c5_oth3g
gen enr_alt=enr_gen+enr_scn+enr_stn+enr_obn+enr_otn
su enr enr_alt
su enr enr_alt if outl!=1
* very good!
label var enr_gen "Genral caste pupils grade 1-5"
label var enr_scn "SC caste pupils grade 1-5"
label var enr_stn "ST caste pupils grade 1-5"
label var enr_obn "OB caste pupils grade 1-5"
label var enr_otn "Other caste pupils grade 1-5"
label var enr_alt "Total pupils grade 1-5"
drop c?_*

* School management
gen mgt_tribal = schmgt==2
gen mgt_local = schmgt==3
label var mgt_tribal "School management: Tribal"
label var mgt_local "School management: Local"
* School category 
gen cat_pup = schcat==2
gen cat_pups = schcat==3
label var cat_pup "School includes Upper Primary"
label var cat_pups "School includes Upper Pri. and Sec."
* Pupil teacher ratio
* note that enr is for year 1-5 only
* tchpos & parapos refer to whole school which may include upper primary
* Thus count only teachers in the dataset
egen tchpos2_=count(schcd) if para==0,by(schcd ac_year)
egen tchpos2=mean(tchpos2_),by(schcd ac_year)
egen parapos2_=count(schcd) if para==1,by(schcd ac_year)
egen parapos2=mean(parapos2_),by(schcd ac_year)
replace tchpos2=0 if tchpos2==.
replace parapos2=0 if parapos2==.
label var tchpos2 "# of (normal) lower-primary teachers in teacher data"
label var parapos2 "# of lower-primary para-teachers in teacher data" 
gen puptch=enr/(tchpos+parapos)
gen puptch2=enr/(tchpos2+parapos2)
* set top 0.5% missing, some appear to be unrealistic
quietly su puptch,d
gen top1=r(p99)
quietly su puptch if puptch>top1,d
replace outl=1 if puptch>r(p50) & puptch~=.
drop top1
quietly su puptch2,d
gen top1=r(p99)
quietly su puptch2 if puptch2>top1,d
replace outl=1 if puptch2>r(p50) & puptch2~=.
drop top1
label var puptch "enr/(tchpos+parapos)"
label var puptch2 "enr/(tchpos2+parapos2)"
* Share of parateachers
gen paras=parapos/(tchpos+parapos)
gen paras2=parapos2/(tchpos2+parapos2)
label var paras "% teachers parateachers in school"
label var paras2 "% teachers parateachers in school (parapos2,tchpos2)"
* Single teacher school
gen byte singlet = tchpos==1 & parapos==0
label var singlet "Single teacher school (and no parateachers)"

set logtype text
log using /tera1/IndiaTeachers/Gender/samplequality0511nofx.txt,append
su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4 
su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4 & outl==1
su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2011 & age>=18 & age<=55 & category<4 & outl==0
su ac_year female age lcaste ed_g if ac_year>2005 & ac_year<=2010 & age>=18 & age<=55 & category<4 & outl==0
* incl 2005
su ac_year female age lcaste ed_g if ac_year<=2011 & age>=18 & age<=55 & category<4 
su ac_year female age lcaste ed_g if ac_year<=2011 & age>=18 & age<=55 & category<4 & outl==1
su ac_year female age lcaste ed_g if ac_year<=2011 & age>=18 & age<=55 & category<4 & outl==0
su ac_year female age lcaste ed_g if ac_year<=2010 & age>=18 & age<=55 & category<4 & outl==0

log close 

saveold /tera1/DISE_Dec13/DISE_clean_Dec13/teachers_public_reg0511nofx,replace


********************************************
*** POLITICAL CYCYLES AND TEACHER TURNOVER *
********************************************
clear
use /tera1/DISE_Dec13/DISE_clean_Dec13/teachers_public_reg0511nofx
gen newtch=1 if yojm==ac_year
replace newtch=0 if newtch==.
label var newtch "Teacher recruited this year"
tab ac_year, ge(yd)

* HERE: Drop unnecessary vars since heavy on memory 
drop yoj qual_acad qual_prof cls_taught main_taught1 math_upto eng_upto scienceupto appointsub stream name1 name2 distname highclass schname distcrc conti_r conti_e tlm_r tlm_e funds_e funds_r osrc_e osrc_r schmntcgrant_r schmntcgrant_e tle_r tle_e constname enr1 enr1c enr1g enr2 enr2c enr2g enr3 enr3c enr3g enr4 enr4c enr4g enr5 enr5c enr5g doub_ doub tchpos2_ parapos2_ 
drop constcd 
keep if outl==0 
keep if ac_year>=2005
* ~3 GB

**** MERGE POLITICAL EVENTS ****
rename ac_year year
* Lag the year to apply the new political result to the *post-election* year
replace year=year-1
sort distcd year
merge distcd year using /tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix
replace year=year+1
rename year ac_year
drop if _merge==2
drop _merge

* state trends
foreach num of numlist 1/35 {
capture gen st_`num'=0
capture replace st_`num'=ac_year if state==`num'
}

* ed5 is the election year here (see the year lag above)
* ed1 is the 1st post-election year
quietly tab elecyr, ge(ed)
quietly tab eleciv, ge(iv)

tis ac_year
iis schcd

** Indicator on whether may have started in the mid of last year
*gen break=0 if appear==1 & workingsince==ac_year 
*replace break=1 if appear==1 & workingsince==ac_year-1
** workingsince has many missings 0.5 mil out of 2.7 mil
*count if appear==1 & workingsince!=.
*count if appear==1 & workingsince==.


gen trn_any=trn_brc+trn_crc+trn_diet+trn_other

* make space
drop slno blkcd  schcat schtype nod misdob cld tchid lastyr firye dob* enr_gen-cat_pups CFiv1-CFiv2b ivfem1-ivfem27 tchsan-c5enr math_g-lenr
keep if category<=4 & outl==0 & age<=55 & age>=18
* more space see if need some of them
drop paras paras2 state2 month sparty saligns dturnout dturnoutpre
* still more space
drop obs yojm yob head tchpos2 parapos2 puptch singlet fems resst ressc nontch_ass qual_prof_d
compress

* Caste dummies
gen byte ca_sc = caste == 2
gen byte ca_st = caste == 3
gen byte ca_ob = caste == 4|caste==5|caste==6

* balanced panel (by school 2005-2011)
gen schi_=1 if ac_year==2005
egen schi=mean(schi_),by(schcd)
replace schi_=2 if ac_year==2006 & schi==1
drop schi
egen schi=max(schi_),by(schcd)
replace schi_=3 if ac_year==2007 & schi==2
drop schi
egen schi=max(schi_),by(schcd)
replace schi_=4 if ac_year==2008 & schi==3
drop schi
egen schi=max(schi_),by(schcd)
replace schi_=5 if ac_year==2009 & schi==4
drop schi
egen schi=max(schi_),by(schcd)
replace schi_=6 if ac_year==2010 & schi==5
drop schi
egen schi=max(schi_),by(schcd)
replace schi_=7 if ac_year==2011 & schi==6
drop schi
egen schi=max(schi_),by(schcd)
* balanced if schi==7

gen bef = ed3==1|ed4==1
gen aft = ed1==1|ed2==1

* Save
save /tera1/IndiaTeachers/ResourceCycle/cycle_tch_reg.dta,replace
use /tera1/IndiaTeachers/ResourceCycle/cycle_tch_reg.dta,clear


***** Event study Graphs (Figure 2) based on 4 regressions ******
** Election year dummies, full data and balanced panel
*(1) xtreg disap ed3 ed4 ed1 ed2 yd* if category<4 & outl==0 & age<=55 & age>=18, fe cluster(state)
*(2) xtreg disap ed3 ed4 ed1 ed2 yd* if category<4 & outl==0 & age<=55 & age>=18 & schi==7, fe cluster(state)
** 2-year dummies, full data and balanced panel
*(3) xtreg disap bef aft yd* if category<4 & outl==0 & age<=55 & age>=18, fe cluster(state)
*(4) xtreg disap bef aft yd* if category<4 & outl==0 & age<=55 & age>=18 & schi==7, fe cluster(state)
do eventgraphs.do

* SUMMARY STATS (Table 1)
quietly reg disap iv1 iv2 iv4 iv5 yd* if category<4 & outl==0 & age<=55 & age>=18
set logtype text
log using /tera1/IndiaTeachers/ResourceCycle/sumstats_tch.txt,replace
su disap female age tenure ed_g ca_sc ca_st ca_ob newtch ed1 ed2 ed3 ed4 ed5 if e(sample), sep(0)
* Balanced panel
quietly reg disap iv1 iv2 iv4 iv5 yd* if category<4 & outl==0 & age<=55 & age>=18 & schi==7
su disap female age tenure ed_g ca_sc ca_st ca_ob newtch ed1 ed2 ed3 ed4 ed5 if e(sample), sep(0)
log close

*** Table for the paper (Table 4 column 1)
* Turnout
xtivreg2 disap (ed1 ed2 ed4 ed5 = iv1 iv2 iv4 iv5) yd* st_* if category<4 & outl==0 & age<=55 & age>=18, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/exit_elec, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)

*** Appendix: Turnover effects by urban/rural (Appendix Table A3)
xtivreg2 disap (ed1 ed2 ed4 ed5 = iv1 iv2 iv4 iv5) yd* st_* if category<4 & outl==0 & age<=55 & age>=18 & urban==0, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/exit_elec_rur, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
xtivreg2 disap (ed1 ed2 ed4 ed5 = iv1 iv2 iv4 iv5) yd* st_* if category<4 & outl==0 & age<=55 & age>=18 & urban==1, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/exit_elec_urb, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)

*** Characteristics of teachers transfered after the election (Table 11)
* median PT ratio in each dist*year
egen mpt=median(puptch2),by(ac_year distcd)
* Schools with a surplus of teachers
gen surp = 1 if puptch2<mpt
replace surp=0 if  puptch2>=mpt & puptch2!=.
* Table 11
iis distcd
xtivreg2 female ed1 (ed1 ed2 ed4 ed5 = iv1 iv2 iv4 iv5) yd* st_* if disap==1 & category<4 & outl==0 & age<=55 & age>=18,fe cluster(state) 
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_chars, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
foreach var of varlist tenure ed_g lcaste urban disthqm surp {
xtivreg2 `var' ed1 (ed1 ed2 ed4 ed5 = iv1 iv2 iv4 iv5) yd* st_* if disap==1 & category<4 & outl==0 & age<=55 & age>=18,fe cluster(state) 
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_chars, append wide 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
}
** Average chars of all teachers (not used)
*xtivreg2 female ed1 (ed1 ed2 ed4 ed5 = iv1 iv2 iv4 iv5) yd* st_* if category<4 & outl==0 & age<=55 & age>=18,fe cluster(state) 
*outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_chars_all, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
*foreach var of varlist tenure ed_g lcaste {
*xtivreg2 `var' ed1 (ed1 ed2 ed4 ed5 = iv1 iv2 iv4 iv5) yd* st_* if category<4 & outl==0 & age<=55 & age>=18,fe cluster(state) 
*outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_chars_all, append wide 10pct bracket dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
*}


* MLA caste and transfers of teachers (Table X2, Appendix)
* then check if the proportion of low caste MLAs rise / fall
* In politics OBCs are considered General caste, since don't have quotas in Assmebly Elections
* Thus pool all teacher castes together unless they are SC or ST, and treat them separately 
gen pge=1-psc-pst
gen ed1t=ed1*pst
gen ed1c=ed1*psc
gen ed1g=ed1*pge

su psc pst if category<4 & outl==0 & age<=55 & age>=18
* Regressions (Appendix Table X2)
xtreg disap ed1 ed1c ed1t ed2 ed4 ed5 psc pst yd* if category<4 & outl==0 & age<=55 & age>=18 & caste!=2 & caste!=3, fe cluster(state) 
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_st2, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1c ed1t ed2 ed4 ed5 psc pst)
xtreg disap ed1 ed1c ed1t ed2 ed4 ed5 psc pst yd* if category<4 & outl==0 & age<=55 & age>=18 & caste==2, fe cluster(state) 
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_st2, append wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1c ed1t ed2 ed4 ed5 psc pst)
xtreg disap ed1 ed1c ed1t ed2 ed4 ed5 psc pst yd* if category<4 & outl==0 & age<=55 & age>=18 & caste==3, fe cluster(state) 
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_st2, append wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1c ed1t ed2 ed4 ed5 psc pst)

* New leading party and political alignment (Table 5)
gen ed1n=ed1*newrule
gen ed1a=ed1*aligns
gen ed1d=ed1*dbigch

xtreg disap ed1 ed1n ed2 ed4 ed5 newrule yd* if category<4 & outl==0 & age<=55 & age>=18, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_pol, replace wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1n ed2 ed4 ed5 newrule)
su newrule if e(sample)
xtreg disap ed1 ed1a ed2 ed4 ed5 aligns yd* if category<4 & outl==0 & age<=55 & age>=18, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_pol, append wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1a ed2 ed4 ed5 aligns)
su aligns if e(sample)
xtreg disap ed1 ed1d ed2 ed4 ed5 dbigch yd* if category<4 & outl==0 & age<=55 & age>=18, fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/disap_pol, append wide 10pct bracket dec(3) fmt(g) keep(ed1 ed1d ed2 ed4 ed5 dbigch)
su dbigch if e(sample)

************************************
*** District Exit rates and others *
************************************
clear
use /tera1/DISE_Dec13/DISE_clean_Dec13/teachers_public_reg0511nofx
drop if outl==1
keep if age>=18 & age<=55
keep if category<4
keep ac_year distcd disap appear workingsince tchpos2 parapos2 single
* Indicator on whether may have started in the mid of last year
gen break=0 if appear==1 & workingsince==ac_year 
replace break=1 if appear==1 & workingsince==ac_year-1
** Some averages over the whole time series, for split sample analysis
* mean break per district
egen mbreak=mean(break),by(distcd)
* mean single teacher schools and mean number of teachers per school 
egen msingle=mean(single),by(distcd)
egen mtchpos2=mean(tchpos2),by(distcd)
* sample medians: mbreak .2895753, msingle .0247062, 3.421663 
* workingsince has many missings 0.5 mil out of 2.7 mil
collapse (mean) disap mbreak msingle mtchpos2,by(ac_year distcd)
sort ac_year distcd 
saveold /tera1/IndiaTeachers/Politicalcycle/districtexitrates2.dta,replace

*********************
* DISTRICT DATA SET *
*********************
clear
use /tera1/DISE_Dec13/DISE_clean_Dec13/teachers_public_reg0511nofx
tab ac_year, ge(yd)
gen diyr=distcd*100+(ac_year-2000)

* Numbers of teachers by district-year cells
gen newtch=1 if yojm==ac_year & category<4
gen newtch_p=1 if yojm==ac_year & category==4
egen newtchn=sum(newtch),by(diyr)
egen newtchn_p=sum(newtch_p),by(diyr)
egen tchn_=count(ac_year) if category<4,by(diyr)
egen tchn=mean(tchn_),by(diyr)
egen tchn_p_=count(ac_year) if category==4,by(diyr)
egen tchn_p=mean(tchn_p_),by(diyr)
drop tchn_ tchn_p_
label var newtchn "# Teachers (formal) recruited this year (dist,yr)"
label var newtchn_p "# Para-teachers recruited this year (dist,yr)"
label var tchn "# Teachers (formal) (dist,yr)"
label var tchn_p "# Para-teachers (dist,yr)"

************************
**** POLITICAL DATA **** 
************************
rename ac_year year
* match politics to schools so that 2008 election result is matched to 2009-2010 DISE (ie 2008-2009 data changes)
* for newest DISE 2011-12 we need election result 2010 (got upto 2012)
replace year=year-1
sort distcd year
merge distcd year using /tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix
replace year=year+1
rename year ac_year
drop if _merge==2
drop _merge

*********************
**** CENSUS DATA **** 
*********************
* Note, comes in 2011 district structure! -> imperfect match!
sort distcd
merge distcd using "/tera1/IndiaTeachers/Census/districts2011.dta"
drop if _merge==2
drop _merge


*************************
*** ENROLMENT, PT-RATIO *
*************************
* drop old ones 
drop enr lenr puptch puptch2
gen tch=parapos2+tchpos2
gen enr=enr1+enr2+enr3+enr4
replace enr=enr+enr5 if state!=15 & state!=17 & state!=18 & state!=19 & state!=24 & state!=25 & state!=26 & state!=27 & state!=29 & state!=30 & state!=32 
gen pt=enr/tch
replace pt=. if enr==0|tch==0
gen pt_nopara=enr/tchpos2
replace pt_nopara=. if enr==0|tchpos2==0
su pt pt_nopara if outl==0

* HERE: Drop unnecessary vars since mem & disk runs out
drop yoj qual_acad qual_prof cls_taught main_taught1 math_upto eng_upto nontch_ass workingsince scienceupto appointsub stream name1 name2 distname highclass schname distcrc conti_r conti_e tlm_r tlm_e funds_e funds_r osrc_e osrc_r schmntcgrant_r schmntcgrant_e tle_r tle_e constname enr1 enr1c enr1g enr2 enr2c enr2g enr3 enr3c enr3g enr4 enr4c enr4g enr5 enr5c enr5g doub_ doub tchpos2_ parapos2_ 

* Total training days (paras dropped earlier)
gen trn_anyf=trn_brc+trn_crc+trn_diet+trn_other if category<4
*gen trn_anyp=trn_brc+trn_crc+trn_diet+trn_other if category==4
egen dtrnf=sum(trn_anyf),by(diyr)

gen casg = 1 if caste==1 & category<4
gen casc = 1 if caste==2 & category<4
gen cast = 1 if caste==3 & category<4
gen caso = 1 if caste>=4 & category<4
gen female_f = 1 if female==1 & category<4
foreach var of varlist casg casc cast caso female_f {
replace `var'=0 if category<4 & `var'==.
}

* I used to constrain this to ages 18-55 but there is no reason to do it?
keep if category<4 & outl==0 & ac_year>=2005
* ~4 GB

* more variables? % in castes [do not compute district enrolment from teacher level data!]
collapse (sd) disthqm_sd=disthqm (mean) elecyr eleciv aligns newrule CFiv1 CFiv2 fems resst ressc newtchn* dtrn? tchn tchn_p female_f lcaste casg casc cast caso state distcd ac_year splitter disthqm urban paras durban dlit_f dsexratio dsc dst diff_lit ,by(diyr)
label var newtchn "# Teachers (formal) recruited this year (dist,yr)"
label var newtchn_p "# Para-teachers recruited this year (dist,yr)"
label var tchn "# Teachers (formal) (dist,yr)"
label var tchn_p "# Para-teachers (dist,yr)"
save /tera1/IndiaTeachers/Gender/districtset.dta,replace

**********************************************************
* ELECTION CYCLE AND DISTRICT LEVEL TEACHER RECRUITEMENT *
**********************************************************
use /tera1/IndiaTeachers/Gender/districtset.dta,clear

gen newtcha=newtchn+newtchn_p

tab elecyr,ge(ed)
tab eleciv,ge(iv)
tab ac_year,ge(yd)
foreach num of numlist 1/35 {
capture gen st_`num'=0
capture replace st_`num'=ac_year if state==`num'
}
tis ac_year
iis distcd

* New teacher hires at district level (Table 4 column 5)
set logtype text 
log using /tera1/IndiaTeachers/ResourceCycle/dise_new_log.txt,replace
xtivreg2 newtcha (ed4 ed5 ed1 = iv4 iv5 iv1) ed2 yd* st_*,fe cluster(state)
outreg2 using /tera1/IndiaTeachers/ResourceCycle/dise_new, replace wide 10pct bracket dec(3) fmt(g) 
log close

****************************************************
*** Index of turnover volatility by election year **
****************************************************
use /tera1/IndiaTeachers/Gender/districtset.dta,clear
tab elecyr,ge(ed)
tab eleciv,ge(iv)
tab ac_year,ge(yd)
tis ac_year
iis distcd
sort ac_year distcd 
merge ac_year distcd using /tera1/IndiaTeachers/Politicalcycle/districtexitrates2.dta
*only dists for which all year present
sort distcd ac_year 
egen pob=count(distcd),by(distcd)
keep if pob==7
codebook distcd if elecyr!=. & pob!=. 
* 572 dists should be included
* Excess training in P1 phase
gen trnf=dtrnf/tchn
*gen trnp=dtrnp/tchn_p
gen cod1=.
gen trd1=.
levelsof distcd, local(ds)
foreach dis of local ds {
* (1) disap effect by election dummy only 
quietly capture reg disap ed1 if distcd==`dis'
quietly capture replace cod1=_b[ed1] if distcd==`dis'
* (2) training effect by election dummy only 
quietly capture reg trnf ed1 if distcd==`dis'
quietly capture replace trd1=_b[ed1] if distcd==`dis'
}
* exclude dists for which not estimated (ie the same result reprinted)
replace cod1=. if cod1==cod1[_n-1] & distcd!=distcd[_n-1] & distcd!=. & distcd[_n-1]!=.
replace trd1=. if trd1==trd1[_n-1] & distcd!=distcd[_n-1] & distcd!=. & distcd[_n-1]!=.
label var cod1 "Excess teacher turnover explained by the Post-election year"
label var trd1 "Excess teacher training explained by the Post-election year"
* save file
keep ac_year distcd disap cod1 trd1
sort distcd ac_year
save /tera1/IndiaTeachers/Politicalcycle/exitvolatility.dta,replace

