
*ANALYSIS OF POLITICAL CYCLE
*
*INPUTS:
*/tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER_clean_fix.dta
*/tera1/DISE_Dec13/DISE_clean_Dec13/turnover_schools_primaries.dta (turnover_schools_Dec13.do)
*/tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix (appendelec.do)


*OUTPUTS:
*/tera1/IndiaTeachers/Turnover/pritchlist.dta
*/tera1/IndiaTeachers/Turnover/polcycle_all.dta 
*/tera1/IndiaTeachers/Turnover/polcycle_reg.dta 
*
*updated: 21.10.2015 

clear
*set mem 12g
set more off
**********************
**** TEACHER DATA ****
**********************
* Get numbers of teachers who teach at primary level 
use qual_acad eng_upto math_upto cls_taught schcd ac_year category sex caste trn* nontch_ass using /tera1/DISE_Dec13/DISE_clean_Dec13/STEPS_TEACHER_clean_fix.dta 
drop if ac_year>2011
gen tchpri=1 if cls_taught==1|cls_taught==3
gen tchpri_nopara=1 if tchpri==1 & category<4 
gen paratch_pri=1 if tchpri==1 & category==4 
gen female=1 if sex==2
replace female=0 if sex==1
gen female_pri=1 if sex==2 & tchpri==1
replace female_pri=0 if sex==1 & tchpri==1
* Training & non-teaching
gen ed_g = qual_acad>=4 &qual_acad<=6
gen byte math_g = math_upto>=4 & math_upto<=6
gen byte eng_g = eng_upto>=4 & eng_upto<=6
replace math_upto=. if math_upto>6
replace eng_upto=. if eng_upto>6
gen trn_any=trn_brc+trn_crc+trn_diet+trn_other
gen trnnon=trn_any+nontch_ass
replace trn_any=. if trn_any>365
replace trnnon=. if trnnon>365
* HEADTEACHER GENDER, CASTE
gen head=1 if category==1
egen headn=sum(head), by(schcd ac_year)
replace headn=2 if headn>2 & headn!=.
gen heada=1 if category==2
egen headan=sum(heada), by(schcd ac_year)
replace headan=2 if headan>2 & headan!=.
gen head_f_ = category==1 & headn==1 & sex==2
egen head_f=max(head_f_),by(schcd ac_year)
gen head_af_ = category==2 & headan==1 & sex==2
egen head_af=max(head_af_),by(schcd ac_year)
gen head_c_ = head==1 & headn==1 & caste~=1 & caste~=.
egen head_c=max(head_c_),by(schcd ac_year)
drop head
* Teacher caste for primary teachers
gen tlcaste=0 if caste==1 & tchpri==1
replace tlcaste=1 if caste>1 & caste<=11 & tchpri==1 & category<4
gen ttcaste=1 if caste==3 & tchpri==1
replace ttcaste=0 if caste<=11 & caste!=3 & tchpri==1 & category<4
* Teacher gender for primary teachers
gen tfemale=female if tchpri==1 & category<4

collapse (count) tchpri tchpri_nopara paratch_pri (mean) tlcaste ttcaste tfemale ed_g eng_g math_g math_upto eng_upto trn_any nontch_ass trnnon headn headan head_f head_af head_c female female_pri,by(schcd ac_year)
*Three obs are clear outliers
drop if tchpri>1000 & tchpri~=.
label var tchpri "# of teachers who teach (lower) primary (incl para)"
label var tchpri_nopara "# of teachers who teach (lower) primary (excl para)"
label var paratch_pri "# of teachers who teach (lower) primary (para only)"
label var headn "Headteacher 0=no, 1=one, 2=2+"
label var headan "Acting Headteacher 0=no, 1=one, 2=2+"
label var head_f "Headteacher female"
label var head_af "Acting Headteacher female"
label var head_c "Headteacher SC/ST/OB/Other"
label var ed_g "Graduate (BSc etc)"
label var math_g "Maths to university level"
label var eng_g "English to university level"
label var trn_any "Avg. Training days (in any place)"
label var nontch_ass "Avg. Non-teaching assignment days"
label var trnnon "Avg. training or nonteaching days"
label var female "% of teachers who are female (incl paras, incl nonprimary teachers) (by schcd ac_year)"
label var female_pri "% of primary teachers who are female (incl paras) (by schcd ac_year)"
label var tlcaste "% primary teachers SC/ST/OB caste (excl paras)"
label var ttcaste "% primary teachers Scheduled Tribe caste (excl paras)"
label var tfemale "% primary teachers female (excl paras)"
sort schcd ac_year 
saveold /tera1/IndiaTeachers/Turnover/pritchlist.dta,replace


*********************
**** SCHOOL DATA ****
*********************
use /tera1/DISE_Dec13/DISE_clean_Dec13/turnover_schools_primaries.dta,clear
drop if ac_year>2011
sort schcd ac_year 
merge schcd ac_year using /tera1/IndiaTeachers/Turnover/pritchlist.dta
* The schools dropped here are not officially primary schools (by schcat), but claim to have teachers who teach primary (by cls_taught)
* 200.000 per year. 
drop if _merge==2
drop _merge

gen outl=.
label var outl "Outliers"

* Some enrolment figures don't make sense. Shave 0.5% from enrollment figures for classes 1-5.
foreach var of varlist enr1 enr2 enr3 enr4 enr5 {
quietly su `var',d
gen top1=r(p99)
quietly su `var' if `var'>top1,d
replace outl=1 if `var'>r(p50) & `var'~=.
drop top1
}


*tab state if enr3>0 & enr4>0 & enr5==0 & enr3!=. & enr4!=. & enr5!=.
*tab state if enr3>0 & enr4>0 & enr5>0 & enr3!=. & enr4!=. & enr5!=.
* compute ratio: (schools where pupils in 3 and 4 but not in 5 / schools where pupils in 3,4,5)
* Ratio always either below 0.2 or above 1 (former has 5 years lower primary, latter 4 years)
* States with 4 years lower primary: 13 15 17 18 19 25 26 27 30 32
***! KG tells me DISE report says that it's states = 15 17 18 19 24 25 26 27 29 30 32

* lower primary enrolment
gen enr=enr1+enr2+enr3+enr4
replace enr=enr+enr5 if state!=15 & state!=17 & state!=18 & state!=19 & state!=24 & state!=25 & state!=26 & state!=27 & state!=29 & state!=30 & state!=32 
gen lenr=ln(enr)
label var lenr "Ln Enrollment in grades 1-4/5"
egen disthqm=mean(disthq),by(schcd)
label var disthqm "Distance to district HQ (mean)"
drop disthq
compress

* DPEP funds

** set top 0.5% of positive numbers to outliers.
foreach var of varlist conti_r tlm_r funds_r osrc_r schmntcgrant_r tle_r conti_e tlm_e funds_e osrc_e schmntcgrant_e tle_e {
quietly su `var',d
gen top1=r(p99)
quietly su `var' if `var'>top1,d
replace outl=1 if `var'>r(p50) & `var'~=.
drop top1
}

gen DPEPf=conti_r+tlm_r+schmntcgrant_r+tle_r
label var DPEPf "DPEP/SSA funds in total (sum of 4 items)"
* this to avoid funny things with logs
gen DPEPfp=DPEPf/enr
label var DPEPfp "DPEP/SSA funds per pupil"
replace DPEPfp=0 if DPEPfp<1
gen DPEP = DPEPfp>0 & DPEPf~=.
label var DPEP "Recipient of any DPEP/SSA funds (dummy)"
gen lnDPEPfp=ln(DPEPfp)
label var lnDPEPfp "log DPEP/SSA funds per pupil"
replace lnDPEPfp=0 if DPEPfp==0|lnDPEPfp==.

* individual grants, not taking logs since variable amount of zeros
replace schmntcgrant_r=0 if schmntcgrant_r==.
replace tle_r=0 if tle_r==.
foreach var of varlist conti_r tlm_r funds_r osrc_r schmntcgrant_r tle_r conti_e tlm_e funds_e osrc_e schmntcgrant_e tle_e {
gen `var'p=`var'/enr
replace `var'p=0 if `var'p<1
}

label var conti_rp "School dev grant (DPEP/SSA) receipts per pupil"
label var tlm_rp "TLM grant (DPEP/SSA) receipts per pupil"
label var funds_rp "Funds collected from students receipts per pupil"
label var osrc_rp "Funds from other sources receipts per pupil"
label var schmntcgrant_rp "School maintenance grant (DPEP/SSA) receipts per pupil"
label var tle_rp "TLE grant (DPEP/SSA) % used"

* School management
gen mgt_tribal = schmgt==2
gen mgt_local = schmgt==3
gen mgt_priv = schmgt==4|schmgt==5
label var mgt_tribal "School management: Tribal"
label var mgt_local "School management: Local"
label var mgt_priv "School management: Private (aided+unaided)"
* School category 
gen cat_pup = schcat==2
gen cat_pups = schcat==3
label var cat_pup "School includes Upper Primary"
label var cat_pups "School includes Upper Pri. and Sec."

* Pupil teacher ratio
* note that enr is for year 1-4/5 only
* tchpos & parapos refer to whole school which may include upper primary, thus use 'tchpri'
gen puptch=enr/tchpri
gen puptch_nopara=enr/tchpri_nopara
* in both: note that zero teachers leads to pt-ratio not being defined!
gen noreg=tchpri_nopara==0
* Number of formal teachers there should be, if max of 40 pups per teacher enforced
gen tch40_=enr/40
gen tch40=floor(enr/40)
replace tch40=tch40+1 if tch40_!=tch40 | tch40==0
* set to zero for those with no pupils.
replace tch40=0 if enr==0
* Number of formal teachers required if also should have a minimum of 2 per school
gen tch40_2=tch40
replace tch40_2=2 if tch40==1
drop tch40_

* set top and bottom 0.5% as outliers. Unrealistic figures.
quietly su puptch,d
gen top1=r(p99)
gen bot1=r(p1)
quietly su puptch if puptch>top1,d
replace outl=1 if puptch>=r(p50) & puptch~=.
quietly su puptch if puptch<bot1,d
replace outl=1 if puptch<=r(p50) & puptch~=.
drop top1 bot1

label var puptch "enr/tchpri = enrolment 1-4/5 / primary teachers (inc para)"
label var puptch_nopara "enr/tchpri = enrolment 1-4/5 / primary teachers (excl para)"
label var noreg "No regular teacher in the primary school"
label var tch40 "required # of teachers if max 40 per teacher"
label var tch40_2 "tch40 + minimum of 2 per school (if any pupils)"



* Fix some worrying outliers on Distance to HQ
* set top 0.5% missing
quietly su disthqm,d
gen top1=r(p99)
su disthqm if disthqm>top1,d
replace outl=1 if disthqm>r(p50) & disthqm~=.
drop top1

************************
**** POLITICAL DATA ****
************************
rename ac_year year
*match politics to schools so that 2004 election result is matched to 2005-2006 DISE as that's where the new gov applies
replace year=year-1
sort distcd year
merge distcd year using /tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix
replace year=year+1
rename year ac_year
drop if _merge==2
drop _merge

compress
saveold /tera1/IndiaTeachers/Turnover/polcycle_all.dta,replace






