*
* Merge crime data from police districts (2005-2012) to DISE district codes (distcd)
** 22.4.2015

*Requires:
* /tera1/IndiaTeachers/violence/dstrIPC2001-12.dta
* /tera1/IndiaTeachers/violence/distlist.dta
* /violence/handmatched_state_distname_year.dta
* /AssemblyElec/2000-2012-DistrictPoliticsMatrix

* Produces Table 13 and Appendix Table A4

clear
use "/tera1/IndiaTeachers/violence/dstrIPC2001-12.dta"
drop if district=="TOTAL"
gen state=1 if stateut=="JAMMU & KASHMIR"
replace state=2 if stateut=="HIMACHAL PRADESH"
replace state=3 if stateut=="PUNJAB"
replace state=5 if stateut=="UTTARAKHAND"
replace state=6 if stateut=="HARYANA"
replace state=8 if stateut=="RAJASTHAN"
replace state=9 if stateut=="UTTAR PRADESH"
replace state=10 if stateut=="BIHAR"
replace state=11 if stateut=="SIKKIM"
replace state=12 if stateut=="ARUNACHAL PRADESH"
replace state=13 if stateut=="NAGALAND"
replace state=14 if stateut=="MANIPUR"
replace state=15 if stateut=="MIZORAM"
replace state=16 if stateut=="TRIPURA"
replace state=17 if stateut=="MEGHALAYA"
replace state=18 if stateut=="ASSAM"
replace state=19 if stateut=="WEST BENGAL"
replace state=20 if stateut=="JHARKHAND"
replace state=21 if stateut=="ODISHA"
replace state=22 if stateut=="CHHATTISGARH"
replace state=23 if stateut=="MADHYA PRADESH"
replace state=24 if stateut=="GUJARAT"
replace state=25 if stateut=="DAMAN & DIU"
replace state=26 if stateut=="D & N HAVELI"
replace state=27 if stateut=="MAHARASHTRA"
replace state=28 if stateut=="ANDHRA PRADESH"
replace state=29 if stateut=="KARNATAKA"
replace state=30 if stateut=="GOA"
replace state=32 if stateut=="KERALA"
replace state=33 if stateut=="TAMIL NADU"
replace state=34 if stateut=="PUDUCHERRY"
* The states that don't get a number are not in ASER

gen state2="JK" if stateut=="JAMMU & KASHMIR"
replace state2="HP" if stateut=="HIMACHAL PRADESH"
replace state2="PB" if stateut=="PUNJAB"
replace state2="UT" if stateut=="UTTARAKHAND"
replace state2="HY" if stateut=="HARYANA"
replace state2="RS" if stateut=="RAJASTHAN"
replace state2="UP" if stateut=="UTTAR PRADESH"
replace state2="BH" if stateut=="BIHAR"
replace state2="SK" if stateut=="SIKKIM"
replace state2="AP" if stateut=="ARUNACHAL PRADESH"
replace state2="NL" if stateut=="NAGALAND"
replace state2="MR" if stateut=="MANIPUR"
replace state2="MZ" if stateut=="MIZORAM"
replace state2="TP" if stateut=="TRIPURA"
replace state2="MG" if stateut=="MEGHALAYA"
replace state2="AS" if stateut=="ASSAM"
replace state2="WB" if stateut=="WEST BENGAL"
replace state2="JH" if stateut=="JHARKHAND"
replace state2="OR" if stateut=="ODISHA"
replace state2="CH" if stateut=="CHHATTISGARH"
replace state2="MP" if stateut=="MADHYA PRADESH"
replace state2="GU" if stateut=="GUJARAT"
replace state2="" if stateut=="DAMAN & DIU"
replace state2="" if stateut=="D & N HAVELI"
replace state2="MH" if stateut=="MAHARASHTRA"
replace state2="AP" if stateut=="ANDHRA PRADESH"
replace state2="KT" if stateut=="KARNATAKA"
replace state2="GO" if stateut=="GOA"
replace state2="KL" if stateut=="KERALA"
replace state2="TN" if stateut=="TAMIL NADU"
replace state2="PY" if stateut=="PUDUCHERRY"

sort year state district
save "/tera1/IndiaTeachers/violence/police12.dta",replace


* MORE POLICE DISTRICTS THAN DISTRICTS IN NEARLY EVERY MAJOR STATE 
* Might be straightforward if police districts are a clean partioning of districts
* But changes over time mean this has to be mapped year by year


*** FUZZY MATCH WITH RECLINK ***
* require: state, year
* Match with district

* Dise district codes from 
*clear
*use /tera1/DISE_Dec13/DISE_clean_Dec13/Schools.dta,using(ac_year distcd distname state)
*rename ac_year year
*collapse (mean) distcd state,by(year distname)
*drop if distname==""
*sort year state distname
*save /tera1/IndiaTeachers/violence/distlist.dta,replace

** Open list of DISE districts 2005-2012
use /tera1/IndiaTeachers/violence/distlist.dta,clear
* id using for reclink, form YYSSNN = Year State Number
gen idu=1 if year!=year[_n-1] | state!=state[_n-1]
replace idu=idu[_n-1]+1 if idu==.
replace idu=idu+state*100+(year-2000)*10000
label var idu "Admin dist identifier"
* 5046 unique values, 37 states
save /tera1/IndiaTeachers/violence/distlist2.dta,replace

use /tera1/IndiaTeachers/violence/police12.dta,clear
keep if year>=2005 & year<=2012
keep if state!=.
rename district distname
sort year state distname 
duplicates list year state distname
* Since this is railways, drop the duplicate
duplicates drop year state distname,force
* id master for reclink
gen idm=1 if year!=year[_n-1] | state!=state[_n-1]
replace idm=idm[_n-1]+1 if idm==.
replace idm=idm+state*100+(year-2000)*10000
label var idm "Police dist identifier"
* 5691 unique values, 31 states
reclink year state distname using /tera1/IndiaTeachers/violence/distlist2.dta, idmaster(idm) idusing(idu) gen(lscore) req(year state) wmatch(1 1 10)

* Kamrup and Bangalore Commr. police districts cover two districts
* drop from analysis
drop if distname=="KAMRUP"|distname=="BANGALORE COMMR."

* 881 unmatched, others look good.
* Actually, just 154 unique districts, see this:
* The remaining matched by hand, by searching from Wikipedia and taking account of district splits
* The unmatched_police_dists_done.xls -> handmatched_state_distname_year.csv -> handmatched_state_distname_year.dta
gen unmatched=_merge==1
drop _merge
sort unmatched state distname year
merge 1:1 unmatched state distname year using /tera1/IndiaTeachers/violence/handmatched_state_distname_year.dta
replace distcd=distcd2 if distcd==.
drop distcd2 unmatched _merge

keep year distname murder-totalipccrimes distcd 
rename distname poldist
sort distcd year

saveold /tera1/IndiaTeachers/violence/crimes05-12_distcd_year.dta,replace

********************************
* ESTIMATE EFFECT OF THE CYCLE *
********************************
use /tera1/IndiaTeachers/violence/crimes05-12_distcd_year.dta,clear
drop if distcd==.
collapse (sum) murder rape kidnappingabduction riots arson,by(distcd year)
* 5521 -> 4877

sort distcd year
saveold /tera1/IndiaTeachers/violence/crimes0512.dta,replace
replace year=year-1
sort distcd year
merge distcd year using /tera1/IndiaTeachers/AssemblyElec/2000-2012-DistrictPoliticsMatrix
* Could prossibly improve on the merge with fuzzy matching
replace year=year+1
drop if _merge==2
drop _merge



quietly tab elecyr, ge(ed)
quietly tab eleciv, ge(iv)
quietly tab year, ge(yd)

gen statecd=floor(distcd/100)

tis year
iis distcd

***********************
* ELECTIONS AND CRIME *
***********************
*Concentration of crimes to election & post-election year
foreach var of varlist murder rape kidnappingabduction riots arson {
egen `var'_s=sum(`var'),by(distcd)
gen `var'_e=`var' if ed1==1|ed2==1
replace `var'_e=0 if ed1!=1 & ed2!=1
egen `var'_es=sum(`var'_e),by(distcd)
gen `var'_c=`var'_es/`var'_s
drop `var'_s `var'_e `var'_es
}
label var murder_c "share of district murders taking place in election and post-election year"

pca *_c 
predict p1
egen p1z=std(p1)

set more off
su year murder rape kidnappingabduction riots arson if ed1!=.
*su *_c
*corr *_c
*su p1z,d
cd /tera1/IndiaTeachers/Politicalcycle


* Table 13
* log to adjust for sizes of areas
foreach var of varlist murder rape kidnappingabduction riots arson {
gen l`var'=ln(`var'+1)
}
quietly xtreg lmurder ed4 ed5 ed1 ed2 yd*, fe cluster(statecd) 
outreg2 using elec_crimel, wide 10pct bracket replace dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
quietly xtreg lrape ed4 ed5 ed1 ed2 yd*, fe cluster(statecd) 
outreg2 using elec_crimel, wide 10pct bracket append dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
quietly xtreg lkidnappingabduction ed4 ed5 ed1 ed2 yd*, fe cluster(statecd) 
outreg2 using elec_crimel, wide 10pct bracket append dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
quietly xtreg lriots ed4 ed5 ed1 ed2 yd*, fe cluster(statecd) 
outreg2 using elec_crimel, wide 10pct bracket append dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)
quietly xtreg larson ed4 ed5 ed1 ed2 yd*, fe cluster(statecd) 
outreg2 using elec_crimel, wide 10pct bracket append dec(3) fmt(g) keep(ed1 ed2 ed4 ed5)

* Sumstats (Table A4)
set logtype text
log using /tera1/IndiaTeachers/Politicalcycle/elec_crime_stats.txt,replace
su year murder rape kidnappingabduction riots arson ed1 ed2 ed3 ed4 ed5 if e(sample)
log close












